/****************************************************************************/
/* This file is part of FreeFEM.                                            */
/*                                                                          */
/* FreeFEM is free software: you can redistribute it and/or modify          */
/* it under the terms of the GNU Lesser General Public License as           */
/* published by the Free Software Foundation, either version 3 of           */
/* the License, or (at your option) any later version.                      */
/*                                                                          */
/* FreeFEM is distributed in the hope that it will be useful,               */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of           */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            */
/* GNU Lesser General Public License for more details.                      */
/*                                                                          */
/* You should have received a copy of the GNU Lesser General Public License */
/* along with FreeFEM. If not, see <http://www.gnu.org/licenses/>.          */
/****************************************************************************/
// SUMMARY : ...
// LICENSE : LGPLv3
// ORG     : LJLL Universite Pierre et Marie Curie, Paris, FRANCE
// AUTHORS : ...
// E-MAIL  : ...

/* clang-format off */
//ff-c++-LIBRARY-dep:
//ff-c++-cpp-dep:
//  the 3D quadratrure comme from MoFEM (Mesh Oriented Finite Element Method)
// come from
/*
 Journal of Computational Mathematics, Vol.27, No.1, 2009, 89–96.
 A SET OF SYMMETRIC QUADRATURE RULES ON TRIANGLES AND TETRAHEDRA*
 Linbo Zhang, Tao Cui and Hui Liu
 LSEC, ICMSEC, Academy of Mathematics and Systems Science, Chinese Academy of Sciences, Beijing 100190, China Email: zlb@lsec.cc.ac.cn, tcui@lsec.cc.ac.cn, liuhui@lsec.cc.ac.cn
 */
// https://www.researchgate.net/publication/228667586_A_set_of_symmetric_quadrature_rules_on_triangles_and_tetrahedra
// see https://likask.bitbucket.io/index.html
// or https://likask.bitbucket.io/quad_8c.html
/* clang-format on */

#include <stdlib.h>
#include <math.h>
#include <iostream>
#include <fstream>
#include "error.hpp"
#include "AFunction.hpp"
using namespace std;

#include "RNM.hpp"
#include "rgraph.hpp"
#include "fem.hpp"
#include "QuadratureFormular.hpp"
using namespace Fem2D;
/* awk -F[ t=:]* -f tt.awk  coords.txt >QF.cpp
 *
 * /integration/ { if(ii) {print "};"
 * print "const QuadratureFormular QuadratureFormular_T_" ii "(3," ii " ," N
 * ",P_QuadratureFormular_T_" ii ");" print "" print ""
 * };ii=$3;N=$5;
 * print "static const QuadraturePoint P_QuadratureFormular_T_" $3 "[] = {";}
 * !/integration/ {print "QuadraturePoint(" $4 "/2," $2"," $3"),"}
 * END {print "};";
 * print "const QuadratureFormular QuadratureFormular_T_" ii "(3," ii " ," N
 * ",P_QuadratureFormular_T_" ii ");" print "" print ""
 * }
 */
/*
 * static const QuadraturePoint P_QuadratureFormular_T_2[] = {
 * QuadraturePoint(0.6666666666667/2,0.1666666666667,0.6666666666667),
 * QuadraturePoint(0.6666666666667/2,0.6666666666667,0.1666666666667),
 * QuadraturePoint(0.6666666666667/2,0.1666666666667,0.1666666666667),
 * };
 * const QuadratureFormular QuadratureFormular_T_2(3,2 ,3,P_QuadratureFormular_T_2);
 *
 *
 * static const QuadraturePoint P_QuadratureFormular_T_4[] = {
 * QuadraturePoint(0.2199034873106/2,0.0915762135098,0.0915762135098),
 * QuadraturePoint(0.2199034873106/2,0.8168475729805,0.0915762135098),
 * QuadraturePoint(0.2199034873106/2,0.0915762135098,0.8168475729805),
 * QuadraturePoint(0.4467631793560/2,0.1081030181681,0.4459484909160),
 * QuadraturePoint(0.4467631793560/2,0.4459484909160,0.1081030181681),
 * QuadraturePoint(0.4467631793560/2,0.4459484909160,0.4459484909160),
 * };
 * const QuadratureFormular QuadratureFormular_T_4(3,4 ,6,P_QuadratureFormular_T_4);
 *
 *
 * static const QuadraturePoint P_QuadratureFormular_T_5[] = {
 * QuadraturePoint(0.0262712099504/2,0.0000000000000,1.0000000000000),
 * QuadraturePoint(0.0262716612068/2,1.0000000000000,0.0000000000000),
 * QuadraturePoint(0.0274163947600/2,0.0000000000000,0.0000000000000),
 * QuadraturePoint(0.2348383865823/2,0.2673273531185,0.6728199218710),
 * QuadraturePoint(0.2348412238268/2,0.6728175529461,0.2673288599482),
 * QuadraturePoint(0.2480251793114/2,0.0649236350054,0.6716530111494),
 * QuadraturePoint(0.2480304922521/2,0.6716498539042,0.0649251690029),
 * QuadraturePoint(0.2518604605529/2,0.0654032456800,0.2693789366453),
 * QuadraturePoint(0.2518660533658/2,0.2693767069140,0.0654054874919),
 * QuadraturePoint(0.4505789381914/2,0.3386738503896,0.3386799893027),
 * };
 * const QuadratureFormular QuadratureFormular_T_5(3,5 ,10,P_QuadratureFormular_T_5);
 *
 *
 * static const QuadraturePoint P_QuadratureFormular_T_7[] = {
 * QuadraturePoint(0.0102558174092/2,1.0000000000000,0.0000000000000),
 * QuadraturePoint(0.0102558174092/2,0.0000000000000,0.0000000000000),
 * QuadraturePoint(0.0102558174092/2,0.0000000000000,1.0000000000000),
 * QuadraturePoint(0.1116047046647/2,0.7839656651012,0.0421382841642),
 * QuadraturePoint(0.1116047046647/2,0.1738960507345,0.7839656651012),
 * QuadraturePoint(0.1116047046647/2,0.1738960507345,0.0421382841642),
 * QuadraturePoint(0.1116047046647/2,0.0421382841642,0.1738960507345),
 * QuadraturePoint(0.1116047046647/2,0.7839656651012,0.1738960507345),
 * QuadraturePoint(0.1116047046647/2,0.0421382841642,0.7839656651012),
 * QuadraturePoint(0.1679775595335/2,0.4743880861752,0.4743880861752),
 * QuadraturePoint(0.1679775595335/2,0.4743880861752,0.0512238276497),
 * QuadraturePoint(0.1679775595335/2,0.0512238276497,0.4743880861752),
 * QuadraturePoint(0.2652238803946/2,0.2385615300181,0.5228769399639),
 * QuadraturePoint(0.2652238803946/2,0.5228769399639,0.2385615300181),
 * QuadraturePoint(0.2652238803946/2,0.2385615300181,0.2385615300181),
 * };
 * const QuadratureFormular QuadratureFormular_T_7(3,7 ,15,P_QuadratureFormular_T_7);
 *
 *
 * static const QuadraturePoint P_QuadratureFormular_T_9[] = {
 * QuadraturePoint(0.0519871420646/2,0.0451890097844,0.0451890097844),
 * QuadraturePoint(0.0519871420646/2,0.0451890097844,0.9096219804312),
 * QuadraturePoint(0.0519871420646/2,0.9096219804312,0.0451890097844),
 * QuadraturePoint(0.0707034101784/2,0.7475124727339,0.0304243617288),
 * QuadraturePoint(0.0707034101784/2,0.2220631655373,0.0304243617288),
 * QuadraturePoint(0.0707034101784/2,0.7475124727339,0.2220631655373),
 * QuadraturePoint(0.0707034101784/2,0.2220631655373,0.7475124727339),
 * QuadraturePoint(0.0707034101784/2,0.0304243617288,0.7475124727339),
 * QuadraturePoint(0.0707034101784/2,0.0304243617288,0.2220631655373),
 * QuadraturePoint(0.0909390760952/2,0.1369912012649,0.2182900709714),
 * QuadraturePoint(0.0909390760952/2,0.6447187277637,0.2182900709714),
 * QuadraturePoint(0.0909390760952/2,0.1369912012649,0.6447187277637),
 * QuadraturePoint(0.0909390760952/2,0.2182900709714,0.6447187277637),
 * QuadraturePoint(0.0909390760952/2,0.2182900709714,0.1369912012649),
 * QuadraturePoint(0.0909390760952/2,0.6447187277637,0.1369912012649),
 * QuadraturePoint(0.1032344051380/2,0.0369603304334,0.4815198347833),
 * QuadraturePoint(0.1032344051380/2,0.4815198347833,0.0369603304334),
 * QuadraturePoint(0.1032344051380/2,0.4815198347833,0.4815198347833),
 * QuadraturePoint(0.1881601469167/2,0.4036039798179,0.1927920403641),
 * QuadraturePoint(0.1881601469167/2,0.4036039798179,0.4036039798179),
 * QuadraturePoint(0.1881601469167/2,0.1927920403641,0.4036039798179),
 * };
 * const QuadratureFormular QuadratureFormular_T_9(3,9 ,21,P_QuadratureFormular_T_9);
 */

static QuadraturePoint P_QuadratureFormular_T_11[] = {
  QuadraturePoint(0.0114082494033 / 2, 0.0000000000000, 0.9451704450174),
  QuadraturePoint(0.0114082494033 / 2, 0.9451704450173, 0.0000000000000),
  QuadraturePoint(0.0132691285720 / 2, 0.9289002405719, 0.0685505797224),
  QuadraturePoint(0.0132691285720 / 2, 0.0685505797224, 0.9289002405717),
  QuadraturePoint(0.0155865773350 / 2, 0.0243268355615, 0.0243268355616),
  QuadraturePoint(0.0408274780428 / 2, 0.1279662835335, 0.0277838749488),
  QuadraturePoint(0.0408274780429 / 2, 0.0277838749488, 0.1279662835337),
  QuadraturePoint(0.0579849665116 / 2, 0.0287083428360, 0.7498347588657),
  QuadraturePoint(0.0579849665116 / 2, 0.7498347588656, 0.0287083428360),
  QuadraturePoint(0.0601385247663 / 2, 0.7228007909707, 0.2497602062385),
  QuadraturePoint(0.0601385247663 / 2, 0.2497602062386, 0.7228007909707),
  QuadraturePoint(0.0625273888433 / 2, 0.0865562992839, 0.8325513856997),
  QuadraturePoint(0.0625273888433 / 2, 0.8325513856998, 0.0865562992839),
  QuadraturePoint(0.0639684321504 / 2, 0.3061619157672, 0.0303526617491),
  QuadraturePoint(0.0639684321504 / 2, 0.0303526617491, 0.3061619157675),
  QuadraturePoint(0.0661325872161 / 2, 0.4868610595047, 0.4868610595047),
  QuadraturePoint(0.0668503236820 / 2, 0.6657904293017, 0.1765456154219),
  QuadraturePoint(0.0668503236821 / 2, 0.1765456154221, 0.6657904293016),
  QuadraturePoint(0.0686904305977 / 2, 0.0293121007360, 0.5295657488669),
  QuadraturePoint(0.0686904305977 / 2, 0.5295657488667, 0.0293121007360),
  QuadraturePoint(0.1002717543859 / 2, 0.1444673824391, 0.1444673824391),
  QuadraturePoint(0.1143136784099 / 2, 0.3299740111411, 0.5361815729050),
  QuadraturePoint(0.1143136784099 / 2, 0.5361815729052, 0.3299740111409),
  QuadraturePoint(0.1223648146752 / 2, 0.5511507516862, 0.1437790861923),
  QuadraturePoint(0.1223648146752 / 2, 0.1437790861923, 0.5511507516862),
  QuadraturePoint(0.1394422334178 / 2, 0.3348066587327, 0.1529619437161),
  QuadraturePoint(0.1394422334178 / 2, 0.1529619437161, 0.3348066587327),
  QuadraturePoint(0.1744377829182 / 2, 0.3430183498147, 0.3430183498147),
};
const QuadratureFormular QuadratureFormular_T_11(11, 28, P_QuadratureFormular_T_11);
static QuadraturePoint P_QuadratureFormular_T_13[] = {
  QuadraturePoint(0.0166240998757 / 2, 0.0242935351590, 0.9493059293846),
  QuadraturePoint(0.0166811699778 / 2, 0.0265193427722, 0.0242695130640),
  QuadraturePoint(0.0166830569067 / 2, 0.9492126023551, 0.0265067966437),
  QuadraturePoint(0.0175680870083 / 2, 0.0033775763749, 0.4767316412363),
  QuadraturePoint(0.0184474661845 / 2, 0.4757672298101, 0.5198921829102),
  QuadraturePoint(0.0197942410188 / 2, 0.5190783193471, 0.0055912706202),
  QuadraturePoint(0.0203540395855 / 2, 0.8616839745321, 0.0133996048618),
  QuadraturePoint(0.0206852863940 / 2, 0.1249209759926, 0.8613054321334),
  QuadraturePoint(0.0208271366086 / 2, 0.0138565453861, 0.1247733717358),
  QuadraturePoint(0.0317819778279 / 2, 0.0211887064222, 0.8438438351223),
  QuadraturePoint(0.0320472035241 / 2, 0.8432296787219, 0.1354563645830),
  QuadraturePoint(0.0320607681146 / 2, 0.1354231797865, 0.0213482820656),
  QuadraturePoint(0.0430765959183 / 2, 0.3088853510679, 0.0221919663014),
  QuadraturePoint(0.0438473415339 / 2, 0.6685057595169, 0.3089012879389),
  QuadraturePoint(0.0439209672733 / 2, 0.0226545012557, 0.6691709943321),
  QuadraturePoint(0.0479951923691 / 2, 0.2808515408772, 0.6924718155106),
  QuadraturePoint(0.0483806260733 / 2, 0.6922446749051, 0.0268723345026),
  QuadraturePoint(0.0484867423375 / 2, 0.0268617447119, 0.2810093973222),
  QuadraturePoint(0.0556964488024 / 2, 0.1141778485470, 0.7973581413586),
  QuadraturePoint(0.0561026364356 / 2, 0.7974807922061, 0.0879806508791),
  QuadraturePoint(0.0565190123693 / 2, 0.0892807293894, 0.1145020561128),
  QuadraturePoint(0.0689289890670 / 2, 0.1052487892455, 0.6686904119922),
  QuadraturePoint(0.0717213336089 / 2, 0.6663022280740, 0.2275051631832),
  QuadraturePoint(0.0727453920976 / 2, 0.2307803737547, 0.1054572561221),
  QuadraturePoint(0.0788807336737 / 2, 0.1705059157540, 0.5174064398658),
  QuadraturePoint(0.0810114345512 / 2, 0.5086593973043, 0.3170523855209),
  QuadraturePoint(0.0825725299055 / 2, 0.3141823862281, 0.1810706361659),
  QuadraturePoint(0.0842044567330 / 2, 0.4617460817864, 0.4678594539804),
  QuadraturePoint(0.0843585533305 / 2, 0.0693087496081, 0.4622856042085),
  QuadraturePoint(0.0851969868488 / 2, 0.4651955259268, 0.0724357805669),
  QuadraturePoint(0.0902845328052 / 2, 0.2578625857893, 0.6131395039177),
  QuadraturePoint(0.0914283143485 / 2, 0.6112627766779, 0.1300360834609),
  QuadraturePoint(0.0916279065409 / 2, 0.1305182135934, 0.2581713828884),
  QuadraturePoint(0.1025573374896 / 2, 0.4281437991828, 0.2362005969817),
  QuadraturePoint(0.1033159661413 / 2, 0.3356995783730, 0.4311026308588),
  QuadraturePoint(0.1035854367193 / 2, 0.2305424298836, 0.3456013949376),
};
const QuadratureFormular QuadratureFormular_T_13(13, 36, P_QuadratureFormular_T_13);
static QuadraturePoint P_QuadratureFormular_T_14[] = {
  QuadraturePoint(0.0010616711990 / 2, 0.0000000000000, 1.0000000000000),
  QuadraturePoint(0.0010616711990 / 2, 1.0000000000000, 0.0000000000000),
  QuadraturePoint(0.0010616711990 / 2, 0.0000000000000, 0.0000000000000),
  QuadraturePoint(0.0131460236101 / 2, 0.0573330873026, 0.0151382269814),
  QuadraturePoint(0.0131460236101 / 2, 0.0573330873026, 0.9275286857160),
  QuadraturePoint(0.0131460236101 / 2, 0.9275286857160, 0.0573330873026),
  QuadraturePoint(0.0131460236101 / 2, 0.0151382269814, 0.0573330873026),
  QuadraturePoint(0.0131460236101 / 2, 0.9275286857160, 0.0151382269814),
  QuadraturePoint(0.0131460236101 / 2, 0.0151382269814, 0.9275286857160),
  QuadraturePoint(0.0242881926949 / 2, 0.8159625040711, 0.1659719969565),
  QuadraturePoint(0.0242881926949 / 2, 0.8159625040711, 0.0180654989724),
  QuadraturePoint(0.0242881926949 / 2, 0.1659719969565, 0.8159625040711),
  QuadraturePoint(0.0242881926949 / 2, 0.0180654989724, 0.8159625040711),
  QuadraturePoint(0.0242881926949 / 2, 0.1659719969565, 0.0180654989724),
  QuadraturePoint(0.0242881926949 / 2, 0.0180654989724, 0.1659719969565),
  QuadraturePoint(0.0316799866332 / 2, 0.3165475556378, 0.0186886898773),
  QuadraturePoint(0.0316799866332 / 2, 0.6647637544849, 0.0186886898773),
  QuadraturePoint(0.0316799866332 / 2, 0.0186886898773, 0.6647637544849),
  QuadraturePoint(0.0316799866332 / 2, 0.0186886898773, 0.3165475556378),
  QuadraturePoint(0.0316799866332 / 2, 0.3165475556378, 0.6647637544849),
  QuadraturePoint(0.0316799866332 / 2, 0.6647637544849, 0.3165475556378),
  QuadraturePoint(0.0349317947036 / 2, 0.0192662192492, 0.4903668903754),
  QuadraturePoint(0.0349317947036 / 2, 0.4903668903754, 0.0192662192492),
  QuadraturePoint(0.0349317947036 / 2, 0.4903668903754, 0.4903668903754),
  QuadraturePoint(0.0383664533945 / 2, 0.0875134669581, 0.8249730660837),
  QuadraturePoint(0.0383664533945 / 2, 0.0875134669581, 0.0875134669581),
  QuadraturePoint(0.0383664533945 / 2, 0.8249730660837, 0.0875134669581),
  QuadraturePoint(0.0578369491210 / 2, 0.0935526036219, 0.2079865423167),
  QuadraturePoint(0.0578369491210 / 2, 0.0935526036219, 0.6984608540613),
  QuadraturePoint(0.0578369491210 / 2, 0.2079865423167, 0.0935526036219),
  QuadraturePoint(0.0578369491210 / 2, 0.6984608540613, 0.0935526036219),
  QuadraturePoint(0.0578369491210 / 2, 0.6984608540613, 0.2079865423167),
  QuadraturePoint(0.0578369491210 / 2, 0.2079865423167, 0.6984608540613),
  QuadraturePoint(0.0725821687394 / 2, 0.0974892983467, 0.5380088595149),
  QuadraturePoint(0.0725821687394 / 2, 0.3645018421383, 0.0974892983467),
  QuadraturePoint(0.0725821687394 / 2, 0.5380088595149, 0.0974892983467),
  QuadraturePoint(0.0725821687394 / 2, 0.5380088595149, 0.3645018421383),
  QuadraturePoint(0.0725821687394 / 2, 0.3645018421383, 0.5380088595149),
  QuadraturePoint(0.0725821687394 / 2, 0.0974892983467, 0.3645018421383),
  QuadraturePoint(0.0897856524107 / 2, 0.2217145894873, 0.5565708210253),
  QuadraturePoint(0.0897856524107 / 2, 0.5565708210253, 0.2217145894873),
  QuadraturePoint(0.0897856524107 / 2, 0.2217145894873, 0.2217145894873),
  QuadraturePoint(0.1034544533617 / 2, 0.3860471669296, 0.2279056661408),
  QuadraturePoint(0.1034544533617 / 2, 0.2279056661408, 0.3860471669296),
  QuadraturePoint(0.1034544533617 / 2, 0.3860471669296, 0.3860471669296),
};
const QuadratureFormular QuadratureFormular_T_14(14, 45, P_QuadratureFormular_T_14);
static QuadraturePoint P_QuadratureFormular_T_16[] = {
  QuadraturePoint(0.0006202599851 / 2, 1.0000000000000, 0.0000000000000),
  QuadraturePoint(0.0006315174712 / 2, 0.0000000000000, 1.0000000000000),
  QuadraturePoint(0.0007086601559 / 2, 0.0000000000000, 0.0000000000000),
  QuadraturePoint(0.0055163716168 / 2, 0.9398863583577, 0.0049848744634),
  QuadraturePoint(0.0062692407656 / 2, 0.0543806683058, 0.9386405618617),
  QuadraturePoint(0.0078531408826 / 2, 0.0093940049164, 0.0526424462697),
  QuadraturePoint(0.0094551483864 / 2, 0.0164345086362, 0.9469035517351),
  QuadraturePoint(0.0097824511271 / 2, 0.9469487269862, 0.0363373677167),
  QuadraturePoint(0.0099861643489 / 2, 0.0426604005768, 0.0151224541799),
  QuadraturePoint(0.0137553818816 / 2, 0.0122269495439, 0.8693773510664),
  QuadraturePoint(0.0140979178040 / 2, 0.8673696521047, 0.1204917285774),
  QuadraturePoint(0.0149646864337 / 2, 0.8456744021389, 0.0157763967870),
  QuadraturePoint(0.0156097503612 / 2, 0.1395759632103, 0.8448120870375),
  QuadraturePoint(0.0157683693348 / 2, 0.1317821743231, 0.0135009605584),
  QuadraturePoint(0.0175794546383 / 2, 0.0157955126300, 0.1455274938536),
  QuadraturePoint(0.0204113840270 / 2, 0.7365462884436, 0.0155697540908),
  QuadraturePoint(0.0209562878616 / 2, 0.0139688430330, 0.7379836894450),
  QuadraturePoint(0.0210713412998 / 2, 0.2547895186039, 0.7297615689771),
  QuadraturePoint(0.0217646760202 / 2, 0.7316386522555, 0.2543076683315),
  QuadraturePoint(0.0222288408699 / 2, 0.0157253728951, 0.2696239795791),
  QuadraturePoint(0.0224186693682 / 2, 0.2662302843647, 0.0144783956308),
  QuadraturePoint(0.0230122616993 / 2, 0.8673504065214, 0.0591679410400),
  QuadraturePoint(0.0236813902500 / 2, 0.0741493666957, 0.8634782575061),
  QuadraturePoint(0.0257464643368 / 2, 0.0159285948360, 0.4191238955238),
  QuadraturePoint(0.0257956801608 / 2, 0.0156061028068, 0.5809222921146),
  QuadraturePoint(0.0258072327610 / 2, 0.5910094817484, 0.0159251452651),
  QuadraturePoint(0.0260343232059 / 2, 0.4034771496889, 0.5806700368104),
  QuadraturePoint(0.0265768141609 / 2, 0.5694745628526, 0.4149495146302),
  QuadraturePoint(0.0265784761831 / 2, 0.0678493700650, 0.0761218678591),
  QuadraturePoint(0.0267532329238 / 2, 0.4265968590272, 0.0157509692312),
  QuadraturePoint(0.0375787806641 / 2, 0.0670982507890, 0.7741898312421),
  QuadraturePoint(0.0383065894195 / 2, 0.7528310231480, 0.0819119495639),
  QuadraturePoint(0.0384849695025 / 2, 0.7753727783557, 0.1577128457292),
  QuadraturePoint(0.0389619825852 / 2, 0.1689073157787, 0.7503943099742),
  QuadraturePoint(0.0394604111547 / 2, 0.1687335832919, 0.0708311507268),
  QuadraturePoint(0.0412364778098 / 2, 0.0821244708436, 0.1762996626771),
  QuadraturePoint(0.0512872438483 / 2, 0.6288705363345, 0.0807744953317),
  QuadraturePoint(0.0516405641935 / 2, 0.0811413015266, 0.3054373589776),
  QuadraturePoint(0.0518230042269 / 2, 0.2969112065080, 0.6227485988871),
  QuadraturePoint(0.0528527988181 / 2, 0.0767542314171, 0.6247247149546),
  QuadraturePoint(0.0538505573027 / 2, 0.6223022333845, 0.3011485821166),
  QuadraturePoint(0.0541895329319 / 2, 0.3103786288051, 0.0779098365079),
  QuadraturePoint(0.0584737146444 / 2, 0.0819218215187, 0.4603633038351),
  QuadraturePoint(0.0592863168363 / 2, 0.4717022665013, 0.0821554006797),
  QuadraturePoint(0.0594358276749 / 2, 0.4546603415250, 0.4637565033890),
  QuadraturePoint(0.0631800255863 / 2, 0.1701091339237, 0.6422277808188),
  QuadraturePoint(0.0632926845153 / 2, 0.6406004329487, 0.1898293537256),
  QuadraturePoint(0.0640707361772 / 2, 0.1912267583717, 0.1739955685343),
  QuadraturePoint(0.0812040595918 / 2, 0.1885315767070, 0.4798914070406),
  QuadraturePoint(0.0814437513530 / 2, 0.4772929957691, 0.3348356598119),
  QuadraturePoint(0.0814679201241 / 2, 0.3126974621760, 0.4957972197259),
  QuadraturePoint(0.0815050548084 / 2, 0.4961225945946, 0.1927553668904),
  QuadraturePoint(0.0815164664939 / 2, 0.1928805312867, 0.3161015807261),
  QuadraturePoint(0.0816931059623 / 2, 0.3360041453816, 0.1894892801290),
  QuadraturePoint(0.0923218334531 / 2, 0.3337280550848, 0.3343571021811),
};
const QuadratureFormular QuadratureFormular_T_16(16, 55, P_QuadratureFormular_T_16);
static QuadraturePoint P_QuadratureFormular_T_18[] = {
  QuadraturePoint(0.0025165756986 / 2, 0.0116731059668, 0.9812565951289),
  QuadraturePoint(0.0025273452007 / 2, 0.9810030858388, 0.0071462504863),
  QuadraturePoint(0.0033269295333 / 2, 0.0106966317092, 0.0115153933376),
  QuadraturePoint(0.0081503492125 / 2, 0.9382476983551, 0.0495570591341),
  QuadraturePoint(0.0086135525742 / 2, 0.0126627518417, 0.9370123620615),
  QuadraturePoint(0.0087786746179 / 2, 0.0598109409984, 0.0121364578922),
  QuadraturePoint(0.0097099585562 / 2, 0.0137363297927, 0.0612783625597),
  QuadraturePoint(0.0102466211915 / 2, 0.9229527959405, 0.0141128270602),
  QuadraturePoint(0.0108397688341 / 2, 0.0633107354993, 0.9220197291727),
  QuadraturePoint(0.0129385390176 / 2, 0.0117265100335, 0.1500520475229),
  QuadraturePoint(0.0136339823583 / 2, 0.1554720587323, 0.8325147121589),
  QuadraturePoint(0.0138477328147 / 2, 0.8343293888982, 0.0125228158759),
  QuadraturePoint(0.0139421540105 / 2, 0.8501638031957, 0.1371997508736),
  QuadraturePoint(0.0144121399968 / 2, 0.0128816350522, 0.8477627063479),
  QuadraturePoint(0.0153703455534 / 2, 0.1510801608959, 0.0136526924039),
  QuadraturePoint(0.0162489802253 / 2, 0.0101917879217, 0.5770438618345),
  QuadraturePoint(0.0169718304280 / 2, 0.2813372399303, 0.7066853759623),
  QuadraturePoint(0.0170088532421 / 2, 0.7124374628501, 0.0124569780990),
  QuadraturePoint(0.0170953520675 / 2, 0.2763025250863, 0.0121741311386),
  QuadraturePoint(0.0173888854559 / 2, 0.0109658368561, 0.4194306712466),
  QuadraturePoint(0.0174543962439 / 2, 0.4289110517884, 0.5599616067469),
  QuadraturePoint(0.0178406757287 / 2, 0.4215420555115, 0.0116475994785),
  QuadraturePoint(0.0178446863879 / 2, 0.5711258590444, 0.0118218313989),
  QuadraturePoint(0.0179046337552 / 2, 0.5826868270511, 0.4057889581177),
  QuadraturePoint(0.0181259756201 / 2, 0.0130567806713, 0.2725023750868),
  QuadraturePoint(0.0184784838882 / 2, 0.0130760400964, 0.7224712523233),
  QuadraturePoint(0.0185793564371 / 2, 0.7263437062407, 0.2602984019251),
  QuadraturePoint(0.0203217151777 / 2, 0.0687230068637, 0.0631417277210),
  QuadraturePoint(0.0213771661809 / 2, 0.8652302101529, 0.0720611837338),
  QuadraturePoint(0.0231916854098 / 2, 0.0648599071037, 0.8590433543910),
  QuadraturePoint(0.0274426710859 / 2, 0.1483494943362, 0.7888788352240),
  QuadraturePoint(0.0290301922340 / 2, 0.0624359898396, 0.1493935499354),
  QuadraturePoint(0.0294522738505 / 2, 0.7871369011735, 0.0656382042757),
  QuadraturePoint(0.0299436251629 / 2, 0.0519104921610, 0.5255635695605),
  QuadraturePoint(0.0307026948119 / 2, 0.1543129927444, 0.0716383926917),
  QuadraturePoint(0.0325263365863 / 2, 0.2617842745603, 0.0621479485288),
  QuadraturePoint(0.0327884208506 / 2, 0.7667257872813, 0.1658211554831),
  QuadraturePoint(0.0331234675192 / 2, 0.2582103676627, 0.6800119766139),
  QuadraturePoint(0.0346167526875 / 2, 0.0679065925147, 0.7571515437782),
  QuadraturePoint(0.0347081373976 / 2, 0.5293578274804, 0.4121503841107),
  QuadraturePoint(0.0347372049404 / 2, 0.0666036150484, 0.2612513087886),
  QuadraturePoint(0.0348528762454 / 2, 0.0585675461899, 0.3902236114535),
  QuadraturePoint(0.0348601561186 / 2, 0.0644535360411, 0.6373626559761),
  QuadraturePoint(0.0355471569975 / 2, 0.6748138429151, 0.0637583342061),
  QuadraturePoint(0.0360182996383 / 2, 0.3914602310369, 0.5503238090563),
  QuadraturePoint(0.0362926285843 / 2, 0.6487701492307, 0.2836728360263),
  QuadraturePoint(0.0381897702083 / 2, 0.3946498220408, 0.0605175522554),
  QuadraturePoint(0.0392252800118 / 2, 0.5390137151933, 0.0611990176936),
  QuadraturePoint(0.0482710125888 / 2, 0.1627895082785, 0.6861322141035),
  QuadraturePoint(0.0489912121566 / 2, 0.6812436322641, 0.1567968345899),
  QuadraturePoint(0.0497220833872 / 2, 0.1542832878020, 0.1667512624020),
  QuadraturePoint(0.0507065736986 / 2, 0.2522727750445, 0.2504803933395),
  QuadraturePoint(0.0509771994043 / 2, 0.2547981532407, 0.4994090649043),
  QuadraturePoint(0.0521360063667 / 2, 0.1485580549194, 0.5756023096087),
  QuadraturePoint(0.0523460874925 / 2, 0.2930239606436, 0.5656897354162),
  QuadraturePoint(0.0524440683552 / 2, 0.2808991272310, 0.1437921574248),
  QuadraturePoint(0.0527459644823 / 2, 0.4820989592971, 0.2518557535865),
  QuadraturePoint(0.0529449063728 / 2, 0.5641878245444, 0.1462966743153),
  QuadraturePoint(0.0542395594501 / 2, 0.1307699644344, 0.4489577586117),
  QuadraturePoint(0.0543470203419 / 2, 0.1479692221948, 0.3001174386829),
  QuadraturePoint(0.0547100548639 / 2, 0.5638684222946, 0.2813772089298),
  QuadraturePoint(0.0557288345913 / 2, 0.4361157428790, 0.4252053446420),
  QuadraturePoint(0.0577734264233 / 2, 0.3603263935285, 0.2599190004889),
  QuadraturePoint(0.0585393781623 / 2, 0.4224188334674, 0.1453238443303),
  QuadraturePoint(0.0609039250680 / 2, 0.3719001833052, 0.3780122703567),
  QuadraturePoint(0.0637273964449 / 2, 0.2413645006928, 0.3847563284940),
};
const QuadratureFormular QuadratureFormular_T_18(18, 66, P_QuadratureFormular_T_18);
static QuadraturePoint P_QuadratureFormular_T_20[] = {
  QuadraturePoint(0.0021744545399 / 2, 0.0089411337112, 0.0086983293702),
  QuadraturePoint(0.0028987135265 / 2, 0.9792622629807, 0.0102644133744),
  QuadraturePoint(0.0030846029337 / 2, 0.0105475382112, 0.9785514202515),
  QuadraturePoint(0.0034401633104 / 2, 0.0023777061947, 0.0636551098604),
  QuadraturePoint(0.0041898472012 / 2, 0.0630425115795, 0.0041506347509),
  QuadraturePoint(0.0044738051498 / 2, 0.9308422496730, 0.0048053482263),
  QuadraturePoint(0.0047054420814 / 2, 0.0629076555490, 0.9316790069481),
  QuadraturePoint(0.0048867935750 / 2, 0.9315962246381, 0.0626264881801),
  QuadraturePoint(0.0051927643369 / 2, 0.0061951689415, 0.9293587058564),
  QuadraturePoint(0.0074073058981 / 2, 0.0287125819237, 0.0310202122997),
  QuadraturePoint(0.0079755410301 / 2, 0.9293844478305, 0.0342152968219),
  QuadraturePoint(0.0083550522910 / 2, 0.0375457566621, 0.9257868884669),
  QuadraturePoint(0.0096166660864 / 2, 0.0086895739064, 0.1584971251510),
  QuadraturePoint(0.0096318257850 / 2, 0.1547597053965, 0.8363606657688),
  QuadraturePoint(0.0098577460758 / 2, 0.8331025294185, 0.0089257244824),
  QuadraturePoint(0.0102657880301 / 2, 0.8374231073526, 0.1529167304078),
  QuadraturePoint(0.0103188103111 / 2, 0.1559362505234, 0.0094966240058),
  QuadraturePoint(0.0106291001630 / 2, 0.0098599642095, 0.8342211493596),
  QuadraturePoint(0.0106881306895 / 2, 0.4055873733289, 0.0074389302008),
  QuadraturePoint(0.0106969021010 / 2, 0.5964727898618, 0.3956330809311),
  QuadraturePoint(0.0109026461714 / 2, 0.0080747800416, 0.4031319425903),
  QuadraturePoint(0.0109899783575 / 2, 0.0075073977721, 0.5851609594681),
  QuadraturePoint(0.0113423055229 / 2, 0.3936764519237, 0.5974896592899),
  QuadraturePoint(0.0120535642930 / 2, 0.5846530726212, 0.0087250464968),
  QuadraturePoint(0.0139619193821 / 2, 0.4870804112120, 0.0202129229912),
  QuadraturePoint(0.0141147991536 / 2, 0.2683512811785, 0.7202340088668),
  QuadraturePoint(0.0141930347046 / 2, 0.7223956288748, 0.2662399366456),
  QuadraturePoint(0.0144212676268 / 2, 0.2716826742357, 0.0112882698808),
  QuadraturePoint(0.0144704346855 / 2, 0.0112580842046, 0.7169695963325),
  QuadraturePoint(0.0144949769872 / 2, 0.0115034734370, 0.2740067110166),
  QuadraturePoint(0.0145386775694 / 2, 0.7140525900564, 0.0113511560497),
  QuadraturePoint(0.0145964190926 / 2, 0.4902871053112, 0.4936491841468),
  QuadraturePoint(0.0147314578466 / 2, 0.0201423425209, 0.4832573459601),
  QuadraturePoint(0.0167463963304 / 2, 0.0361107464859, 0.0935679501582),
  QuadraturePoint(0.0168955500458 / 2, 0.8607998819851, 0.0397379067075),
  QuadraturePoint(0.0169422662884 / 2, 0.1005891526001, 0.8586343419352),
  QuadraturePoint(0.0173070172095 / 2, 0.0918740717058, 0.0395513001973),
  QuadraturePoint(0.0174524546493 / 2, 0.8604888296191, 0.0966224057079),
  QuadraturePoint(0.0177217222159 / 2, 0.0439842178673, 0.8561886349107),
  QuadraturePoint(0.0282824024023 / 2, 0.2011017606735, 0.7449115835626),
  QuadraturePoint(0.0284996712488 / 2, 0.7449993726263, 0.0536865638166),
  QuadraturePoint(0.0285005646539 / 2, 0.0532186641310, 0.1963754275935),
  QuadraturePoint(0.0300647223478 / 2, 0.7453984647401, 0.1982065805550),
  QuadraturePoint(0.0302031277082 / 2, 0.1957289932876, 0.0555713833156),
  QuadraturePoint(0.0303987136077 / 2, 0.1092532057988, 0.6100036182413),
  QuadraturePoint(0.0305668796074 / 2, 0.0567625702001, 0.7409121894959),
  QuadraturePoint(0.0306067413002 / 2, 0.0483837933475, 0.6075135660978),
  QuadraturePoint(0.0309330068201 / 2, 0.1080612809760, 0.1122081510437),
  QuadraturePoint(0.0309773820835 / 2, 0.6185605900991, 0.2698753703035),
  QuadraturePoint(0.0313146250545 / 2, 0.7721296013497, 0.1114117395333),
  QuadraturePoint(0.0313573493392 / 2, 0.6115734801133, 0.3389367677931),
  QuadraturePoint(0.0314320469287 / 2, 0.3381326103376, 0.0494693938787),
  QuadraturePoint(0.0315182143894 / 2, 0.1173084128254, 0.7696451309795),
  QuadraturePoint(0.0324248137985 / 2, 0.2674551260596, 0.1115718808154),
  QuadraturePoint(0.0347512152386 / 2, 0.6542100160026, 0.1906548314700),
  QuadraturePoint(0.0350393454927 / 2, 0.0538297481158, 0.3358616826849),
  QuadraturePoint(0.0350717420310 / 2, 0.1848840324117, 0.1551831523851),
  QuadraturePoint(0.0352129215334 / 2, 0.3376267104744, 0.6081402596294),
  QuadraturePoint(0.0352615504981 / 2, 0.6067102034499, 0.0542632795598),
  QuadraturePoint(0.0366403220343 / 2, 0.4612614085496, 0.0688176670722),
  QuadraturePoint(0.0367733107670 / 2, 0.1525465365671, 0.6510240845749),
  QuadraturePoint(0.0371675662937 / 2, 0.0700582543543, 0.4661904392742),
  QuadraturePoint(0.0373371571606 / 2, 0.4704201379032, 0.4634826455353),
  QuadraturePoint(0.0403973346588 / 2, 0.1216461693746, 0.2381494875516),
  QuadraturePoint(0.0413580040638 / 2, 0.6371404052702, 0.1238399384513),
  QuadraturePoint(0.0421957791870 / 2, 0.2379904515119, 0.6370216452326),
  QuadraturePoint(0.0495451004037 / 2, 0.1483929857177, 0.4894188577780),
  QuadraturePoint(0.0500419261141 / 2, 0.3598069571550, 0.1452880866253),
  QuadraturePoint(0.0505794587115 / 2, 0.4941441055095, 0.3610216383818),
  QuadraturePoint(0.0520037210188 / 2, 0.1440630687981, 0.3513508341887),
  QuadraturePoint(0.0521533567886 / 2, 0.5019764440004, 0.1435491663293),
  QuadraturePoint(0.0524899152358 / 2, 0.3555423834298, 0.5016491599502),
  QuadraturePoint(0.0599159762516 / 2, 0.2443439540771, 0.2406052129104),
  QuadraturePoint(0.0599609997426 / 2, 0.2437064989342, 0.5109017277055),
  QuadraturePoint(0.0599915272129 / 2, 0.5122200807321, 0.2452737973543),
  QuadraturePoint(0.0634133183449 / 2, 0.2526038315178, 0.3700319555094),
  QuadraturePoint(0.0635311861108 / 2, 0.3759895652851, 0.2505406611631),
  QuadraturePoint(0.0637206605672 / 2, 0.3729077987144, 0.3753750277549),
};
const QuadratureFormular QuadratureFormular_T_20(20, 78, P_QuadratureFormular_T_20);
static QuadraturePoint P_QuadratureFormular_T_21[] = {
  QuadraturePoint(0.0006704436439 / 2, 0.0035524391922, 0.0035524391922),
  QuadraturePoint(0.0006704436439 / 2, 0.0035524391922, 0.9928951216156),
  QuadraturePoint(0.0006704436439 / 2, 0.9928951216156, 0.0035524391922),
  QuadraturePoint(0.0045472608074 / 2, 0.9553548273730, 0.0087898929093),
  QuadraturePoint(0.0045472608074 / 2, 0.0358552797177, 0.0087898929093),
  QuadraturePoint(0.0045472608074 / 2, 0.9553548273730, 0.0358552797177),
  QuadraturePoint(0.0045472608074 / 2, 0.0087898929093, 0.0358552797177),
  QuadraturePoint(0.0045472608074 / 2, 0.0087898929093, 0.9553548273730),
  QuadraturePoint(0.0045472608074 / 2, 0.0358552797177, 0.9553548273730),
  QuadraturePoint(0.0052077585320 / 2, 0.8865264879047, 0.1082329745017),
  QuadraturePoint(0.0052077585320 / 2, 0.8865264879047, 0.0052405375935),
  QuadraturePoint(0.0052077585320 / 2, 0.0052405375935, 0.1082329745017),
  QuadraturePoint(0.0052077585320 / 2, 0.0052405375935, 0.8865264879047),
  QuadraturePoint(0.0052077585320 / 2, 0.1082329745017, 0.8865264879047),
  QuadraturePoint(0.0052077585320 / 2, 0.1082329745017, 0.0052405375935),
  QuadraturePoint(0.0065435432887 / 2, 0.0466397432150, 0.9067205135700),
  QuadraturePoint(0.0065435432887 / 2, 0.0466397432150, 0.0466397432150),
  QuadraturePoint(0.0065435432887 / 2, 0.9067205135700, 0.0466397432150),
  QuadraturePoint(0.0092737841533 / 2, 0.2075720456946, 0.0082759241284),
  QuadraturePoint(0.0092737841533 / 2, 0.2075720456946, 0.7841520301770),
  QuadraturePoint(0.0092737841533 / 2, 0.7841520301770, 0.2075720456946),
  QuadraturePoint(0.0092737841533 / 2, 0.0082759241284, 0.7841520301770),
  QuadraturePoint(0.0092737841533 / 2, 0.0082759241284, 0.2075720456946),
  QuadraturePoint(0.0092737841533 / 2, 0.7841520301770, 0.0082759241284),
  QuadraturePoint(0.0095937782623 / 2, 0.0858119489725, 0.0314836947701),
  QuadraturePoint(0.0095937782623 / 2, 0.8827043562574, 0.0314836947701),
  QuadraturePoint(0.0095937782623 / 2, 0.0314836947701, 0.0858119489725),
  QuadraturePoint(0.0095937782623 / 2, 0.0858119489725, 0.8827043562574),
  QuadraturePoint(0.0095937782623 / 2, 0.8827043562574, 0.0858119489725),
  QuadraturePoint(0.0095937782623 / 2, 0.0314836947701, 0.8827043562574),
  QuadraturePoint(0.0114247809167 / 2, 0.6688778233826, 0.0095150760625),
  QuadraturePoint(0.0114247809167 / 2, 0.0095150760625, 0.3216071005550),
  QuadraturePoint(0.0114247809167 / 2, 0.0095150760625, 0.6688778233826),
  QuadraturePoint(0.0114247809167 / 2, 0.6688778233826, 0.3216071005550),
  QuadraturePoint(0.0114247809167 / 2, 0.3216071005550, 0.6688778233826),
  QuadraturePoint(0.0114247809167 / 2, 0.3216071005550, 0.0095150760625),
  QuadraturePoint(0.0117216964174 / 2, 0.4379999543113, 0.0099859785681),
  QuadraturePoint(0.0117216964174 / 2, 0.0099859785681, 0.5520140671206),
  QuadraturePoint(0.0117216964174 / 2, 0.4379999543113, 0.5520140671206),
  QuadraturePoint(0.0117216964174 / 2, 0.0099859785681, 0.4379999543113),
  QuadraturePoint(0.0117216964174 / 2, 0.5520140671206, 0.4379999543113),
  QuadraturePoint(0.0117216964174 / 2, 0.5520140671206, 0.0099859785681),
  QuadraturePoint(0.0188197155232 / 2, 0.7974931072148, 0.0405093994119),
  QuadraturePoint(0.0188197155232 / 2, 0.0405093994119, 0.1619974933734),
  QuadraturePoint(0.0188197155232 / 2, 0.0405093994119, 0.7974931072148),
  QuadraturePoint(0.0188197155232 / 2, 0.1619974933734, 0.7974931072148),
  QuadraturePoint(0.0188197155232 / 2, 0.7974931072148, 0.1619974933734),
  QuadraturePoint(0.0188197155232 / 2, 0.1619974933734, 0.0405093994119),
  QuadraturePoint(0.0235260980271 / 2, 0.3864215551955, 0.3864215551955),
  QuadraturePoint(0.0235260980271 / 2, 0.3864215551955, 0.2271568896090),
  QuadraturePoint(0.0235260980271 / 2, 0.2271568896090, 0.3864215551955),
  QuadraturePoint(0.0235571466151 / 2, 0.8090129379329, 0.0954935310336),
  QuadraturePoint(0.0235571466151 / 2, 0.0954935310336, 0.8090129379329),
  QuadraturePoint(0.0235571466151 / 2, 0.0954935310336, 0.0954935310336),
  QuadraturePoint(0.0268246207430 / 2, 0.2745425238718, 0.0479840480721),
  QuadraturePoint(0.0268246207430 / 2, 0.0479840480721, 0.6774734280561),
  QuadraturePoint(0.0268246207430 / 2, 0.6774734280561, 0.0479840480721),
  QuadraturePoint(0.0268246207430 / 2, 0.6774734280561, 0.2745425238718),
  QuadraturePoint(0.0268246207430 / 2, 0.2745425238718, 0.6774734280561),
  QuadraturePoint(0.0268246207430 / 2, 0.0479840480721, 0.2745425238718),
  QuadraturePoint(0.0314289776779 / 2, 0.4053472446667, 0.5429849622344),
  QuadraturePoint(0.0314289776779 / 2, 0.0516677930989, 0.4053472446667),
  QuadraturePoint(0.0314289776779 / 2, 0.4053472446667, 0.0516677930989),
  QuadraturePoint(0.0314289776779 / 2, 0.5429849622344, 0.0516677930989),
  QuadraturePoint(0.0314289776779 / 2, 0.0516677930989, 0.5429849622344),
  QuadraturePoint(0.0314289776779 / 2, 0.5429849622344, 0.4053472446667),
  QuadraturePoint(0.0337196192159 / 2, 0.1877738615539, 0.1068148267588),
  QuadraturePoint(0.0337196192159 / 2, 0.7054113116872, 0.1877738615539),
  QuadraturePoint(0.0337196192159 / 2, 0.7054113116872, 0.1068148267588),
  QuadraturePoint(0.0337196192159 / 2, 0.1068148267588, 0.7054113116872),
  QuadraturePoint(0.0337196192159 / 2, 0.1877738615539, 0.7054113116872),
  QuadraturePoint(0.0337196192159 / 2, 0.1068148267588, 0.1877738615539),
  QuadraturePoint(0.0427745294213 / 2, 0.1195059712009, 0.3057122990643),
  QuadraturePoint(0.0427745294213 / 2, 0.1195059712009, 0.5747817297348),
  QuadraturePoint(0.0427745294213 / 2, 0.5747817297348, 0.1195059712009),
  QuadraturePoint(0.0427745294213 / 2, 0.5747817297348, 0.3057122990643),
  QuadraturePoint(0.0427745294213 / 2, 0.3057122990643, 0.5747817297348),
  QuadraturePoint(0.0427745294213 / 2, 0.3057122990643, 0.1195059712009),
  QuadraturePoint(0.0441138932737 / 2, 0.5981245743363, 0.2009377128319),
  QuadraturePoint(0.0441138932737 / 2, 0.2009377128319, 0.5981245743363),
  QuadraturePoint(0.0441138932737 / 2, 0.2009377128319, 0.2009377128319),
  QuadraturePoint(0.0461469594684 / 2, 0.2160775200005, 0.3121360256673),
  QuadraturePoint(0.0461469594684 / 2, 0.3121360256673, 0.2160775200005),
  QuadraturePoint(0.0461469594684 / 2, 0.2160775200005, 0.4717864543321),
  QuadraturePoint(0.0461469594684 / 2, 0.3121360256673, 0.4717864543321),
  QuadraturePoint(0.0461469594684 / 2, 0.4717864543321, 0.3121360256673),
  QuadraturePoint(0.0461469594684 / 2, 0.4717864543321, 0.2160775200005),
  QuadraturePoint(0.0469152468624 / 2, 0.4376579903849, 0.4376579903849),
  QuadraturePoint(0.0469152468624 / 2, 0.4376579903849, 0.1246840192303),
  QuadraturePoint(0.0469152468624 / 2, 0.1246840192303, 0.4376579903849),
  QuadraturePoint(0.0551199980347 / 2, 0.3333333333333, 0.3333333333333),
};
const QuadratureFormular QuadratureFormular_T_21(21, 91, P_QuadratureFormular_T_21);
static QuadraturePoint P_QuadratureFormular_T_23[] = {
  QuadraturePoint(0.0006438298261 / 2, 0.0087809303836, 0.9903676436772),
  QuadraturePoint(0.0006438413076 / 2, 0.9903675314220, 0.0087809216232),
  QuadraturePoint(0.0010134735710 / 2, 0.0027029276450, 0.0335914404439),
  QuadraturePoint(0.0010134752576 / 2, 0.0335909214524, 0.0027028946710),
  QuadraturePoint(0.0019679929935 / 2, 0.0091675068606, 0.0091676353051),
  QuadraturePoint(0.0033467313784 / 2, 0.9675568182558, 0.0084737176656),
  QuadraturePoint(0.0033467339208 / 2, 0.0084737200688, 0.9675569435345),
  QuadraturePoint(0.0042873323375 / 2, 0.0078781948792, 0.0676784943862),
  QuadraturePoint(0.0042873459885 / 2, 0.0676785477700, 0.0078781659291),
  QuadraturePoint(0.0043003801372 / 2, 0.9470266955047, 0.0442974541187),
  QuadraturePoint(0.0043003849098 / 2, 0.0442974755680, 0.9470266676487),
  QuadraturePoint(0.0056934629205 / 2, 0.9144243214882, 0.0081735455132),
  QuadraturePoint(0.0056934640134 / 2, 0.0081735424459, 0.9144244234031),
  QuadraturePoint(0.0061643868015 / 2, 0.2497452292741, 0.3833232434720),
  QuadraturePoint(0.0061644756418 / 2, 0.3833232646055, 0.2497451268005),
  QuadraturePoint(0.0062014513591 / 2, 0.8876850353557, 0.1035328809446),
  QuadraturePoint(0.0062014531952 / 2, 0.1035329228297, 0.8876849931840),
  QuadraturePoint(0.0069636330294 / 2, 0.0077255923618, 0.1403190991974),
  QuadraturePoint(0.0069636331842 / 2, 0.1403192425107, 0.0077255934624),
  QuadraturePoint(0.0075066257720 / 2, 0.8104591009652, 0.1809642523926),
  QuadraturePoint(0.0075066264565 / 2, 0.1809643003717, 0.8104590515334),
  QuadraturePoint(0.0079074768339 / 2, 0.8330767948684, 0.0083010939677),
  QuadraturePoint(0.0079074772485 / 2, 0.0083010907126, 0.8330768545392),
  QuadraturePoint(0.0080353344623 / 2, 0.0348407706147, 0.0348406969482),
  QuadraturePoint(0.0087963441074 / 2, 0.2740287679608, 0.7173981847948),
  QuadraturePoint(0.0087963448112 / 2, 0.7173982224778, 0.2740287304386),
  QuadraturePoint(0.0091304195716 / 2, 0.2394976858234, 0.0081859182262),
  QuadraturePoint(0.0091304213611 / 2, 0.0081859185845, 0.2394975566677),
  QuadraturePoint(0.0092821748751 / 2, 0.0068836152075, 0.4843740892687),
  QuadraturePoint(0.0092821815662 / 2, 0.4843741485699, 0.0068836232949),
  QuadraturePoint(0.0094499806178 / 2, 0.4960767772741, 0.4960767529507),
  QuadraturePoint(0.0094627468484 / 2, 0.6112936776245, 0.3804323691239),
  QuadraturePoint(0.0094627485294 / 2, 0.3804323980345, 0.6112936466533),
  QuadraturePoint(0.0095555772285 / 2, 0.7303890713524, 0.0083987179701),
  QuadraturePoint(0.0095555792843 / 2, 0.0083987168639, 0.7303890895407),
  QuadraturePoint(0.0096138842488 / 2, 0.6128525675612, 0.0075475979695),
  QuadraturePoint(0.0096138846826 / 2, 0.0075475961037, 0.6128525484582),
  QuadraturePoint(0.0099991524212 / 2, 0.0079525316513, 0.3559773826721),
  QuadraturePoint(0.0099991551850 / 2, 0.3559774870460, 0.0079525358502),
  QuadraturePoint(0.0100301319277 / 2, 0.9110236977966, 0.0437233665345),
  QuadraturePoint(0.0100301346636 / 2, 0.0437233605166, 0.9110236807446),
  QuadraturePoint(0.0124936676185 / 2, 0.0388480061835, 0.0967030908282),
  QuadraturePoint(0.0124936726125 / 2, 0.0967032117936, 0.0388479942386),
  QuadraturePoint(0.0140197309137 / 2, 0.0873226911312, 0.0873226620391),
  QuadraturePoint(0.0143336216896 / 2, 0.0421445202084, 0.8485617789108),
  QuadraturePoint(0.0143336272125 / 2, 0.8485617974961, 0.0421445420915),
  QuadraturePoint(0.0153604142740 / 2, 0.8477921333864, 0.1067435942472),
  QuadraturePoint(0.0153604183425 / 2, 0.1067435889398, 0.8477921328146),
  QuadraturePoint(0.0184523825614 / 2, 0.1833966521991, 0.0416340521608),
  QuadraturePoint(0.0184523863146 / 2, 0.0416340541167, 0.1833965196930),
  QuadraturePoint(0.0195833983573 / 2, 0.7611632251560, 0.1941599202852),
  QuadraturePoint(0.0195834019994 / 2, 0.1941599254144, 0.7611632153938),
  QuadraturePoint(0.0197632751342 / 2, 0.7579378747173, 0.0439826608586),
  QuadraturePoint(0.0197632766677 / 2, 0.0439826512395, 0.7579378242308),
  QuadraturePoint(0.0198806391019 / 2, 0.0369760535918, 0.5363186076436),
  QuadraturePoint(0.0198806485776 / 2, 0.5363187134342, 0.0369760780935),
  QuadraturePoint(0.0207181838484 / 2, 0.1001256948921, 0.7912267093545),
  QuadraturePoint(0.0207181934893 / 2, 0.7912266693524, 0.1001257554673),
  QuadraturePoint(0.0208943071440 / 2, 0.0379866714177, 0.4157413128558),
  QuadraturePoint(0.0208943251956 / 2, 0.4157414028965, 0.0379867061535),
  QuadraturePoint(0.0214864573885 / 2, 0.6507106491463, 0.0420141226713),
  QuadraturePoint(0.0214864586007 / 2, 0.0420141133438, 0.6507105645084),
  QuadraturePoint(0.0222218133036 / 2, 0.0425548444254, 0.2920626023484),
  QuadraturePoint(0.0222218160203 / 2, 0.2920627107240, 0.0425548546753),
  QuadraturePoint(0.0223345305455 / 2, 0.5389729538180, 0.4193031469005),
  QuadraturePoint(0.0223345378739 / 2, 0.4193031828489, 0.5389729093610),
  QuadraturePoint(0.0224758924946 / 2, 0.6549472009700, 0.3007352636162),
  QuadraturePoint(0.0224758980440 / 2, 0.3007352790917, 0.6549471812731),
  QuadraturePoint(0.0229701395845 / 2, 0.3752400771585, 0.3453980130752),
  QuadraturePoint(0.0229703394438 / 2, 0.3453980282786, 0.3752400695673),
  QuadraturePoint(0.0232798376102 / 2, 0.0994532168761, 0.1598308695187),
  QuadraturePoint(0.0232798427506 / 2, 0.1598309359585, 0.0994531960132),
  QuadraturePoint(0.0269483199647 / 2, 0.1797326661667, 0.7124585430924),
  QuadraturePoint(0.0269483307107 / 2, 0.7124584461943, 0.1797327722240),
  QuadraturePoint(0.0280438758010 / 2, 0.1066065678636, 0.7001701784175),
  QuadraturePoint(0.0280438764607 / 2, 0.7001701904096, 0.1066065855677),
  QuadraturePoint(0.0287526270172 / 2, 0.0993303629801, 0.6065647984796),
  QuadraturePoint(0.0287526387271 / 2, 0.6065648052521, 0.0993303896769),
  QuadraturePoint(0.0298980829063 / 2, 0.1023223542704, 0.2533381579528),
  QuadraturePoint(0.0298980922759 / 2, 0.2533382324938, 0.1023223826189),
  QuadraturePoint(0.0309004358516 / 2, 0.6166226715217, 0.2769502060575),
  QuadraturePoint(0.0309004385956 / 2, 0.2769500693109, 0.6166227900624),
  QuadraturePoint(0.0314031017088 / 2, 0.0904184571873, 0.4981522637001),
  QuadraturePoint(0.0314031073955 / 2, 0.4981522767248, 0.0904185045149),
  QuadraturePoint(0.0319191553024 / 2, 0.0928231860168, 0.3738418516908),
  QuadraturePoint(0.0319191668378 / 2, 0.3738418699229, 0.0928232584790),
  QuadraturePoint(0.0321429924062 / 2, 0.2521678840407, 0.2521680925697),
  QuadraturePoint(0.0330395601388 / 2, 0.5087500218708, 0.3905580544330),
  QuadraturePoint(0.0330395631829 / 2, 0.3905579116731, 0.5087501437661),
  QuadraturePoint(0.0356169095589 / 2, 0.1706141469096, 0.5266738039554),
  QuadraturePoint(0.0356169276054 / 2, 0.5266737761312, 0.1706142257537),
  QuadraturePoint(0.0365741189998 / 2, 0.3487581527629, 0.2588055084886),
  QuadraturePoint(0.0365741515204 / 2, 0.2588053596017, 0.3487583491703),
  QuadraturePoint(0.0365977646990 / 2, 0.1696614558053, 0.3013522183964),
  QuadraturePoint(0.0365978053889 / 2, 0.3013521806875, 0.1696615963219),
  QuadraturePoint(0.0369945680114 / 2, 0.2580202409759, 0.4584741774478),
  QuadraturePoint(0.0369945775059 / 2, 0.4584740860198, 0.2580203819011),
  QuadraturePoint(0.0374053623787 / 2, 0.1848898683498, 0.1848898704551),
  QuadraturePoint(0.0375550258317 / 2, 0.6130740338465, 0.1921611994069),
  QuadraturePoint(0.0375550312530 / 2, 0.1921611750994, 0.6130740398389),
  QuadraturePoint(0.0388887693486 / 2, 0.4180541160599, 0.1650613336416),
  QuadraturePoint(0.0388887708342 / 2, 0.1650612642036, 0.4180541199244),
  QuadraturePoint(0.0392705643548 / 2, 0.5159205739625, 0.2982719005229),
  QuadraturePoint(0.0392705802517 / 2, 0.2982718935750, 0.5159205534362),
  QuadraturePoint(0.0398766879831 / 2, 0.4098894602340, 0.4098894317792),
};
const QuadratureFormular QuadratureFormular_T_23(23, 105, P_QuadratureFormular_T_23);
static QuadraturePoint P_QuadratureFormular_T_25[] = {
  QuadraturePoint(0.0014873417859 / 2, 0.0082881595033, 0.9848202768869),
  QuadraturePoint(0.0014889035262 / 2, 0.4618422030241, 0.5381577969759),
  QuadraturePoint(0.0015005944380 / 2, 0.0071066441239, 0.0080842361390),
  QuadraturePoint(0.0015059208313 / 2, 0.9847613141699, 0.0070015755134),
  QuadraturePoint(0.0015318868715 / 2, 0.5374447869049, 0.4625552130951),
  QuadraturePoint(0.0023032634487 / 2, 0.0000000000000, 0.4887676880140),
  QuadraturePoint(0.0023649067042 / 2, 0.4914131929361, 0.0000000000000),
  QuadraturePoint(0.0028751143611 / 2, 0.0070345937020, 0.9574158053697),
  QuadraturePoint(0.0029862488735 / 2, 0.9564734714228, 0.0364655449485),
  QuadraturePoint(0.0030384162737 / 2, 0.0370198792045, 0.0070908577166),
  QuadraturePoint(0.0032092459688 / 2, 0.1024124542747, 0.8936125594937),
  QuadraturePoint(0.0037029598435 / 2, 0.5928065811509, 0.0049451705600),
  QuadraturePoint(0.0037407186035 / 2, 0.0050948422371, 0.0996676659189),
  QuadraturePoint(0.0038452543223 / 2, 0.0081562023689, 0.0415561148784),
  QuadraturePoint(0.0038670778668 / 2, 0.0424936107568, 0.9494865260352),
  QuadraturePoint(0.0039192555178 / 2, 0.9495543500844, 0.0081794507292),
  QuadraturePoint(0.0039573282688 / 2, 0.8932787471239, 0.0053224326262),
  QuadraturePoint(0.0044032251724 / 2, 0.0069317612927, 0.9065401020433),
  QuadraturePoint(0.0045907108173 / 2, 0.9035839030665, 0.0894771171077),
  QuadraturePoint(0.0047023669435 / 2, 0.0905665738209, 0.0070525342005),
  QuadraturePoint(0.0050014843818 / 2, 0.0083929332787, 0.6663179931111),
  QuadraturePoint(0.0052387830156 / 2, 0.6261245686071, 0.0092197583153),
  QuadraturePoint(0.0054422104092 / 2, 0.0062801592979, 0.8335207460527),
  QuadraturePoint(0.0056931248912 / 2, 0.8272539257367, 0.1665134939330),
  QuadraturePoint(0.0059107422989 / 2, 0.0062005875353, 0.7424693255229),
  QuadraturePoint(0.0059687967687 / 2, 0.1676900311185, 0.0065717743528),
  QuadraturePoint(0.0067262190287 / 2, 0.7199353069567, 0.0064354534962),
  QuadraturePoint(0.0068307848624 / 2, 0.2749740090237, 0.7185296120719),
  QuadraturePoint(0.0069531259112 / 2, 0.0079257582005, 0.1766411374714),
  QuadraturePoint(0.0072460270642 / 2, 0.0069981220752, 0.2704767254004),
  QuadraturePoint(0.0072728189613 / 2, 0.8125248773263, 0.0082299533210),
  QuadraturePoint(0.0073008930847 / 2, 0.0073536969970, 0.5934167875453),
  QuadraturePoint(0.0073604666776 / 2, 0.7283665935411, 0.2648817553752),
  QuadraturePoint(0.0074119923255 / 2, 0.1800642304565, 0.8115848976682),
  QuadraturePoint(0.0074892214336 / 2, 0.2658102467762, 0.0068553525429),
  QuadraturePoint(0.0078604067260 / 2, 0.0070892364520, 0.3757632659744),
  QuadraturePoint(0.0078621726423 / 2, 0.3774054302043, 0.6148573533757),
  QuadraturePoint(0.0080506361066 / 2, 0.0369649608668, 0.9210792302893),
  QuadraturePoint(0.0081442860473 / 2, 0.9203194109805, 0.0426025082114),
  QuadraturePoint(0.0081478804152 / 2, 0.0425477806431, 0.0372689941794),
  QuadraturePoint(0.0092444146612 / 2, 0.6191278394983, 0.3724055713809),
  QuadraturePoint(0.0094674635165 / 2, 0.3762697209178, 0.0081436422011),
  QuadraturePoint(0.0097132210137 / 2, 0.0956111149690, 0.8771098372601),
  QuadraturePoint(0.0099753581151 / 2, 0.0302473410377, 0.0943858903393),
  QuadraturePoint(0.0103367803673 / 2, 0.8739905691754, 0.0313198990883),
  QuadraturePoint(0.0112263277166 / 2, 0.8604133734958, 0.1049019782046),
  QuadraturePoint(0.0114309118745 / 2, 0.0347307852352, 0.8609856462886),
  QuadraturePoint(0.0115550567487 / 2, 0.1043606608343, 0.0357152881004),
  QuadraturePoint(0.0135575856957 / 2, 0.7797622824754, 0.1872318199265),
  QuadraturePoint(0.0135984962900 / 2, 0.0185865164256, 0.4834397678794),
  QuadraturePoint(0.0137754813837 / 2, 0.0324585286618, 0.7783474916042),
  QuadraturePoint(0.0137961015942 / 2, 0.8371293901157, 0.0804060570156),
  QuadraturePoint(0.0138408839904 / 2, 0.0836602075315, 0.8421414817051),
  QuadraturePoint(0.0140634019977 / 2, 0.0784070242501, 0.0849927089145),
  QuadraturePoint(0.0140991451009 / 2, 0.4929238648458, 0.4892855914710),
  QuadraturePoint(0.0142004111991 / 2, 0.1870637584073, 0.0345210858281),
  QuadraturePoint(0.0144518424517 / 2, 0.4892636967025, 0.0190774755077),
  QuadraturePoint(0.0150245979639 / 2, 0.0401982618372, 0.1691143187109),
  QuadraturePoint(0.0152817804122 / 2, 0.7894259278865, 0.0412206731484),
  QuadraturePoint(0.0155550724169 / 2, 0.1686260456429, 0.7894860640585),
  QuadraturePoint(0.0164570886000 / 2, 0.3750901913174, 0.5895318272013),
  QuadraturePoint(0.0165275759573 / 2, 0.0356362876880, 0.3681256217699),
  QuadraturePoint(0.0166847554451 / 2, 0.5887548164804, 0.0359968962541),
  QuadraturePoint(0.0167409312985 / 2, 0.0373308082182, 0.6790704673533),
  QuadraturePoint(0.0168674663361 / 2, 0.2820769993374, 0.0373639992361),
  QuadraturePoint(0.0168882230165 / 2, 0.6819277603320, 0.2803330345725),
  QuadraturePoint(0.0172087112691 / 2, 0.0374938324382, 0.2634016180014),
  QuadraturePoint(0.0174681068264 / 2, 0.6984079204127, 0.0364154673322),
  QuadraturePoint(0.0176663899614 / 2, 0.2654390894079, 0.6980717436193),
  QuadraturePoint(0.0182967621475 / 2, 0.1429848440800, 0.7612254618453),
  QuadraturePoint(0.0183576852459 / 2, 0.7623554007647, 0.0943741220275),
  QuadraturePoint(0.0186392569521 / 2, 0.0934222022749, 0.1479799836832),
  QuadraturePoint(0.0189781060590 / 2, 0.5759004479923, 0.3821329641698),
  QuadraturePoint(0.0191847922578 / 2, 0.3822427332525, 0.0426716362301),
  QuadraturePoint(0.0194080442044 / 2, 0.0411414081675, 0.5718082874432),
  QuadraturePoint(0.0194720072193 / 2, 0.0802462538379, 0.7702204382042),
  QuadraturePoint(0.0200855080495 / 2, 0.7625229819410, 0.1559420577362),
  QuadraturePoint(0.0201673909332 / 2, 0.1524941445131, 0.0842965421322),
  QuadraturePoint(0.0221742162761 / 2, 0.0622159195833, 0.4538181318873),
  QuadraturePoint(0.0229702440508 / 2, 0.1109539036076, 0.4586014071171),
  QuadraturePoint(0.0233465117399 / 2, 0.4575627212057, 0.4795313560210),
  QuadraturePoint(0.0234883135338 / 2, 0.4322865136374, 0.1230591237472),
  QuadraturePoint(0.0240682099018 / 2, 0.5865002850241, 0.0834119779793),
  QuadraturePoint(0.0240910792953 / 2, 0.0869359250818, 0.6755677013351),
  QuadraturePoint(0.0245677049481 / 2, 0.0929594906936, 0.2326500892727),
  QuadraturePoint(0.0246536315719 / 2, 0.6661932141454, 0.2448294007406),
  QuadraturePoint(0.0246756530052 / 2, 0.4780306362227, 0.0661749044835),
  QuadraturePoint(0.0249704602710 / 2, 0.4372215294577, 0.4442145585244),
  QuadraturePoint(0.0250026544082 / 2, 0.6779224504669, 0.0929096534577),
  QuadraturePoint(0.0250490869426 / 2, 0.2423431255660, 0.0889793655129),
  QuadraturePoint(0.0250936250125 / 2, 0.2288925420305, 0.6780053081672),
  QuadraturePoint(0.0251482076226 / 2, 0.3315065049959, 0.5847381559741),
  QuadraturePoint(0.0255010290447 / 2, 0.3424200526607, 0.5139245722736),
  QuadraturePoint(0.0256544511979 / 2, 0.0862630046475, 0.3340976249234),
  QuadraturePoint(0.0257974750630 / 2, 0.5113188946635, 0.1380154720554),
  QuadraturePoint(0.0270007753993 / 2, 0.1538977841001, 0.6788062619562),
  QuadraturePoint(0.0274431536844 / 2, 0.6779951348472, 0.1663358925269),
  QuadraturePoint(0.0277072401488 / 2, 0.1664600469411, 0.1582214504849),
  QuadraturePoint(0.0278284415364 / 2, 0.0950910318888, 0.5666590332543),
  QuadraturePoint(0.0287207381105 / 2, 0.3436048136712, 0.0978960873457),
  QuadraturePoint(0.0288826834956 / 2, 0.5560417025366, 0.3468917820947),
  QuadraturePoint(0.0293302729759 / 2, 0.1452404029513, 0.3599534491052),
  QuadraturePoint(0.0318902879557 / 2, 0.1619685156238, 0.5810131373330),
  QuadraturePoint(0.0319083660286 / 2, 0.5800164844262, 0.2560674640672),
  QuadraturePoint(0.0320938960329 / 2, 0.2450201223288, 0.5881469552102),
  QuadraturePoint(0.0321618608780 / 2, 0.2557621891794, 0.1652244065047),
  QuadraturePoint(0.0322424127534 / 2, 0.2205239985511, 0.3496507466106),
  QuadraturePoint(0.0327072446421 / 2, 0.4940183111285, 0.2549448448453),
  QuadraturePoint(0.0329946316695 / 2, 0.2531570689798, 0.2543369115017),
  QuadraturePoint(0.0331828096025 / 2, 0.5846891116357, 0.1666603916479),
  QuadraturePoint(0.0334857162651 / 2, 0.1660333602278, 0.2523240191705),
  QuadraturePoint(0.0335468472792 / 2, 0.2505426292461, 0.4959007627528),
  QuadraturePoint(0.0337049042988 / 2, 0.3519336802182, 0.1805380367800),
  QuadraturePoint(0.0340361462767 / 2, 0.3502668835419, 0.4358582329881),
  QuadraturePoint(0.0342465235323 / 2, 0.4400892485512, 0.2120576104941),
  QuadraturePoint(0.0345528817251 / 2, 0.4680855471546, 0.3552681570774),
  QuadraturePoint(0.0356782875703 / 2, 0.1770237763947, 0.4670352922266),
  QuadraturePoint(0.0364656225016 / 2, 0.3900920779501, 0.3323152819300),
  QuadraturePoint(0.0365172708706 / 2, 0.2805847774120, 0.3898041176680),
  QuadraturePoint(0.0371924811018 / 2, 0.3361523347440, 0.2778500044356),
};
const QuadratureFormular QuadratureFormular_T_25(25, 120, P_QuadratureFormular_T_25);

template< class Rd >
const GQuadratureFormular< Rd > *BuilQFd(const long &nex, const KNM_< double > &qf) {
  ffassert(qf.M( ) == Rd::d + 1);
  int np = qf.N( );
  GQuadraturePoint< Rd > *pq = new GQuadraturePoint< Rd >[np];

  for (int i = 0; i < np; ++i) {
    pq[i].a = qf(i, 0);

    for (int j = 0; j < Rd::d; ++j) {
      pq[i][j] = qf(i, j + 1);
    }
  }

  return new GQuadratureFormular< Rd >(nex, np, pq, true);
}

template< typename T >
T *CCopy(T *pr, T p) {
  *pr = p;
  return pr;
}

template< class Rd >
const GQuadratureFormular< Rd > **pBuilQFd(const GQuadratureFormular< Rd > **const &pr,
                                           const long &nex, const KNM_< double > &qf) {
  ffassert(pr);
  *pr = BuilQFd< Rd >(nex, qf);
  return pr;
}

// to add new FreeFem++ type ...

typedef GQuadraturePoint< R3 > PQP3;
typedef GQuadratureFormular< R3 > PQF3;

// QUAD QUAD_3D_P1_ = { 1 4

PQP3 QF_TET_P1[] = {
  PQP3(R3(0.25, 0.25, 0.25), 1.),    // 0 0
};
PQF3 const QuadratureFormular_Tet_P1(1, 1, QF_TET_P1);
// QUAD QUAD_3D_P2_ = { 4 16
PQP3 QF_TET_P2[] = {
  PQP3(R3(.13819660112501051517954131656343619, .13819660112501051517954131656343619,
          .13819660112501051517954131656343619),
       .25),    // 0 0
  PQP3(R3(1. - 3. * (.13819660112501051517954131656343619), .13819660112501051517954131656343619,
          .13819660112501051517954131656343619),
       .25),    // 1 4
  PQP3(R3(.13819660112501051517954131656343619, 1. - 3. * (.13819660112501051517954131656343619),
          .13819660112501051517954131656343619),
       .25),    // 2 8
  PQP3(R3(.13819660112501051517954131656343619, .13819660112501051517954131656343619,
          1. - 3. * (.13819660112501051517954131656343619)),
       .25),    // 3 12
};
PQF3 const QuadratureFormular_Tet_P2(2, 4, QF_TET_P2);
// QUAD QUAD_3D_P3_ = { 8 32
PQP3 QF_TET_P3[] = {
  PQP3(R3(.32805469671142664733580581998119743, .32805469671142664733580581998119743,
          .32805469671142664733580581998119743),
       .13852796651186214232361769837564129),    // 0 0
  PQP3(R3(1. - 3. * (.32805469671142664733580581998119743), .32805469671142664733580581998119743,
          .32805469671142664733580581998119743),
       .13852796651186214232361769837564129),    // 1 4
  PQP3(R3(.32805469671142664733580581998119743, 1. - 3. * (.32805469671142664733580581998119743),
          .32805469671142664733580581998119743),
       .13852796651186214232361769837564129),    // 2 8
  PQP3(R3(.32805469671142664733580581998119743, .32805469671142664733580581998119743,
          1. - 3. * (.32805469671142664733580581998119743)),
       .13852796651186214232361769837564129),    // 3 12
  PQP3(R3(.10695227393293068277170204157061650, .10695227393293068277170204157061650,
          .10695227393293068277170204157061650),
       .11147203348813785767638230162435871),    // 4 16
  PQP3(R3(1. - 3. * (.10695227393293068277170204157061650), .10695227393293068277170204157061650,
          .10695227393293068277170204157061650),
       .11147203348813785767638230162435871),    // 5 20
  PQP3(R3(.10695227393293068277170204157061650, 1. - 3. * (.10695227393293068277170204157061650),
          .10695227393293068277170204157061650),
       .11147203348813785767638230162435871),    // 6 24
  PQP3(R3(.10695227393293068277170204157061650, .10695227393293068277170204157061650,
          1. - 3. * (.10695227393293068277170204157061650)),
       .11147203348813785767638230162435871),    // 7 28
};
PQF3 const QuadratureFormular_Tet_P3(3, 8, QF_TET_P3);
// QUAD QUAD_3D_P4_ = { 14 56
PQP3 QF_TET_P4[] = {
  PQP3(R3(.09273525031089122628655892066032137, .09273525031089122628655892066032137,
          .09273525031089122628655892066032137),
       .07349304311636194934358694586367885),    // 0 0
  PQP3(R3(1. - 3. * (.09273525031089122628655892066032137), .09273525031089122628655892066032137,
          .09273525031089122628655892066032137),
       .07349304311636194934358694586367885),    // 1 4
  PQP3(R3(.09273525031089122628655892066032137, 1. - 3. * (.09273525031089122628655892066032137),
          .09273525031089122628655892066032137),
       .07349304311636194934358694586367885),    // 2 8
  PQP3(R3(.09273525031089122628655892066032137, .09273525031089122628655892066032137,
          1. - 3. * (.09273525031089122628655892066032137)),
       .07349304311636194934358694586367885),    // 3 12
  PQP3(R3(.31088591926330060975814749494040332, .31088591926330060975814749494040332,
          .31088591926330060975814749494040332),
       .11268792571801585036501492847638892),    // 4 16
  PQP3(R3(1. - 3. * (.31088591926330060975814749494040332), .31088591926330060975814749494040332,
          .31088591926330060975814749494040332),
       .11268792571801585036501492847638892),    // 5 20
  PQP3(R3(.31088591926330060975814749494040332, 1. - 3. * (.31088591926330060975814749494040332),
          .31088591926330060975814749494040332),
       .11268792571801585036501492847638892),    // 6 24
  PQP3(R3(.31088591926330060975814749494040332, .31088591926330060975814749494040332,
          1. - 3. * (.31088591926330060975814749494040332)),
       .11268792571801585036501492847638892),    // 7 28
  PQP3(R3(.04550370412564965000000000000000000, .5 - (.04550370412564965000000000000000000),
          .5 - (.04550370412564965000000000000000000)),
       .04254602077708146686093208377328816),    // 8 32
  PQP3(R3(.5 - (.04550370412564965000000000000000000), .04550370412564965000000000000000000,
          .5 - (.04550370412564965000000000000000000)),
       .04254602077708146686093208377328816),    // 9 36
  PQP3(R3(.5 - (.04550370412564965000000000000000000), .5 - (.04550370412564965000000000000000000),
          .04550370412564965000000000000000000),
       .04254602077708146686093208377328816),    // 10 40
  PQP3(R3(.04550370412564965000000000000000000, .5 - (.04550370412564965000000000000000000),
          .04550370412564965000000000000000000),
       .04254602077708146686093208377328816),    // 11 44
  PQP3(R3(.04550370412564965000000000000000000, .04550370412564965000000000000000000,
          .5 - (.04550370412564965000000000000000000)),
       .04254602077708146686093208377328816),    // 12 48
  PQP3(R3(.5 - (.04550370412564965000000000000000000), .04550370412564965000000000000000000,
          .04550370412564965000000000000000000),
       .04254602077708146686093208377328816),    // 13 52
};
PQF3 const QuadratureFormular_Tet_P4(4, 14, QF_TET_P4);
// QUAD QUAD_3D_P5_ = { 14 56
PQP3 QF_TET_P5[] = {
  PQP3(R3(.31088591926330060979734573376345783, .31088591926330060979734573376345783,
          .31088591926330060979734573376345783),
       .11268792571801585079918565233328633),    // 0 0
  PQP3(R3(1. - 3. * (.31088591926330060979734573376345783), .31088591926330060979734573376345783,
          .31088591926330060979734573376345783),
       .11268792571801585079918565233328633),    // 1 4
  PQP3(R3(.31088591926330060979734573376345783, 1. - 3. * (.31088591926330060979734573376345783),
          .31088591926330060979734573376345783),
       .11268792571801585079918565233328633),    // 2 8
  PQP3(R3(.31088591926330060979734573376345783, .31088591926330060979734573376345783,
          1. - 3. * (.31088591926330060979734573376345783)),
       .11268792571801585079918565233328633),    // 3 12
  PQP3(R3(.09273525031089122640232391373703061, .09273525031089122640232391373703061,
          .09273525031089122640232391373703061),
       .07349304311636194954371020548632750),    // 4 16
  PQP3(R3(1. - 3. * (.09273525031089122640232391373703061), .09273525031089122640232391373703061,
          .09273525031089122640232391373703061),
       .07349304311636194954371020548632750),    // 5 20
  PQP3(R3(.09273525031089122640232391373703061, 1. - 3. * (.09273525031089122640232391373703061),
          .09273525031089122640232391373703061),
       .07349304311636194954371020548632750),    // 6 24
  PQP3(R3(.09273525031089122640232391373703061, .09273525031089122640232391373703061,
          1. - 3. * (.09273525031089122640232391373703061)),
       .07349304311636194954371020548632750),    // 7 28
  PQP3(R3(.04550370412564964949188052627933943, .5 - (.04550370412564964949188052627933943),
          .5 - (.04550370412564964949188052627933943)),
       .04254602077708146643806942812025744),    // 8 32
  PQP3(R3(.5 - (.04550370412564964949188052627933943), .04550370412564964949188052627933943,
          .5 - (.04550370412564964949188052627933943)),
       .04254602077708146643806942812025744),    // 9 36
  PQP3(R3(.5 - (.04550370412564964949188052627933943), .5 - (.04550370412564964949188052627933943),
          .04550370412564964949188052627933943),
       .04254602077708146643806942812025744),    // 10 40
  PQP3(R3(.04550370412564964949188052627933943, .5 - (.04550370412564964949188052627933943),
          .04550370412564964949188052627933943),
       .04254602077708146643806942812025744),    // 11 44
  PQP3(R3(.04550370412564964949188052627933943, .04550370412564964949188052627933943,
          .5 - (.04550370412564964949188052627933943)),
       .04254602077708146643806942812025744),    // 12 48
  PQP3(R3(.5 - (.04550370412564964949188052627933943), .04550370412564964949188052627933943,
          .04550370412564964949188052627933943),
       .04254602077708146643806942812025744),    // 13 52
};
PQF3 const QuadratureFormular_Tet_P5(5, 14, QF_TET_P5);
// QUAD QUAD_3D_P6_ = { 24 96
PQP3 QF_TET_P6[] = {
  PQP3(R3(.21460287125915202928883921938628499, .21460287125915202928883921938628499,
          .21460287125915202928883921938628499),
       .03992275025816749209969062755747998),    // 0 0
  PQP3(R3(1. - 3. * (.21460287125915202928883921938628499), .21460287125915202928883921938628499,
          .21460287125915202928883921938628499),
       .03992275025816749209969062755747998),    // 1 4
  PQP3(R3(.21460287125915202928883921938628499, 1. - 3. * (.21460287125915202928883921938628499),
          .21460287125915202928883921938628499),
       .03992275025816749209969062755747998),    // 2 8
  PQP3(R3(.21460287125915202928883921938628499, .21460287125915202928883921938628499,
          1. - 3. * (.21460287125915202928883921938628499)),
       .03992275025816749209969062755747998),    // 3 12
  PQP3(R3(.04067395853461135311557944895641006, .04067395853461135311557944895641006,
          .04067395853461135311557944895641006),
       .01007721105532064294801323744593686),    // 4 16
  PQP3(R3(1. - 3. * (.04067395853461135311557944895641006), .04067395853461135311557944895641006,
          .04067395853461135311557944895641006),
       .01007721105532064294801323744593686),    // 5 20
  PQP3(R3(.04067395853461135311557944895641006, 1. - 3. * (.04067395853461135311557944895641006),
          .04067395853461135311557944895641006),
       .01007721105532064294801323744593686),    // 6 24
  PQP3(R3(.04067395853461135311557944895641006, .04067395853461135311557944895641006,
          1. - 3. * (.04067395853461135311557944895641006)),
       .01007721105532064294801323744593686),    // 7 28
  PQP3(R3(.32233789014227551034399447076249213, .32233789014227551034399447076249213,
          .32233789014227551034399447076249213),
       .05535718154365472209515327785372602),    // 8 32
  PQP3(R3(1. - 3. * (.32233789014227551034399447076249213), .32233789014227551034399447076249213,
          .32233789014227551034399447076249213),
       .05535718154365472209515327785372602),    // 9 36
  PQP3(R3(.32233789014227551034399447076249213, 1. - 3. * (.32233789014227551034399447076249213),
          .32233789014227551034399447076249213),
       .05535718154365472209515327785372602),    // 10 40
  PQP3(R3(.32233789014227551034399447076249213, .32233789014227551034399447076249213,
          1. - 3. * (.32233789014227551034399447076249213)),
       .05535718154365472209515327785372602),    // 11 44
  PQP3(R3(.06366100187501752529923552760572698, .60300566479164914136743113906093969,
          1. - (.06366100187501752529923552760572698) - (.06366100187501752529923552760572698) -
            (.60300566479164914136743113906093969)),
       27. / 560.),    // 12 48
  PQP3(R3(.06366100187501752529923552760572698,
          1. - (.06366100187501752529923552760572698) - (.06366100187501752529923552760572698) -
            (.60300566479164914136743113906093969),
          .60300566479164914136743113906093969),
       27. / 560.),    // 13 52
  PQP3(R3(.60300566479164914136743113906093969, .06366100187501752529923552760572698,
          1. - (.06366100187501752529923552760572698) - (.06366100187501752529923552760572698) -
            (.60300566479164914136743113906093969)),
       27. / 560.),    // 14 56
  PQP3(R3(.60300566479164914136743113906093969,
          1. - (.06366100187501752529923552760572698) - (.06366100187501752529923552760572698) -
            (.60300566479164914136743113906093969),
          .06366100187501752529923552760572698),
       27. / 560.),    // 15 60
  PQP3(R3(1. - (.06366100187501752529923552760572698) - (.06366100187501752529923552760572698) -
            (.60300566479164914136743113906093969),
          .06366100187501752529923552760572698, .60300566479164914136743113906093969),
       27. / 560.),    // 16 64
  PQP3(R3(1. - (.06366100187501752529923552760572698) - (.06366100187501752529923552760572698) -
            (.60300566479164914136743113906093969),
          .60300566479164914136743113906093969, .06366100187501752529923552760572698),
       27. / 560.),    // 17 68
  PQP3(R3(.06366100187501752529923552760572698, .06366100187501752529923552760572698,
          1. - (.06366100187501752529923552760572698) - (.06366100187501752529923552760572698) -
            (.60300566479164914136743113906093969)),
       27. / 560.),    // 18 72
  PQP3(R3(.06366100187501752529923552760572698,
          1. - (.06366100187501752529923552760572698) - (.06366100187501752529923552760572698) -
            (.60300566479164914136743113906093969),
          .06366100187501752529923552760572698),
       27. / 560.),    // 19 76
  PQP3(R3(1. - (.06366100187501752529923552760572698) - (.06366100187501752529923552760572698) -
            (.60300566479164914136743113906093969),
          .06366100187501752529923552760572698, .06366100187501752529923552760572698),
       27. / 560.),    // 20 80
  PQP3(R3(.06366100187501752529923552760572698, .06366100187501752529923552760572698,
          .60300566479164914136743113906093969),
       27. / 560.),    // 21 84
  PQP3(R3(.06366100187501752529923552760572698, .60300566479164914136743113906093969,
          .06366100187501752529923552760572698),
       27. / 560.),    // 22 88
  PQP3(R3(.60300566479164914136743113906093969, .06366100187501752529923552760572698,
          .06366100187501752529923552760572698),
       27. / 560.),    // 23 92
};
PQF3 const QuadratureFormular_Tet_P6(6, 24, QF_TET_P6);
// QUAD QUAD_3D_P7_ = { 35 140
PQP3 QF_TET_P7[] = {
  PQP3(R3(0.25, 0.25, 0.25), .09548528946413084886057843611722638),    // 0 0
  PQP3(R3(.31570114977820279942342999959331149, .31570114977820279942342999959331149,
          .31570114977820279942342999959331149),
       .04232958120996702907628617079854674),    // 1 4
  PQP3(R3(1. - 3. * (.31570114977820279942342999959331149), .31570114977820279942342999959331149,
          .31570114977820279942342999959331149),
       .04232958120996702907628617079854674),    // 2 8
  PQP3(R3(.31570114977820279942342999959331149, 1. - 3. * (.31570114977820279942342999959331149),
          .31570114977820279942342999959331149),
       .04232958120996702907628617079854674),    // 3 12
  PQP3(R3(.31570114977820279942342999959331149, .31570114977820279942342999959331149,
          1. - 3. * (.31570114977820279942342999959331149)),
       .04232958120996702907628617079854674),    // 4 16
  PQP3(R3(.05048982259839636876305382298656247, .5 - (.05048982259839636876305382298656247),
          .5 - (.05048982259839636876305382298656247)),
       .03189692783285757993427482408294246),    // 5 20
  PQP3(R3(.5 - (.05048982259839636876305382298656247), .05048982259839636876305382298656247,
          .5 - (.05048982259839636876305382298656247)),
       .03189692783285757993427482408294246),    // 6 24
  PQP3(R3(.5 - (.05048982259839636876305382298656247), .5 - (.05048982259839636876305382298656247),
          .05048982259839636876305382298656247),
       .03189692783285757993427482408294246),    // 7 28
  PQP3(R3(.05048982259839636876305382298656247, .5 - (.05048982259839636876305382298656247),
          .05048982259839636876305382298656247),
       .03189692783285757993427482408294246),    // 8 32
  PQP3(R3(.05048982259839636876305382298656247, .05048982259839636876305382298656247,
          .5 - (.05048982259839636876305382298656247)),
       .03189692783285757993427482408294246),    // 9 36
  PQP3(R3(.5 - (.05048982259839636876305382298656247), .05048982259839636876305382298656247,
          .05048982259839636876305382298656247),
       .03189692783285757993427482408294246),    // 10 40
  PQP3(R3(.18883383102600104773643110385458576, .57517163758700002348324157702230752,
          1. - (.18883383102600104773643110385458576) - (.18883383102600104773643110385458576) -
            (.57517163758700002348324157702230752)),
       .03720713072833462136961556119148112),    // 11 44
  PQP3(R3(.18883383102600104773643110385458576,
          1. - (.18883383102600104773643110385458576) - (.18883383102600104773643110385458576) -
            (.57517163758700002348324157702230752),
          .57517163758700002348324157702230752),
       .03720713072833462136961556119148112),    // 12 48
  PQP3(R3(.57517163758700002348324157702230752, .18883383102600104773643110385458576,
          1. - (.18883383102600104773643110385458576) - (.18883383102600104773643110385458576) -
            (.57517163758700002348324157702230752)),
       .03720713072833462136961556119148112),    // 13 52
  PQP3(R3(.57517163758700002348324157702230752,
          1. - (.18883383102600104773643110385458576) - (.18883383102600104773643110385458576) -
            (.57517163758700002348324157702230752),
          .18883383102600104773643110385458576),
       .03720713072833462136961556119148112),    // 14 56
  PQP3(R3(1. - (.18883383102600104773643110385458576) - (.18883383102600104773643110385458576) -
            (.57517163758700002348324157702230752),
          .18883383102600104773643110385458576, .57517163758700002348324157702230752),
       .03720713072833462136961556119148112),    // 15 60
  PQP3(R3(1. - (.18883383102600104773643110385458576) - (.18883383102600104773643110385458576) -
            (.57517163758700002348324157702230752),
          .57517163758700002348324157702230752, .18883383102600104773643110385458576),
       .03720713072833462136961556119148112),    // 16 64
  PQP3(R3(.18883383102600104773643110385458576, .18883383102600104773643110385458576,
          1. - (.18883383102600104773643110385458576) - (.18883383102600104773643110385458576) -
            (.57517163758700002348324157702230752)),
       .03720713072833462136961556119148112),    // 17 68
  PQP3(R3(.18883383102600104773643110385458576,
          1. - (.18883383102600104773643110385458576) - (.18883383102600104773643110385458576) -
            (.57517163758700002348324157702230752),
          .18883383102600104773643110385458576),
       .03720713072833462136961556119148112),    // 18 72
  PQP3(R3(1. - (.18883383102600104773643110385458576) - (.18883383102600104773643110385458576) -
            (.57517163758700002348324157702230752),
          .18883383102600104773643110385458576, .18883383102600104773643110385458576),
       .03720713072833462136961556119148112),    // 19 76
  PQP3(R3(.18883383102600104773643110385458576, .18883383102600104773643110385458576,
          .57517163758700002348324157702230752),
       .03720713072833462136961556119148112),    // 20 80
  PQP3(R3(.18883383102600104773643110385458576, .57517163758700002348324157702230752,
          .18883383102600104773643110385458576),
       .03720713072833462136961556119148112),    // 21 84
  PQP3(R3(.57517163758700002348324157702230752, .18883383102600104773643110385458576,
          .18883383102600104773643110385458576),
       .03720713072833462136961556119148112),    // 22 88
  PQP3(R3(.02126547254148324598883610149981994, .81083024109854856111810537984823239,
          1. - (.02126547254148324598883610149981994) - (.02126547254148324598883610149981994) -
            (.81083024109854856111810537984823239)),
       .00811077082990334156610343349109654),    // 23 92
  PQP3(R3(.02126547254148324598883610149981994,
          1. - (.02126547254148324598883610149981994) - (.02126547254148324598883610149981994) -
            (.81083024109854856111810537984823239),
          .81083024109854856111810537984823239),
       .00811077082990334156610343349109654),    // 24 96
  PQP3(R3(.81083024109854856111810537984823239, .02126547254148324598883610149981994,
          1. - (.02126547254148324598883610149981994) - (.02126547254148324598883610149981994) -
            (.81083024109854856111810537984823239)),
       .00811077082990334156610343349109654),    // 25 100
  PQP3(R3(.81083024109854856111810537984823239,
          1. - (.02126547254148324598883610149981994) - (.02126547254148324598883610149981994) -
            (.81083024109854856111810537984823239),
          .02126547254148324598883610149981994),
       .00811077082990334156610343349109654),    // 26 104
  PQP3(R3(1. - (.02126547254148324598883610149981994) - (.02126547254148324598883610149981994) -
            (.81083024109854856111810537984823239),
          .02126547254148324598883610149981994, .81083024109854856111810537984823239),
       .00811077082990334156610343349109654),    // 27 108
  PQP3(R3(1. - (.02126547254148324598883610149981994) - (.02126547254148324598883610149981994) -
            (.81083024109854856111810537984823239),
          .81083024109854856111810537984823239, .02126547254148324598883610149981994),
       .00811077082990334156610343349109654),    // 28 112
  PQP3(R3(.02126547254148324598883610149981994, .02126547254148324598883610149981994,
          1. - (.02126547254148324598883610149981994) - (.02126547254148324598883610149981994) -
            (.81083024109854856111810537984823239)),
       .00811077082990334156610343349109654),    // 29 116
  PQP3(R3(.02126547254148324598883610149981994,
          1. - (.02126547254148324598883610149981994) - (.02126547254148324598883610149981994) -
            (.81083024109854856111810537984823239),
          .02126547254148324598883610149981994),
       .00811077082990334156610343349109654),    // 30 120
  PQP3(R3(1. - (.02126547254148324598883610149981994) - (.02126547254148324598883610149981994) -
            (.81083024109854856111810537984823239),
          .02126547254148324598883610149981994, .02126547254148324598883610149981994),
       .00811077082990334156610343349109654),    // 31 124
  PQP3(R3(.02126547254148324598883610149981994, .02126547254148324598883610149981994,
          .81083024109854856111810537984823239),
       .00811077082990334156610343349109654),    // 32 128
  PQP3(R3(.02126547254148324598883610149981994, .81083024109854856111810537984823239,
          .02126547254148324598883610149981994),
       .00811077082990334156610343349109654),    // 33 132
  PQP3(R3(.81083024109854856111810537984823239, .02126547254148324598883610149981994,
          .02126547254148324598883610149981994),
       .00811077082990334156610343349109654),    // 34 136
};
PQF3 const QuadratureFormular_Tet_P7(7, 35, QF_TET_P7);
// QUAD QUAD_3D_P8_ = { 46 184
PQP3 QF_TET_P8[] = {
  PQP3(R3(.03967542307038990126507132953938949, .03967542307038990126507132953938949,
          .03967542307038990126507132953938949),
       .00639714777990232132145142033517302),    // 0 0
  PQP3(R3(1. - 3. * (.03967542307038990126507132953938949), .03967542307038990126507132953938949,
          .03967542307038990126507132953938949),
       .00639714777990232132145142033517302),    // 1 4
  PQP3(R3(.03967542307038990126507132953938949, 1. - 3. * (.03967542307038990126507132953938949),
          .03967542307038990126507132953938949),
       .00639714777990232132145142033517302),    // 2 8
  PQP3(R3(.03967542307038990126507132953938949, .03967542307038990126507132953938949,
          1. - 3. * (.03967542307038990126507132953938949)),
       .00639714777990232132145142033517302),    // 3 12
  PQP3(R3(.31448780069809631378416056269714830, .31448780069809631378416056269714830,
          .31448780069809631378416056269714830),
       .04019044802096617248816115847981783),    // 4 16
  PQP3(R3(1. - 3. * (.31448780069809631378416056269714830), .31448780069809631378416056269714830,
          .31448780069809631378416056269714830),
       .04019044802096617248816115847981783),    // 5 20
  PQP3(R3(.31448780069809631378416056269714830, 1. - 3. * (.31448780069809631378416056269714830),
          .31448780069809631378416056269714830),
       .04019044802096617248816115847981783),    // 6 24
  PQP3(R3(.31448780069809631378416056269714830, .31448780069809631378416056269714830,
          1. - 3. * (.31448780069809631378416056269714830)),
       .04019044802096617248816115847981783),    // 7 28
  PQP3(R3(.10198669306270330000000000000000000, .10198669306270330000000000000000000,
          .10198669306270330000000000000000000),
       .02430797550477032117486910877192260),    // 8 32
  PQP3(R3(1. - 3. * (.10198669306270330000000000000000000), .10198669306270330000000000000000000,
          .10198669306270330000000000000000000),
       .02430797550477032117486910877192260),    // 9 36
  PQP3(R3(.10198669306270330000000000000000000, 1. - 3. * (.10198669306270330000000000000000000),
          .10198669306270330000000000000000000),
       .02430797550477032117486910877192260),    // 10 40
  PQP3(R3(.10198669306270330000000000000000000, .10198669306270330000000000000000000,
          1. - 3. * (.10198669306270330000000000000000000)),
       .02430797550477032117486910877192260),    // 11 44
  PQP3(R3(.18420369694919151227594641734890918, .18420369694919151227594641734890918,
          .18420369694919151227594641734890918),
       .05485889241369744046692412399039144),    // 12 48
  PQP3(R3(1. - 3. * (.18420369694919151227594641734890918), .18420369694919151227594641734890918,
          .18420369694919151227594641734890918),
       .05485889241369744046692412399039144),    // 13 52
  PQP3(R3(.18420369694919151227594641734890918, 1. - 3. * (.18420369694919151227594641734890918),
          .18420369694919151227594641734890918),
       .05485889241369744046692412399039144),    // 14 56
  PQP3(R3(.18420369694919151227594641734890918, .18420369694919151227594641734890918,
          1. - 3. * (.18420369694919151227594641734890918)),
       .05485889241369744046692412399039144),    // 15 60
  PQP3(R3(.06343628775453989240514123870189827, .5 - (.06343628775453989240514123870189827),
          .5 - (.06343628775453989240514123870189827)),
       .03571961223409918246495096899661762),    // 16 64
  PQP3(R3(.5 - (.06343628775453989240514123870189827), .06343628775453989240514123870189827,
          .5 - (.06343628775453989240514123870189827)),
       .03571961223409918246495096899661762),    // 17 68
  PQP3(R3(.5 - (.06343628775453989240514123870189827), .5 - (.06343628775453989240514123870189827),
          .06343628775453989240514123870189827),
       .03571961223409918246495096899661762),    // 18 72
  PQP3(R3(.06343628775453989240514123870189827, .5 - (.06343628775453989240514123870189827),
          .06343628775453989240514123870189827),
       .03571961223409918246495096899661762),    // 19 76
  PQP3(R3(.06343628775453989240514123870189827, .06343628775453989240514123870189827,
          .5 - (.06343628775453989240514123870189827)),
       .03571961223409918246495096899661762),    // 20 80
  PQP3(R3(.5 - (.06343628775453989240514123870189827), .06343628775453989240514123870189827,
          .06343628775453989240514123870189827),
       .03571961223409918246495096899661762),    // 21 84
  PQP3(R3(.02169016206772800480266248262493018, .71993192203946593588943495335273478,
          1. - (.02169016206772800480266248262493018) - (.02169016206772800480266248262493018) -
            (.71993192203946593588943495335273478)),
       .00718319069785253940945110521980376),    // 22 88
  PQP3(R3(.02169016206772800480266248262493018,
          1. - (.02169016206772800480266248262493018) - (.02169016206772800480266248262493018) -
            (.71993192203946593588943495335273478),
          .71993192203946593588943495335273478),
       .00718319069785253940945110521980376),    // 23 92
  PQP3(R3(.71993192203946593588943495335273478, .02169016206772800480266248262493018,
          1. - (.02169016206772800480266248262493018) - (.02169016206772800480266248262493018) -
            (.71993192203946593588943495335273478)),
       .00718319069785253940945110521980376),    // 24 96
  PQP3(R3(.71993192203946593588943495335273478,
          1. - (.02169016206772800480266248262493018) - (.02169016206772800480266248262493018) -
            (.71993192203946593588943495335273478),
          .02169016206772800480266248262493018),
       .00718319069785253940945110521980376),    // 25 100
  PQP3(R3(1. - (.02169016206772800480266248262493018) - (.02169016206772800480266248262493018) -
            (.71993192203946593588943495335273478),
          .02169016206772800480266248262493018, .71993192203946593588943495335273478),
       .00718319069785253940945110521980376),    // 26 104
  PQP3(R3(1. - (.02169016206772800480266248262493018) - (.02169016206772800480266248262493018) -
            (.71993192203946593588943495335273478),
          .71993192203946593588943495335273478, .02169016206772800480266248262493018),
       .00718319069785253940945110521980376),    // 27 108
  PQP3(R3(.02169016206772800480266248262493018, .02169016206772800480266248262493018,
          1. - (.02169016206772800480266248262493018) - (.02169016206772800480266248262493018) -
            (.71993192203946593588943495335273478)),
       .00718319069785253940945110521980376),    // 28 112
  PQP3(R3(.02169016206772800480266248262493018,
          1. - (.02169016206772800480266248262493018) - (.02169016206772800480266248262493018) -
            (.71993192203946593588943495335273478),
          .02169016206772800480266248262493018),
       .00718319069785253940945110521980376),    // 29 116
  PQP3(R3(1. - (.02169016206772800480266248262493018) - (.02169016206772800480266248262493018) -
            (.71993192203946593588943495335273478),
          .02169016206772800480266248262493018, .02169016206772800480266248262493018),
       .00718319069785253940945110521980376),    // 30 120
  PQP3(R3(.02169016206772800480266248262493018, .02169016206772800480266248262493018,
          .71993192203946593588943495335273478),
       .00718319069785253940945110521980376),    // 31 124
  PQP3(R3(.02169016206772800480266248262493018, .71993192203946593588943495335273478,
          .02169016206772800480266248262493018),
       .00718319069785253940945110521980376),    // 32 128
  PQP3(R3(.71993192203946593588943495335273478, .02169016206772800480266248262493018,
          .02169016206772800480266248262493018),
       .00718319069785253940945110521980376),    // 33 132
  PQP3(R3(.20448008063679571424133557487274534, .58057719012880922417539817139062041,
          1. - (.20448008063679571424133557487274534) - (.20448008063679571424133557487274534) -
            (.58057719012880922417539817139062041)),
       .01637218194531911754093813975611913),    // 34 136
  PQP3(R3(.20448008063679571424133557487274534,
          1. - (.20448008063679571424133557487274534) - (.20448008063679571424133557487274534) -
            (.58057719012880922417539817139062041),
          .58057719012880922417539817139062041),
       .01637218194531911754093813975611913),    // 35 140
  PQP3(R3(.58057719012880922417539817139062041, .20448008063679571424133557487274534,
          1. - (.20448008063679571424133557487274534) - (.20448008063679571424133557487274534) -
            (.58057719012880922417539817139062041)),
       .01637218194531911754093813975611913),    // 36 144
  PQP3(R3(.58057719012880922417539817139062041,
          1. - (.20448008063679571424133557487274534) - (.20448008063679571424133557487274534) -
            (.58057719012880922417539817139062041),
          .20448008063679571424133557487274534),
       .01637218194531911754093813975611913),    // 37 148
  PQP3(R3(1. - (.20448008063679571424133557487274534) - (.20448008063679571424133557487274534) -
            (.58057719012880922417539817139062041),
          .20448008063679571424133557487274534, .58057719012880922417539817139062041),
       .01637218194531911754093813975611913),    // 38 152
  PQP3(R3(1. - (.20448008063679571424133557487274534) - (.20448008063679571424133557487274534) -
            (.58057719012880922417539817139062041),
          .58057719012880922417539817139062041, .20448008063679571424133557487274534),
       .01637218194531911754093813975611913),    // 39 156
  PQP3(R3(.20448008063679571424133557487274534, .20448008063679571424133557487274534,
          1. - (.20448008063679571424133557487274534) - (.20448008063679571424133557487274534) -
            (.58057719012880922417539817139062041)),
       .01637218194531911754093813975611913),    // 40 160
  PQP3(R3(.20448008063679571424133557487274534,
          1. - (.20448008063679571424133557487274534) - (.20448008063679571424133557487274534) -
            (.58057719012880922417539817139062041),
          .20448008063679571424133557487274534),
       .01637218194531911754093813975611913),    // 41 164
  PQP3(R3(1. - (.20448008063679571424133557487274534) - (.20448008063679571424133557487274534) -
            (.58057719012880922417539817139062041),
          .20448008063679571424133557487274534, .20448008063679571424133557487274534),
       .01637218194531911754093813975611913),    // 42 168
  PQP3(R3(.20448008063679571424133557487274534, .20448008063679571424133557487274534,
          .58057719012880922417539817139062041),
       .01637218194531911754093813975611913),    // 43 172
  PQP3(R3(.20448008063679571424133557487274534, .58057719012880922417539817139062041,
          .20448008063679571424133557487274534),
       .01637218194531911754093813975611913),    // 44 176
  PQP3(R3(.58057719012880922417539817139062041, .20448008063679571424133557487274534,
          .20448008063679571424133557487274534),
       .01637218194531911754093813975611913),    // 45 180
};
PQF3 const QuadratureFormular_Tet_P8(8, 46, QF_TET_P8);
// QUAD QUAD_3D_P9_ = { 59 236
PQP3 QF_TET_P9[] = {
  PQP3(R3(0.25, 0.25, 0.25), .05489853459364812686895885032391298),    // 0 0
  PQP3(R3(.03785502061999503609086515586175707, .03785502061999503609086515586175707,
          .03785502061999503609086515586175707),
       .00421825735654367356185795185819147),    // 1 4
  PQP3(R3(1. - 3. * (.03785502061999503609086515586175707), .03785502061999503609086515586175707,
          .03785502061999503609086515586175707),
       .00421825735654367356185795185819147),    // 2 8
  PQP3(R3(.03785502061999503609086515586175707, 1. - 3. * (.03785502061999503609086515586175707),
          .03785502061999503609086515586175707),
       .00421825735654367356185795185819147),    // 3 12
  PQP3(R3(.03785502061999503609086515586175707, .03785502061999503609086515586175707,
          1. - 3. * (.03785502061999503609086515586175707)),
       .00421825735654367356185795185819147),    // 4 16
  PQP3(R3(.16954439965012220000000000000000000, .16954439965012220000000000000000000,
          .16954439965012220000000000000000000),
       .02348412311384798927791501022996111),    // 5 20
  PQP3(R3(1. - 3. * (.16954439965012220000000000000000000), .16954439965012220000000000000000000,
          .16954439965012220000000000000000000),
       .02348412311384798927791501022996111),    // 6 24
  PQP3(R3(.16954439965012220000000000000000000, 1. - 3. * (.16954439965012220000000000000000000),
          .16954439965012220000000000000000000),
       .02348412311384798927791501022996111),    // 7 28
  PQP3(R3(.16954439965012220000000000000000000, .16954439965012220000000000000000000,
          1. - 3. * (.16954439965012220000000000000000000)),
       .02348412311384798927791501022996111),    // 8 32
  PQP3(R3(.05484140424416689000000000000000000, .05484140424416689000000000000000000,
          .05484140424416689000000000000000000),
       .00421283454980389148648831814037819),    // 9 36
  PQP3(R3(1. - 3. * (.05484140424416689000000000000000000), .05484140424416689000000000000000000,
          .05484140424416689000000000000000000),
       .00421283454980389148648831814037819),    // 10 40
  PQP3(R3(.05484140424416689000000000000000000, 1. - 3. * (.05484140424416689000000000000000000),
          .05484140424416689000000000000000000),
       .00421283454980389148648831814037819),    // 11 44
  PQP3(R3(.05484140424416689000000000000000000, .05484140424416689000000000000000000,
          1. - 3. * (.05484140424416689000000000000000000)),
       .00421283454980389148648831814037819),    // 12 48
  PQP3(R3(.32229717190921058836777748445908171, .32229717190921058836777748445908171,
          .32229717190921058836777748445908171),
       .02994712640542812769203037546126163),    // 13 52
  PQP3(R3(1. - 3. * (.32229717190921058836777748445908171), .32229717190921058836777748445908171,
          .32229717190921058836777748445908171),
       .02994712640542812769203037546126163),    // 14 56
  PQP3(R3(.32229717190921058836777748445908171, 1. - 3. * (.32229717190921058836777748445908171),
          .32229717190921058836777748445908171),
       .02994712640542812769203037546126163),    // 15 60
  PQP3(R3(.32229717190921058836777748445908171, .32229717190921058836777748445908171,
          1. - 3. * (.32229717190921058836777748445908171)),
       .02994712640542812769203037546126163),    // 16 64
  PQP3(R3(.10961777508972033704050355954365052, .5 - (.10961777508972033704050355954365052),
          .5 - (.10961777508972033704050355954365052)),
       .03695441750679136335292416138761121),    // 17 68
  PQP3(R3(.5 - (.10961777508972033704050355954365052), .10961777508972033704050355954365052,
          .5 - (.10961777508972033704050355954365052)),
       .03695441750679136335292416138761121),    // 18 72
  PQP3(R3(.5 - (.10961777508972033704050355954365052), .5 - (.10961777508972033704050355954365052),
          .10961777508972033704050355954365052),
       .03695441750679136335292416138761121),    // 19 76
  PQP3(R3(.10961777508972033704050355954365052, .5 - (.10961777508972033704050355954365052),
          .10961777508972033704050355954365052),
       .03695441750679136335292416138761121),    // 20 80
  PQP3(R3(.10961777508972033704050355954365052, .10961777508972033704050355954365052,
          .5 - (.10961777508972033704050355954365052)),
       .03695441750679136335292416138761121),    // 21 84
  PQP3(R3(.5 - (.10961777508972033704050355954365052), .10961777508972033704050355954365052,
          .10961777508972033704050355954365052),
       .03695441750679136335292416138761121),    // 22 88
  PQP3(R3(.45915766038590539763886410168178216, .08004485927247373376034330857923567,
          1. - (.45915766038590539763886410168178216) - (.45915766038590539763886410168178216) -
            (.08004485927247373376034330857923567)),
       .00817349224171051348425319650294732),    // 23 92
  PQP3(R3(.45915766038590539763886410168178216,
          1. - (.45915766038590539763886410168178216) - (.45915766038590539763886410168178216) -
            (.08004485927247373376034330857923567),
          .08004485927247373376034330857923567),
       .00817349224171051348425319650294732),    // 24 96
  PQP3(R3(.08004485927247373376034330857923567, .45915766038590539763886410168178216,
          1. - (.45915766038590539763886410168178216) - (.45915766038590539763886410168178216) -
            (.08004485927247373376034330857923567)),
       .00817349224171051348425319650294732),    // 25 100
  PQP3(R3(.08004485927247373376034330857923567,
          1. - (.45915766038590539763886410168178216) - (.45915766038590539763886410168178216) -
            (.08004485927247373376034330857923567),
          .45915766038590539763886410168178216),
       .00817349224171051348425319650294732),    // 26 104
  PQP3(R3(1. - (.45915766038590539763886410168178216) - (.45915766038590539763886410168178216) -
            (.08004485927247373376034330857923567),
          .45915766038590539763886410168178216, .08004485927247373376034330857923567),
       .00817349224171051348425319650294732),    // 27 108
  PQP3(R3(1. - (.45915766038590539763886410168178216) - (.45915766038590539763886410168178216) -
            (.08004485927247373376034330857923567),
          .08004485927247373376034330857923567, .45915766038590539763886410168178216),
       .00817349224171051348425319650294732),    // 28 112
  PQP3(R3(.45915766038590539763886410168178216, .45915766038590539763886410168178216,
          1. - (.45915766038590539763886410168178216) - (.45915766038590539763886410168178216) -
            (.08004485927247373376034330857923567)),
       .00817349224171051348425319650294732),    // 29 116
  PQP3(R3(.45915766038590539763886410168178216,
          1. - (.45915766038590539763886410168178216) - (.45915766038590539763886410168178216) -
            (.08004485927247373376034330857923567),
          .45915766038590539763886410168178216),
       .00817349224171051348425319650294732),    // 30 120
  PQP3(R3(1. - (.45915766038590539763886410168178216) - (.45915766038590539763886410168178216) -
            (.08004485927247373376034330857923567),
          .45915766038590539763886410168178216, .45915766038590539763886410168178216),
       .00817349224171051348425319650294732),    // 31 124
  PQP3(R3(.45915766038590539763886410168178216, .45915766038590539763886410168178216,
          .08004485927247373376034330857923567),
       .00817349224171051348425319650294732),    // 32 128
  PQP3(R3(.45915766038590539763886410168178216, .08004485927247373376034330857923567,
          .45915766038590539763886410168178216),
       .00817349224171051348425319650294732),    // 33 132
  PQP3(R3(.08004485927247373376034330857923567, .45915766038590539763886410168178216,
          .45915766038590539763886410168178216),
       .00817349224171051348425319650294732),    // 34 136
  PQP3(R3(.03296694775357210169727386483414899, .71879584022434055051132299796383374,
          1. - (.03296694775357210169727386483414899) - (.03296694775357210169727386483414899) -
            (.71879584022434055051132299796383374)),
       .00987978656102278957913113314297149),    // 35 140
  PQP3(R3(.03296694775357210169727386483414899,
          1. - (.03296694775357210169727386483414899) - (.03296694775357210169727386483414899) -
            (.71879584022434055051132299796383374),
          .71879584022434055051132299796383374),
       .00987978656102278957913113314297149),    // 36 144
  PQP3(R3(.71879584022434055051132299796383374, .03296694775357210169727386483414899,
          1. - (.03296694775357210169727386483414899) - (.03296694775357210169727386483414899) -
            (.71879584022434055051132299796383374)),
       .00987978656102278957913113314297149),    // 37 148
  PQP3(R3(.71879584022434055051132299796383374,
          1. - (.03296694775357210169727386483414899) - (.03296694775357210169727386483414899) -
            (.71879584022434055051132299796383374),
          .03296694775357210169727386483414899),
       .00987978656102278957913113314297149),    // 38 152
  PQP3(R3(1. - (.03296694775357210169727386483414899) - (.03296694775357210169727386483414899) -
            (.71879584022434055051132299796383374),
          .03296694775357210169727386483414899, .71879584022434055051132299796383374),
       .00987978656102278957913113314297149),    // 39 156
  PQP3(R3(1. - (.03296694775357210169727386483414899) - (.03296694775357210169727386483414899) -
            (.71879584022434055051132299796383374),
          .71879584022434055051132299796383374, .03296694775357210169727386483414899),
       .00987978656102278957913113314297149),    // 40 160
  PQP3(R3(.03296694775357210169727386483414899, .03296694775357210169727386483414899,
          1. - (.03296694775357210169727386483414899) - (.03296694775357210169727386483414899) -
            (.71879584022434055051132299796383374)),
       .00987978656102278957913113314297149),    // 41 164
  PQP3(R3(.03296694775357210169727386483414899,
          1. - (.03296694775357210169727386483414899) - (.03296694775357210169727386483414899) -
            (.71879584022434055051132299796383374),
          .03296694775357210169727386483414899),
       .00987978656102278957913113314297149),    // 42 168
  PQP3(R3(1. - (.03296694775357210169727386483414899) - (.03296694775357210169727386483414899) -
            (.71879584022434055051132299796383374),
          .03296694775357210169727386483414899, .03296694775357210169727386483414899),
       .00987978656102278957913113314297149),    // 43 172
  PQP3(R3(.03296694775357210169727386483414899, .03296694775357210169727386483414899,
          .71879584022434055051132299796383374),
       .00987978656102278957913113314297149),    // 44 176
  PQP3(R3(.03296694775357210169727386483414899, .71879584022434055051132299796383374,
          .03296694775357210169727386483414899),
       .00987978656102278957913113314297149),    // 45 180
  PQP3(R3(.71879584022434055051132299796383374, .03296694775357210169727386483414899,
          .03296694775357210169727386483414899),
       .00987978656102278957913113314297149),    // 46 184
  PQP3(R3(.18174359672117481549870278661377760, .60023700739524674102301240348069459,
          1. - (.18174359672117481549870278661377760) - (.18174359672117481549870278661377760) -
            (.60023700739524674102301240348069459)),
       .02160718741919244401497646690335203),    // 47 188
  PQP3(R3(.18174359672117481549870278661377760,
          1. - (.18174359672117481549870278661377760) - (.18174359672117481549870278661377760) -
            (.60023700739524674102301240348069459),
          .60023700739524674102301240348069459),
       .02160718741919244401497646690335203),    // 48 192
  PQP3(R3(.60023700739524674102301240348069459, .18174359672117481549870278661377760,
          1. - (.18174359672117481549870278661377760) - (.18174359672117481549870278661377760) -
            (.60023700739524674102301240348069459)),
       .02160718741919244401497646690335203),    // 49 196
  PQP3(R3(.60023700739524674102301240348069459,
          1. - (.18174359672117481549870278661377760) - (.18174359672117481549870278661377760) -
            (.60023700739524674102301240348069459),
          .18174359672117481549870278661377760),
       .02160718741919244401497646690335203),    // 50 200
  PQP3(R3(1. - (.18174359672117481549870278661377760) - (.18174359672117481549870278661377760) -
            (.60023700739524674102301240348069459),
          .18174359672117481549870278661377760, .60023700739524674102301240348069459),
       .02160718741919244401497646690335203),    // 51 204
  PQP3(R3(1. - (.18174359672117481549870278661377760) - (.18174359672117481549870278661377760) -
            (.60023700739524674102301240348069459),
          .60023700739524674102301240348069459, .18174359672117481549870278661377760),
       .02160718741919244401497646690335203),    // 52 208
  PQP3(R3(.18174359672117481549870278661377760, .18174359672117481549870278661377760,
          1. - (.18174359672117481549870278661377760) - (.18174359672117481549870278661377760) -
            (.60023700739524674102301240348069459)),
       .02160718741919244401497646690335203),    // 53 212
  PQP3(R3(.18174359672117481549870278661377760,
          1. - (.18174359672117481549870278661377760) - (.18174359672117481549870278661377760) -
            (.60023700739524674102301240348069459),
          .18174359672117481549870278661377760),
       .02160718741919244401497646690335203),    // 54 216
  PQP3(R3(1. - (.18174359672117481549870278661377760) - (.18174359672117481549870278661377760) -
            (.60023700739524674102301240348069459),
          .18174359672117481549870278661377760, .18174359672117481549870278661377760),
       .02160718741919244401497646690335203),    // 55 220
  PQP3(R3(.18174359672117481549870278661377760, .18174359672117481549870278661377760,
          .60023700739524674102301240348069459),
       .02160718741919244401497646690335203),    // 56 224
  PQP3(R3(.18174359672117481549870278661377760, .60023700739524674102301240348069459,
          .18174359672117481549870278661377760),
       .02160718741919244401497646690335203),    // 57 228
  PQP3(R3(.60023700739524674102301240348069459, .18174359672117481549870278661377760,
          .18174359672117481549870278661377760),
       .02160718741919244401497646690335203),    // 58 232
};
PQF3 const QuadratureFormular_Tet_P9(9, 59, QF_TET_P9);
// QUAD QUAD_3D_P10_ = { 79 316
PQP3 QF_TET_P10[] = {
  PQP3(R3(0.25, 0.25, 0.25), .04574189830483037077884770618329337),    // 0 0
  PQP3(R3(.11425191803006935688146412277598412, .11425191803006935688146412277598412,
          .11425191803006935688146412277598412),
       .01092727610912416907498417206565671),    // 1 4
  PQP3(R3(1. - 3. * (.11425191803006935688146412277598412), .11425191803006935688146412277598412,
          .11425191803006935688146412277598412),
       .01092727610912416907498417206565671),    // 2 8
  PQP3(R3(.11425191803006935688146412277598412, 1. - 3. * (.11425191803006935688146412277598412),
          .11425191803006935688146412277598412),
       .01092727610912416907498417206565671),    // 3 12
  PQP3(R3(.11425191803006935688146412277598412, .11425191803006935688146412277598412,
          1. - 3. * (.11425191803006935688146412277598412)),
       .01092727610912416907498417206565671),    // 4 16
  PQP3(R3(.01063790234539248531264164411274776, .01063790234539248531264164411274776,
          .01063790234539248531264164411274776),
       .00055352334192264689534558564012282),    // 5 20
  PQP3(R3(1. - 3. * (.01063790234539248531264164411274776), .01063790234539248531264164411274776,
          .01063790234539248531264164411274776),
       .00055352334192264689534558564012282),    // 6 24
  PQP3(R3(.01063790234539248531264164411274776, 1. - 3. * (.01063790234539248531264164411274776),
          .01063790234539248531264164411274776),
       .00055352334192264689534558564012282),    // 7 28
  PQP3(R3(.01063790234539248531264164411274776, .01063790234539248531264164411274776,
          1. - 3. * (.01063790234539248531264164411274776)),
       .00055352334192264689534558564012282),    // 8 32
  PQP3(R3(.31274070833535645859816704980806110, .31274070833535645859816704980806110,
          .31274070833535645859816704980806110),
       .02569337913913269580782688316792080),    // 9 36
  PQP3(R3(1. - 3. * (.31274070833535645859816704980806110), .31274070833535645859816704980806110,
          .31274070833535645859816704980806110),
       .02569337913913269580782688316792080),    // 10 40
  PQP3(R3(.31274070833535645859816704980806110, 1. - 3. * (.31274070833535645859816704980806110),
          .31274070833535645859816704980806110),
       .02569337913913269580782688316792080),    // 11 44
  PQP3(R3(.31274070833535645859816704980806110, .31274070833535645859816704980806110,
          1. - 3. * (.31274070833535645859816704980806110)),
       .02569337913913269580782688316792080),    // 12 48
  PQP3(R3(.01631296303281644000000000000000000, .5 - (.01631296303281644000000000000000000),
          .5 - (.01631296303281644000000000000000000)),
       .00055387649657283109312967562590035),    // 13 52
  PQP3(R3(.5 - (.01631296303281644000000000000000000), .01631296303281644000000000000000000,
          .5 - (.01631296303281644000000000000000000)),
       .00055387649657283109312967562590035),    // 14 56
  PQP3(R3(.5 - (.01631296303281644000000000000000000), .5 - (.01631296303281644000000000000000000),
          .01631296303281644000000000000000000),
       .00055387649657283109312967562590035),    // 15 60
  PQP3(R3(.01631296303281644000000000000000000, .5 - (.01631296303281644000000000000000000),
          .01631296303281644000000000000000000),
       .00055387649657283109312967562590035),    // 16 64
  PQP3(R3(.01631296303281644000000000000000000, .01631296303281644000000000000000000,
          .5 - (.01631296303281644000000000000000000)),
       .00055387649657283109312967562590035),    // 17 68
  PQP3(R3(.5 - (.01631296303281644000000000000000000), .01631296303281644000000000000000000,
          .01631296303281644000000000000000000),
       .00055387649657283109312967562590035),    // 18 72
  PQP3(R3(.03430622963180452385835196582344460, .59830121060139461905983787517050400,
          1. - (.03430622963180452385835196582344460) - (.03430622963180452385835196582344460) -
            (.59830121060139461905983787517050400)),
       .01044842402938294329072628200105773),    // 19 76
  PQP3(R3(.03430622963180452385835196582344460,
          1. - (.03430622963180452385835196582344460) - (.03430622963180452385835196582344460) -
            (.59830121060139461905983787517050400),
          .59830121060139461905983787517050400),
       .01044842402938294329072628200105773),    // 20 80
  PQP3(R3(.59830121060139461905983787517050400, .03430622963180452385835196582344460,
          1. - (.03430622963180452385835196582344460) - (.03430622963180452385835196582344460) -
            (.59830121060139461905983787517050400)),
       .01044842402938294329072628200105773),    // 21 84
  PQP3(R3(.59830121060139461905983787517050400,
          1. - (.03430622963180452385835196582344460) - (.03430622963180452385835196582344460) -
            (.59830121060139461905983787517050400),
          .03430622963180452385835196582344460),
       .01044842402938294329072628200105773),    // 22 88
  PQP3(R3(1. - (.03430622963180452385835196582344460) - (.03430622963180452385835196582344460) -
            (.59830121060139461905983787517050400),
          .03430622963180452385835196582344460, .59830121060139461905983787517050400),
       .01044842402938294329072628200105773),    // 23 92
  PQP3(R3(1. - (.03430622963180452385835196582344460) - (.03430622963180452385835196582344460) -
            (.59830121060139461905983787517050400),
          .59830121060139461905983787517050400, .03430622963180452385835196582344460),
       .01044842402938294329072628200105773),    // 24 96
  PQP3(R3(.03430622963180452385835196582344460, .03430622963180452385835196582344460,
          1. - (.03430622963180452385835196582344460) - (.03430622963180452385835196582344460) -
            (.59830121060139461905983787517050400)),
       .01044842402938294329072628200105773),    // 25 100
  PQP3(R3(.03430622963180452385835196582344460,
          1. - (.03430622963180452385835196582344460) - (.03430622963180452385835196582344460) -
            (.59830121060139461905983787517050400),
          .03430622963180452385835196582344460),
       .01044842402938294329072628200105773),    // 26 104
  PQP3(R3(1. - (.03430622963180452385835196582344460) - (.03430622963180452385835196582344460) -
            (.59830121060139461905983787517050400),
          .03430622963180452385835196582344460, .03430622963180452385835196582344460),
       .01044842402938294329072628200105773),    // 27 108
  PQP3(R3(.03430622963180452385835196582344460, .03430622963180452385835196582344460,
          .59830121060139461905983787517050400),
       .01044842402938294329072628200105773),    // 28 112
  PQP3(R3(.03430622963180452385835196582344460, .59830121060139461905983787517050400,
          .03430622963180452385835196582344460),
       .01044842402938294329072628200105773),    // 29 116
  PQP3(R3(.59830121060139461905983787517050400, .03430622963180452385835196582344460,
          .03430622963180452385835196582344460),
       .01044842402938294329072628200105773),    // 30 120
  PQP3(R3(.12346418534551115945916818783743644, .47120066204746310257913700590727081,
          1. - (.12346418534551115945916818783743644) - (.12346418534551115945916818783743644) -
            (.47120066204746310257913700590727081)),
       .02513844602651287118280517785487423),    // 31 124
  PQP3(R3(.12346418534551115945916818783743644,
          1. - (.12346418534551115945916818783743644) - (.12346418534551115945916818783743644) -
            (.47120066204746310257913700590727081),
          .47120066204746310257913700590727081),
       .02513844602651287118280517785487423),    // 32 128
  PQP3(R3(.47120066204746310257913700590727081, .12346418534551115945916818783743644,
          1. - (.12346418534551115945916818783743644) - (.12346418534551115945916818783743644) -
            (.47120066204746310257913700590727081)),
       .02513844602651287118280517785487423),    // 33 132
  PQP3(R3(.47120066204746310257913700590727081,
          1. - (.12346418534551115945916818783743644) - (.12346418534551115945916818783743644) -
            (.47120066204746310257913700590727081),
          .12346418534551115945916818783743644),
       .02513844602651287118280517785487423),    // 34 136
  PQP3(R3(1. - (.12346418534551115945916818783743644) - (.12346418534551115945916818783743644) -
            (.47120066204746310257913700590727081),
          .12346418534551115945916818783743644, .47120066204746310257913700590727081),
       .02513844602651287118280517785487423),    // 35 140
  PQP3(R3(1. - (.12346418534551115945916818783743644) - (.12346418534551115945916818783743644) -
            (.47120066204746310257913700590727081),
          .47120066204746310257913700590727081, .12346418534551115945916818783743644),
       .02513844602651287118280517785487423),    // 36 144
  PQP3(R3(.12346418534551115945916818783743644, .12346418534551115945916818783743644,
          1. - (.12346418534551115945916818783743644) - (.12346418534551115945916818783743644) -
            (.47120066204746310257913700590727081)),
       .02513844602651287118280517785487423),    // 37 148
  PQP3(R3(.12346418534551115945916818783743644,
          1. - (.12346418534551115945916818783743644) - (.12346418534551115945916818783743644) -
            (.47120066204746310257913700590727081),
          .12346418534551115945916818783743644),
       .02513844602651287118280517785487423),    // 38 152
  PQP3(R3(1. - (.12346418534551115945916818783743644) - (.12346418534551115945916818783743644) -
            (.47120066204746310257913700590727081),
          .12346418534551115945916818783743644, .12346418534551115945916818783743644),
       .02513844602651287118280517785487423),    // 39 156
  PQP3(R3(.12346418534551115945916818783743644, .12346418534551115945916818783743644,
          .47120066204746310257913700590727081),
       .02513844602651287118280517785487423),    // 40 160
  PQP3(R3(.12346418534551115945916818783743644, .47120066204746310257913700590727081,
          .12346418534551115945916818783743644),
       .02513844602651287118280517785487423),    // 41 164
  PQP3(R3(.47120066204746310257913700590727081, .12346418534551115945916818783743644,
          .12346418534551115945916818783743644),
       .02513844602651287118280517785487423),    // 42 168
  PQP3(R3(.40991962933181117418479812480531207, .16546413290740130923509687990363569,
          1. - (.40991962933181117418479812480531207) - (.40991962933181117418479812480531207) -
            (.16546413290740130923509687990363569)),
       .01178620679249594711782155323755017),    // 43 172
  PQP3(R3(.40991962933181117418479812480531207,
          1. - (.40991962933181117418479812480531207) - (.40991962933181117418479812480531207) -
            (.16546413290740130923509687990363569),
          .16546413290740130923509687990363569),
       .01178620679249594711782155323755017),    // 44 176
  PQP3(R3(.16546413290740130923509687990363569, .40991962933181117418479812480531207,
          1. - (.40991962933181117418479812480531207) - (.40991962933181117418479812480531207) -
            (.16546413290740130923509687990363569)),
       .01178620679249594711782155323755017),    // 45 180
  PQP3(R3(.16546413290740130923509687990363569,
          1. - (.40991962933181117418479812480531207) - (.40991962933181117418479812480531207) -
            (.16546413290740130923509687990363569),
          .40991962933181117418479812480531207),
       .01178620679249594711782155323755017),    // 46 184
  PQP3(R3(1. - (.40991962933181117418479812480531207) - (.40991962933181117418479812480531207) -
            (.16546413290740130923509687990363569),
          .40991962933181117418479812480531207, .16546413290740130923509687990363569),
       .01178620679249594711782155323755017),    // 47 188
  PQP3(R3(1. - (.40991962933181117418479812480531207) - (.40991962933181117418479812480531207) -
            (.16546413290740130923509687990363569),
          .16546413290740130923509687990363569, .40991962933181117418479812480531207),
       .01178620679249594711782155323755017),    // 48 192
  PQP3(R3(.40991962933181117418479812480531207, .40991962933181117418479812480531207,
          1. - (.40991962933181117418479812480531207) - (.40991962933181117418479812480531207) -
            (.16546413290740130923509687990363569)),
       .01178620679249594711782155323755017),    // 49 196
  PQP3(R3(.40991962933181117418479812480531207,
          1. - (.40991962933181117418479812480531207) - (.40991962933181117418479812480531207) -
            (.16546413290740130923509687990363569),
          .40991962933181117418479812480531207),
       .01178620679249594711782155323755017),    // 50 200
  PQP3(R3(1. - (.40991962933181117418479812480531207) - (.40991962933181117418479812480531207) -
            (.16546413290740130923509687990363569),
          .40991962933181117418479812480531207, .40991962933181117418479812480531207),
       .01178620679249594711782155323755017),    // 51 204
  PQP3(R3(.40991962933181117418479812480531207, .40991962933181117418479812480531207,
          .16546413290740130923509687990363569),
       .01178620679249594711782155323755017),    // 52 208
  PQP3(R3(.40991962933181117418479812480531207, .16546413290740130923509687990363569,
          .40991962933181117418479812480531207),
       .01178620679249594711782155323755017),    // 53 212
  PQP3(R3(.16546413290740130923509687990363569, .40991962933181117418479812480531207,
          .40991962933181117418479812480531207),
       .01178620679249594711782155323755017),    // 54 216
  PQP3(R3(.17397243903011716743177479785668929, .62916375300275643773181882027844514,
          1. - (.17397243903011716743177479785668929) - (.17397243903011716743177479785668929) -
            (.62916375300275643773181882027844514)),
       .01332022473886650471019828463616468),    // 55 220
  PQP3(R3(.17397243903011716743177479785668929,
          1. - (.17397243903011716743177479785668929) - (.17397243903011716743177479785668929) -
            (.62916375300275643773181882027844514),
          .62916375300275643773181882027844514),
       .01332022473886650471019828463616468),    // 56 224
  PQP3(R3(.62916375300275643773181882027844514, .17397243903011716743177479785668929,
          1. - (.17397243903011716743177479785668929) - (.17397243903011716743177479785668929) -
            (.62916375300275643773181882027844514)),
       .01332022473886650471019828463616468),    // 57 228
  PQP3(R3(.62916375300275643773181882027844514,
          1. - (.17397243903011716743177479785668929) - (.17397243903011716743177479785668929) -
            (.62916375300275643773181882027844514),
          .17397243903011716743177479785668929),
       .01332022473886650471019828463616468),    // 58 232
  PQP3(R3(1. - (.17397243903011716743177479785668929) - (.17397243903011716743177479785668929) -
            (.62916375300275643773181882027844514),
          .17397243903011716743177479785668929, .62916375300275643773181882027844514),
       .01332022473886650471019828463616468),    // 59 236
  PQP3(R3(1. - (.17397243903011716743177479785668929) - (.17397243903011716743177479785668929) -
            (.62916375300275643773181882027844514),
          .62916375300275643773181882027844514, .17397243903011716743177479785668929),
       .01332022473886650471019828463616468),    // 60 240
  PQP3(R3(.17397243903011716743177479785668929, .17397243903011716743177479785668929,
          1. - (.17397243903011716743177479785668929) - (.17397243903011716743177479785668929) -
            (.62916375300275643773181882027844514)),
       .01332022473886650471019828463616468),    // 61 244
  PQP3(R3(.17397243903011716743177479785668929,
          1. - (.17397243903011716743177479785668929) - (.17397243903011716743177479785668929) -
            (.62916375300275643773181882027844514),
          .17397243903011716743177479785668929),
       .01332022473886650471019828463616468),    // 62 248
  PQP3(R3(1. - (.17397243903011716743177479785668929) - (.17397243903011716743177479785668929) -
            (.62916375300275643773181882027844514),
          .17397243903011716743177479785668929, .17397243903011716743177479785668929),
       .01332022473886650471019828463616468),    // 63 252
  PQP3(R3(.17397243903011716743177479785668929, .17397243903011716743177479785668929,
          .62916375300275643773181882027844514),
       .01332022473886650471019828463616468),    // 64 256
  PQP3(R3(.17397243903011716743177479785668929, .62916375300275643773181882027844514,
          .17397243903011716743177479785668929),
       .01332022473886650471019828463616468),    // 65 260
  PQP3(R3(.62916375300275643773181882027844514, .17397243903011716743177479785668929,
          .17397243903011716743177479785668929),
       .01332022473886650471019828463616468),    // 66 264
  PQP3(R3(.03002157005631784150255786784038011, .81213056814351208262160080755918730,
          1. - (.03002157005631784150255786784038011) - (.03002157005631784150255786784038011) -
            (.81213056814351208262160080755918730)),
       .00615987577565961666092767531756180),    // 67 268
  PQP3(R3(.03002157005631784150255786784038011,
          1. - (.03002157005631784150255786784038011) - (.03002157005631784150255786784038011) -
            (.81213056814351208262160080755918730),
          .81213056814351208262160080755918730),
       .00615987577565961666092767531756180),    // 68 272
  PQP3(R3(.81213056814351208262160080755918730, .03002157005631784150255786784038011,
          1. - (.03002157005631784150255786784038011) - (.03002157005631784150255786784038011) -
            (.81213056814351208262160080755918730)),
       .00615987577565961666092767531756180),    // 69 276
  PQP3(R3(.81213056814351208262160080755918730,
          1. - (.03002157005631784150255786784038011) - (.03002157005631784150255786784038011) -
            (.81213056814351208262160080755918730),
          .03002157005631784150255786784038011),
       .00615987577565961666092767531756180),    // 70 280
  PQP3(R3(1. - (.03002157005631784150255786784038011) - (.03002157005631784150255786784038011) -
            (.81213056814351208262160080755918730),
          .03002157005631784150255786784038011, .81213056814351208262160080755918730),
       .00615987577565961666092767531756180),    // 71 284
  PQP3(R3(1. - (.03002157005631784150255786784038011) - (.03002157005631784150255786784038011) -
            (.81213056814351208262160080755918730),
          .81213056814351208262160080755918730, .03002157005631784150255786784038011),
       .00615987577565961666092767531756180),    // 72 288
  PQP3(R3(.03002157005631784150255786784038011, .03002157005631784150255786784038011,
          1. - (.03002157005631784150255786784038011) - (.03002157005631784150255786784038011) -
            (.81213056814351208262160080755918730)),
       .00615987577565961666092767531756180),    // 73 292
  PQP3(R3(.03002157005631784150255786784038011,
          1. - (.03002157005631784150255786784038011) - (.03002157005631784150255786784038011) -
            (.81213056814351208262160080755918730),
          .03002157005631784150255786784038011),
       .00615987577565961666092767531756180),    // 74 296
  PQP3(R3(1. - (.03002157005631784150255786784038011) - (.03002157005631784150255786784038011) -
            (.81213056814351208262160080755918730),
          .03002157005631784150255786784038011, .03002157005631784150255786784038011),
       .00615987577565961666092767531756180),    // 75 300
  PQP3(R3(.03002157005631784150255786784038011, .03002157005631784150255786784038011,
          .81213056814351208262160080755918730),
       .00615987577565961666092767531756180),    // 76 304
  PQP3(R3(.03002157005631784150255786784038011, .81213056814351208262160080755918730,
          .03002157005631784150255786784038011),
       .00615987577565961666092767531756180),    // 77 308
  PQP3(R3(.81213056814351208262160080755918730, .03002157005631784150255786784038011,
          .03002157005631784150255786784038011),
       .00615987577565961666092767531756180),    // 78 312
};
PQF3 const QuadratureFormular_Tet_P10(10, 79, QF_TET_P10);
// QUAD QUAD_3D_P11_ = { 96 384
PQP3 QF_TET_P11[] = {
  PQP3(R3(.12460560449278830000000000000000000, .12460560449278830000000000000000000,
          .12460560449278830000000000000000000),
       .01612698613577620369120244222737879),    // 0 0
  PQP3(R3(1. - 3. * (.12460560449278830000000000000000000), .12460560449278830000000000000000000,
          .12460560449278830000000000000000000),
       .01612698613577620369120244222737879),    // 1 4
  PQP3(R3(.12460560449278830000000000000000000, 1. - 3. * (.12460560449278830000000000000000000),
          .12460560449278830000000000000000000),
       .01612698613577620369120244222737879),    // 2 8
  PQP3(R3(.12460560449278830000000000000000000, .12460560449278830000000000000000000,
          1. - 3. * (.12460560449278830000000000000000000)),
       .01612698613577620369120244222737879),    // 3 12
  PQP3(R3(.02609630765687464746851542316261877, .02609630765687464746851542316261877,
          .02609630765687464746851542316261877),
       .00178872341812357138976990346996962),    // 4 16
  PQP3(R3(1. - 3. * (.02609630765687464746851542316261877), .02609630765687464746851542316261877,
          .02609630765687464746851542316261877),
       .00178872341812357138976990346996962),    // 5 20
  PQP3(R3(.02609630765687464746851542316261877, 1. - 3. * (.02609630765687464746851542316261877),
          .02609630765687464746851542316261877),
       .00178872341812357138976990346996962),    // 6 24
  PQP3(R3(.02609630765687464746851542316261877, .02609630765687464746851542316261877,
          1. - 3. * (.02609630765687464746851542316261877)),
       .00178872341812357138976990346996962),    // 7 28
  PQP3(R3(.07193883255798884087330011042809557, .07193883255798884087330011042809557,
          .07193883255798884087330011042809557),
       .00847529348343123401863799968389086),    // 8 32
  PQP3(R3(1. - 3. * (.07193883255798884087330011042809557), .07193883255798884087330011042809557,
          .07193883255798884087330011042809557),
       .00847529348343123401863799968389086),    // 9 36
  PQP3(R3(.07193883255798884087330011042809557, 1. - 3. * (.07193883255798884087330011042809557),
          .07193883255798884087330011042809557),
       .00847529348343123401863799968389086),    // 10 40
  PQP3(R3(.07193883255798884087330011042809557, .07193883255798884087330011042809557,
          1. - 3. * (.07193883255798884087330011042809557)),
       .00847529348343123401863799968389086),    // 11 44
  PQP3(R3(.32611122454203676937273102302894204, .32611122454203676937273102302894204,
          .32611122454203676937273102302894204),
       .01238021263944669050859562763135516),    // 12 48
  PQP3(R3(1. - 3. * (.32611122454203676937273102302894204), .32611122454203676937273102302894204,
          .32611122454203676937273102302894204),
       .01238021263944669050859562763135516),    // 13 52
  PQP3(R3(.32611122454203676937273102302894204, 1. - 3. * (.32611122454203676937273102302894204),
          .32611122454203676937273102302894204),
       .01238021263944669050859562763135516),    // 14 56
  PQP3(R3(.32611122454203676937273102302894204, .32611122454203676937273102302894204,
          1. - 3. * (.32611122454203676937273102302894204)),
       .01238021263944669050859562763135516),    // 15 60
  PQP3(R3(.29405882789858127213310307732130217, .29405882789858127213310307732130217,
          .29405882789858127213310307732130217),
       .02205586697199415746140963638568037),    // 16 64
  PQP3(R3(1. - 3. * (.29405882789858127213310307732130217), .29405882789858127213310307732130217,
          .29405882789858127213310307732130217),
       .02205586697199415746140963638568037),    // 17 68
  PQP3(R3(.29405882789858127213310307732130217, 1. - 3. * (.29405882789858127213310307732130217),
          .29405882789858127213310307732130217),
       .02205586697199415746140963638568037),    // 18 72
  PQP3(R3(.29405882789858127213310307732130217, .29405882789858127213310307732130217,
          1. - 3. * (.29405882789858127213310307732130217)),
       .02205586697199415746140963638568037),    // 19 76
  PQP3(R3(.19271399104965490000000000000000000, .19271399104965490000000000000000000,
          .19271399104965490000000000000000000),
       .02295765467664274421265594265203307),    // 20 80
  PQP3(R3(1. - 3. * (.19271399104965490000000000000000000), .19271399104965490000000000000000000,
          .19271399104965490000000000000000000),
       .02295765467664274421265594265203307),    // 21 84
  PQP3(R3(.19271399104965490000000000000000000, 1. - 3. * (.19271399104965490000000000000000000),
          .19271399104965490000000000000000000),
       .02295765467664274421265594265203307),    // 22 88
  PQP3(R3(.19271399104965490000000000000000000, .19271399104965490000000000000000000,
          1. - 3. * (.19271399104965490000000000000000000)),
       .02295765467664274421265594265203307),    // 23 92
  PQP3(R3(.00047127204692773946587837159205225, .5 - (.00047127204692773946587837159205225),
          .5 - (.00047127204692773946587837159205225)),
       .00120553827014535727045055662252294),    // 24 96
  PQP3(R3(.5 - (.00047127204692773946587837159205225), .00047127204692773946587837159205225,
          .5 - (.00047127204692773946587837159205225)),
       .00120553827014535727045055662252294),    // 25 100
  PQP3(R3(.5 - (.00047127204692773946587837159205225), .5 - (.00047127204692773946587837159205225),
          .00047127204692773946587837159205225),
       .00120553827014535727045055662252294),    // 26 104
  PQP3(R3(.00047127204692773946587837159205225, .5 - (.00047127204692773946587837159205225),
          .00047127204692773946587837159205225),
       .00120553827014535727045055662252294),    // 27 108
  PQP3(R3(.00047127204692773946587837159205225, .00047127204692773946587837159205225,
          .5 - (.00047127204692773946587837159205225)),
       .00120553827014535727045055662252294),    // 28 112
  PQP3(R3(.5 - (.00047127204692773946587837159205225), .00047127204692773946587837159205225,
          .00047127204692773946587837159205225),
       .00120553827014535727045055662252294),    // 29 116
  PQP3(R3(.10321360207480949336085123341390539, .5 - (.10321360207480949336085123341390539),
          .5 - (.10321360207480949336085123341390539)),
       .02479381575164443454447803302296997),    // 30 120
  PQP3(R3(.5 - (.10321360207480949336085123341390539), .10321360207480949336085123341390539,
          .5 - (.10321360207480949336085123341390539)),
       .02479381575164443454447803302296997),    // 31 124
  PQP3(R3(.5 - (.10321360207480949336085123341390539), .5 - (.10321360207480949336085123341390539),
          .10321360207480949336085123341390539),
       .02479381575164443454447803302296997),    // 32 128
  PQP3(R3(.10321360207480949336085123341390539, .5 - (.10321360207480949336085123341390539),
          .10321360207480949336085123341390539),
       .02479381575164443454447803302296997),    // 33 132
  PQP3(R3(.10321360207480949336085123341390539, .10321360207480949336085123341390539,
          .5 - (.10321360207480949336085123341390539)),
       .02479381575164443454447803302296997),    // 34 136
  PQP3(R3(.5 - (.10321360207480949336085123341390539), .10321360207480949336085123341390539,
          .10321360207480949336085123341390539),
       .02479381575164443454447803302296997),    // 35 140
  PQP3(R3(.04349989920159741251267172033621503, .63045319723555591476353398203997141,
          1. - (.04349989920159741251267172033621503) - (.04349989920159741251267172033621503) -
            (.63045319723555591476353398203997141)),
       .01203878836480353606935457416590660),    // 36 144
  PQP3(R3(.04349989920159741251267172033621503,
          1. - (.04349989920159741251267172033621503) - (.04349989920159741251267172033621503) -
            (.63045319723555591476353398203997141),
          .63045319723555591476353398203997141),
       .01203878836480353606935457416590660),    // 37 148
  PQP3(R3(.63045319723555591476353398203997141, .04349989920159741251267172033621503,
          1. - (.04349989920159741251267172033621503) - (.04349989920159741251267172033621503) -
            (.63045319723555591476353398203997141)),
       .01203878836480353606935457416590660),    // 38 152
  PQP3(R3(.63045319723555591476353398203997141,
          1. - (.04349989920159741251267172033621503) - (.04349989920159741251267172033621503) -
            (.63045319723555591476353398203997141),
          .04349989920159741251267172033621503),
       .01203878836480353606935457416590660),    // 39 156
  PQP3(R3(1. - (.04349989920159741251267172033621503) - (.04349989920159741251267172033621503) -
            (.63045319723555591476353398203997141),
          .04349989920159741251267172033621503, .63045319723555591476353398203997141),
       .01203878836480353606935457416590660),    // 40 160
  PQP3(R3(1. - (.04349989920159741251267172033621503) - (.04349989920159741251267172033621503) -
            (.63045319723555591476353398203997141),
          .63045319723555591476353398203997141, .04349989920159741251267172033621503),
       .01203878836480353606935457416590660),    // 41 164
  PQP3(R3(.04349989920159741251267172033621503, .04349989920159741251267172033621503,
          1. - (.04349989920159741251267172033621503) - (.04349989920159741251267172033621503) -
            (.63045319723555591476353398203997141)),
       .01203878836480353606935457416590660),    // 42 168
  PQP3(R3(.04349989920159741251267172033621503,
          1. - (.04349989920159741251267172033621503) - (.04349989920159741251267172033621503) -
            (.63045319723555591476353398203997141),
          .04349989920159741251267172033621503),
       .01203878836480353606935457416590660),    // 43 172
  PQP3(R3(1. - (.04349989920159741251267172033621503) - (.04349989920159741251267172033621503) -
            (.63045319723555591476353398203997141),
          .04349989920159741251267172033621503, .04349989920159741251267172033621503),
       .01203878836480353606935457416590660),    // 44 176
  PQP3(R3(.04349989920159741251267172033621503, .04349989920159741251267172033621503,
          .63045319723555591476353398203997141),
       .01203878836480353606935457416590660),    // 45 180
  PQP3(R3(.04349989920159741251267172033621503, .63045319723555591476353398203997141,
          .04349989920159741251267172033621503),
       .01203878836480353606935457416590660),    // 46 184
  PQP3(R3(.63045319723555591476353398203997141, .04349989920159741251267172033621503,
          .04349989920159741251267172033621503),
       .01203878836480353606935457416590660),    // 47 188
  PQP3(R3(.01414839289422299290755441603794058, .82491678632147090000000000000000000,
          1. - (.01414839289422299290755441603794058) - (.01414839289422299290755441603794058) -
            (.82491678632147090000000000000000000)),
       .00189370204498242146248858917618493),    // 48 192
  PQP3(R3(.01414839289422299290755441603794058,
          1. - (.01414839289422299290755441603794058) - (.01414839289422299290755441603794058) -
            (.82491678632147090000000000000000000),
          .82491678632147090000000000000000000),
       .00189370204498242146248858917618493),    // 49 196
  PQP3(R3(.82491678632147090000000000000000000, .01414839289422299290755441603794058,
          1. - (.01414839289422299290755441603794058) - (.01414839289422299290755441603794058) -
            (.82491678632147090000000000000000000)),
       .00189370204498242146248858917618493),    // 50 200
  PQP3(R3(.82491678632147090000000000000000000,
          1. - (.01414839289422299290755441603794058) - (.01414839289422299290755441603794058) -
            (.82491678632147090000000000000000000),
          .01414839289422299290755441603794058),
       .00189370204498242146248858917618493),    // 51 204
  PQP3(R3(1. - (.01414839289422299290755441603794058) - (.01414839289422299290755441603794058) -
            (.82491678632147090000000000000000000),
          .01414839289422299290755441603794058, .82491678632147090000000000000000000),
       .00189370204498242146248858917618493),    // 52 208
  PQP3(R3(1. - (.01414839289422299290755441603794058) - (.01414839289422299290755441603794058) -
            (.82491678632147090000000000000000000),
          .82491678632147090000000000000000000, .01414839289422299290755441603794058),
       .00189370204498242146248858917618493),    // 53 212
  PQP3(R3(.01414839289422299290755441603794058, .01414839289422299290755441603794058,
          1. - (.01414839289422299290755441603794058) - (.01414839289422299290755441603794058) -
            (.82491678632147090000000000000000000)),
       .00189370204498242146248858917618493),    // 54 216
  PQP3(R3(.01414839289422299290755441603794058,
          1. - (.01414839289422299290755441603794058) - (.01414839289422299290755441603794058) -
            (.82491678632147090000000000000000000),
          .01414839289422299290755441603794058),
       .00189370204498242146248858917618493),    // 55 220
  PQP3(R3(1. - (.01414839289422299290755441603794058) - (.01414839289422299290755441603794058) -
            (.82491678632147090000000000000000000),
          .01414839289422299290755441603794058, .01414839289422299290755441603794058),
       .00189370204498242146248858917618493),    // 56 224
  PQP3(R3(.01414839289422299290755441603794058, .01414839289422299290755441603794058,
          .82491678632147090000000000000000000),
       .00189370204498242146248858917618493),    // 57 228
  PQP3(R3(.01414839289422299290755441603794058, .82491678632147090000000000000000000,
          .01414839289422299290755441603794058),
       .00189370204498242146248858917618493),    // 58 232
  PQP3(R3(.82491678632147090000000000000000000, .01414839289422299290755441603794058,
          .01414839289422299290755441603794058),
       .00189370204498242146248858917618493),    // 59 236
  PQP3(R3(.21646077368258425486341884576246642, .52711130286496480000000000000000000,
          1. - (.21646077368258425486341884576246642) - (.21646077368258425486341884576246642) -
            (.52711130286496480000000000000000000)),
       .01838752922255814184581020943433469),    // 60 240
  PQP3(R3(.21646077368258425486341884576246642,
          1. - (.21646077368258425486341884576246642) - (.21646077368258425486341884576246642) -
            (.52711130286496480000000000000000000),
          .52711130286496480000000000000000000),
       .01838752922255814184581020943433469),    // 61 244
  PQP3(R3(.52711130286496480000000000000000000, .21646077368258425486341884576246642,
          1. - (.21646077368258425486341884576246642) - (.21646077368258425486341884576246642) -
            (.52711130286496480000000000000000000)),
       .01838752922255814184581020943433469),    // 62 248
  PQP3(R3(.52711130286496480000000000000000000,
          1. - (.21646077368258425486341884576246642) - (.21646077368258425486341884576246642) -
            (.52711130286496480000000000000000000),
          .21646077368258425486341884576246642),
       .01838752922255814184581020943433469),    // 63 252
  PQP3(R3(1. - (.21646077368258425486341884576246642) - (.21646077368258425486341884576246642) -
            (.52711130286496480000000000000000000),
          .21646077368258425486341884576246642, .52711130286496480000000000000000000),
       .01838752922255814184581020943433469),    // 64 256
  PQP3(R3(1. - (.21646077368258425486341884576246642) - (.21646077368258425486341884576246642) -
            (.52711130286496480000000000000000000),
          .52711130286496480000000000000000000, .21646077368258425486341884576246642),
       .01838752922255814184581020943433469),    // 65 260
  PQP3(R3(.21646077368258425486341884576246642, .21646077368258425486341884576246642,
          1. - (.21646077368258425486341884576246642) - (.21646077368258425486341884576246642) -
            (.52711130286496480000000000000000000)),
       .01838752922255814184581020943433469),    // 66 264
  PQP3(R3(.21646077368258425486341884576246642,
          1. - (.21646077368258425486341884576246642) - (.21646077368258425486341884576246642) -
            (.52711130286496480000000000000000000),
          .21646077368258425486341884576246642),
       .01838752922255814184581020943433469),    // 67 268
  PQP3(R3(1. - (.21646077368258425486341884576246642) - (.21646077368258425486341884576246642) -
            (.52711130286496480000000000000000000),
          .21646077368258425486341884576246642, .21646077368258425486341884576246642),
       .01838752922255814184581020943433469),    // 68 272
  PQP3(R3(.21646077368258425486341884576246642, .21646077368258425486341884576246642,
          .52711130286496480000000000000000000),
       .01838752922255814184581020943433469),    // 69 276
  PQP3(R3(.21646077368258425486341884576246642, .52711130286496480000000000000000000,
          .21646077368258425486341884576246642),
       .01838752922255814184581020943433469),    // 70 280
  PQP3(R3(.52711130286496480000000000000000000, .21646077368258425486341884576246642,
          .21646077368258425486341884576246642),
       .01838752922255814184581020943433469),    // 71 284
  PQP3(R3(.13301884366834711587538262083530116, .73318551371398651551736762818473584,
          1. - (.13301884366834711587538262083530116) - (.13301884366834711587538262083530116) -
            (.73318551371398651551736762818473584)),
       .00375249249801662461193260176157591),    // 72 288
  PQP3(R3(.13301884366834711587538262083530116,
          1. - (.13301884366834711587538262083530116) - (.13301884366834711587538262083530116) -
            (.73318551371398651551736762818473584),
          .73318551371398651551736762818473584),
       .00375249249801662461193260176157591),    // 73 292
  PQP3(R3(.73318551371398651551736762818473584, .13301884366834711587538262083530116,
          1. - (.13301884366834711587538262083530116) - (.13301884366834711587538262083530116) -
            (.73318551371398651551736762818473584)),
       .00375249249801662461193260176157591),    // 74 296
  PQP3(R3(.73318551371398651551736762818473584,
          1. - (.13301884366834711587538262083530116) - (.13301884366834711587538262083530116) -
            (.73318551371398651551736762818473584),
          .13301884366834711587538262083530116),
       .00375249249801662461193260176157591),    // 75 300
  PQP3(R3(1. - (.13301884366834711587538262083530116) - (.13301884366834711587538262083530116) -
            (.73318551371398651551736762818473584),
          .13301884366834711587538262083530116, .73318551371398651551736762818473584),
       .00375249249801662461193260176157591),    // 76 304
  PQP3(R3(1. - (.13301884366834711587538262083530116) - (.13301884366834711587538262083530116) -
            (.73318551371398651551736762818473584),
          .73318551371398651551736762818473584, .13301884366834711587538262083530116),
       .00375249249801662461193260176157591),    // 77 308
  PQP3(R3(.13301884366834711587538262083530116, .13301884366834711587538262083530116,
          1. - (.13301884366834711587538262083530116) - (.13301884366834711587538262083530116) -
            (.73318551371398651551736762818473584)),
       .00375249249801662461193260176157591),    // 78 312
  PQP3(R3(.13301884366834711587538262083530116,
          1. - (.13301884366834711587538262083530116) - (.13301884366834711587538262083530116) -
            (.73318551371398651551736762818473584),
          .13301884366834711587538262083530116),
       .00375249249801662461193260176157591),    // 79 316
  PQP3(R3(1. - (.13301884366834711587538262083530116) - (.13301884366834711587538262083530116) -
            (.73318551371398651551736762818473584),
          .13301884366834711587538262083530116, .13301884366834711587538262083530116),
       .00375249249801662461193260176157591),    // 80 320
  PQP3(R3(.13301884366834711587538262083530116, .13301884366834711587538262083530116,
          .73318551371398651551736762818473584),
       .00375249249801662461193260176157591),    // 81 324
  PQP3(R3(.13301884366834711587538262083530116, .73318551371398651551736762818473584,
          .13301884366834711587538262083530116),
       .00375249249801662461193260176157591),    // 82 328
  PQP3(R3(.73318551371398651551736762818473584, .13301884366834711587538262083530116,
          .13301884366834711587538262083530116),
       .00375249249801662461193260176157591),    // 83 332
  PQP3(R3(.44054756810613723082959230959880706, .11506799584377921703650823955291194,
          1. - (.44054756810613723082959230959880706) - (.44054756810613723082959230959880706) -
            (.11506799584377921703650823955291194)),
       .00633289841693951300885921328914879),    // 84 336
  PQP3(R3(.44054756810613723082959230959880706,
          1. - (.44054756810613723082959230959880706) - (.44054756810613723082959230959880706) -
            (.11506799584377921703650823955291194),
          .11506799584377921703650823955291194),
       .00633289841693951300885921328914879),    // 85 340
  PQP3(R3(.11506799584377921703650823955291194, .44054756810613723082959230959880706,
          1. - (.44054756810613723082959230959880706) - (.44054756810613723082959230959880706) -
            (.11506799584377921703650823955291194)),
       .00633289841693951300885921328914879),    // 86 344
  PQP3(R3(.11506799584377921703650823955291194,
          1. - (.44054756810613723082959230959880706) - (.44054756810613723082959230959880706) -
            (.11506799584377921703650823955291194),
          .44054756810613723082959230959880706),
       .00633289841693951300885921328914879),    // 87 348
  PQP3(R3(1. - (.44054756810613723082959230959880706) - (.44054756810613723082959230959880706) -
            (.11506799584377921703650823955291194),
          .44054756810613723082959230959880706, .11506799584377921703650823955291194),
       .00633289841693951300885921328914879),    // 88 352
  PQP3(R3(1. - (.44054756810613723082959230959880706) - (.44054756810613723082959230959880706) -
            (.11506799584377921703650823955291194),
          .11506799584377921703650823955291194, .44054756810613723082959230959880706),
       .00633289841693951300885921328914879),    // 89 356
  PQP3(R3(.44054756810613723082959230959880706, .44054756810613723082959230959880706,
          1. - (.44054756810613723082959230959880706) - (.44054756810613723082959230959880706) -
            (.11506799584377921703650823955291194)),
       .00633289841693951300885921328914879),    // 90 360
  PQP3(R3(.44054756810613723082959230959880706,
          1. - (.44054756810613723082959230959880706) - (.44054756810613723082959230959880706) -
            (.11506799584377921703650823955291194),
          .44054756810613723082959230959880706),
       .00633289841693951300885921328914879),    // 91 364
  PQP3(R3(1. - (.44054756810613723082959230959880706) - (.44054756810613723082959230959880706) -
            (.11506799584377921703650823955291194),
          .44054756810613723082959230959880706, .44054756810613723082959230959880706),
       .00633289841693951300885921328914879),    // 92 368
  PQP3(R3(.44054756810613723082959230959880706, .44054756810613723082959230959880706,
          .11506799584377921703650823955291194),
       .00633289841693951300885921328914879),    // 93 372
  PQP3(R3(.44054756810613723082959230959880706, .11506799584377921703650823955291194,
          .44054756810613723082959230959880706),
       .00633289841693951300885921328914879),    // 94 376
  PQP3(R3(.11506799584377921703650823955291194, .44054756810613723082959230959880706,
          .44054756810613723082959230959880706),
       .00633289841693951300885921328914879),    // 95 380
};
PQF3 const QuadratureFormular_Tet_P11(11, 96, QF_TET_P11);
// QUAD QUAD_3D_P12_ = { 127 508
PQP3 QF_TET_P12[] = {
  PQP3(R3(0.25, 0.25, 0.25), .02340581914868067999082580773836836),    // 0 0
  PQP3(R3(.19318721110347230000000000000000000, .19318721110347230000000000000000000,
          .19318721110347230000000000000000000),
       .00484469946470415656870798306091558),    // 1 4
  PQP3(R3(1. - 3. * (.19318721110347230000000000000000000), .19318721110347230000000000000000000,
          .19318721110347230000000000000000000),
       .00484469946470415656870798306091558),    // 2 8
  PQP3(R3(.19318721110347230000000000000000000, 1. - 3. * (.19318721110347230000000000000000000),
          .19318721110347230000000000000000000),
       .00484469946470415656870798306091558),    // 3 12
  PQP3(R3(.19318721110347230000000000000000000, .19318721110347230000000000000000000,
          1. - 3. * (.19318721110347230000000000000000000)),
       .00484469946470415656870798306091558),    // 4 16
  PQP3(R3(.01811701371436566878506928822499717, .01811701371436566878506928822499717,
          .01811701371436566878506928822499717),
       .00079865303812732982185563521014343),    // 5 20
  PQP3(R3(1. - 3. * (.01811701371436566878506928822499717), .01811701371436566878506928822499717,
          .01811701371436566878506928822499717),
       .00079865303812732982185563521014343),    // 6 24
  PQP3(R3(.01811701371436566878506928822499717, 1. - 3. * (.01811701371436566878506928822499717),
          .01811701371436566878506928822499717),
       .00079865303812732982185563521014343),    // 7 28
  PQP3(R3(.01811701371436566878506928822499717, .01811701371436566878506928822499717,
          1. - 3. * (.01811701371436566878506928822499717)),
       .00079865303812732982185563521014343),    // 8 32
  PQP3(R3(.10700751831426066518406159227423033, .10700751831426066518406159227423033,
          .10700751831426066518406159227423033),
       .01311872008808756207964488505025527),    // 9 36
  PQP3(R3(1. - 3. * (.10700751831426066518406159227423033), .10700751831426066518406159227423033,
          .10700751831426066518406159227423033),
       .01311872008808756207964488505025527),    // 10 40
  PQP3(R3(.10700751831426066518406159227423033, 1. - 3. * (.10700751831426066518406159227423033),
          .10700751831426066518406159227423033),
       .01311872008808756207964488505025527),    // 11 44
  PQP3(R3(.10700751831426066518406159227423033, .10700751831426066518406159227423033,
          1. - 3. * (.10700751831426066518406159227423033)),
       .01311872008808756207964488505025527),    // 12 48
  PQP3(R3(.29936173715970702940603127680004538, .29936173715970702940603127680004538,
          .29936173715970702940603127680004538),
       .02352182961292765917274505054313770),    // 13 52
  PQP3(R3(1. - 3. * (.29936173715970702940603127680004538), .29936173715970702940603127680004538,
          .29936173715970702940603127680004538),
       .02352182961292765917274505054313770),    // 14 56
  PQP3(R3(.29936173715970702940603127680004538, 1. - 3. * (.29936173715970702940603127680004538),
          .29936173715970702940603127680004538),
       .02352182961292765917274505054313770),    // 15 60
  PQP3(R3(.29936173715970702940603127680004538, .29936173715970702940603127680004538,
          1. - 3. * (.29936173715970702940603127680004538)),
       .02352182961292765917274505054313770),    // 16 64
  PQP3(R3(.33333033333333333042835213613025030, .33333033333333333042835213613025030,
          .33333033333333333042835213613025030),
       .00210860882494149803857437048649497),    // 17 68
  PQP3(R3(1. - 3. * (.33333033333333333042835213613025030), .33333033333333333042835213613025030,
          .33333033333333333042835213613025030),
       .00210860882494149803857437048649497),    // 18 72
  PQP3(R3(.33333033333333333042835213613025030, 1. - 3. * (.33333033333333333042835213613025030),
          .33333033333333333042835213613025030),
       .00210860882494149803857437048649497),    // 19 76
  PQP3(R3(.33333033333333333042835213613025030, .33333033333333333042835213613025030,
          1. - 3. * (.33333033333333333042835213613025030)),
       .00210860882494149803857437048649497),    // 20 80
  PQP3(R3(.16575369007421640000000000000000000, .16575369007421640000000000000000000,
          .16575369007421640000000000000000000),
       .00047839298963616600187228601742259),    // 21 84
  PQP3(R3(1. - 3. * (.16575369007421640000000000000000000), .16575369007421640000000000000000000,
          .16575369007421640000000000000000000),
       .00047839298963616600187228601742259),    // 22 88
  PQP3(R3(.16575369007421640000000000000000000, 1. - 3. * (.16575369007421640000000000000000000),
          .16575369007421640000000000000000000),
       .00047839298963616600187228601742259),    // 23 92
  PQP3(R3(.16575369007421640000000000000000000, .16575369007421640000000000000000000,
          1. - 3. * (.16575369007421640000000000000000000)),
       .00047839298963616600187228601742259),    // 24 96
  PQP3(R3(.04009986052352575650366980228640728, .5 - (.04009986052352575650366980228640728),
          .5 - (.04009986052352575650366980228640728)),
       .00204546234216855322941711800170502),    // 25 100
  PQP3(R3(.5 - (.04009986052352575650366980228640728), .04009986052352575650366980228640728,
          .5 - (.04009986052352575650366980228640728)),
       .00204546234216855322941711800170502),    // 26 104
  PQP3(R3(.5 - (.04009986052352575650366980228640728), .5 - (.04009986052352575650366980228640728),
          .04009986052352575650366980228640728),
       .00204546234216855322941711800170502),    // 27 108
  PQP3(R3(.04009986052352575650366980228640728, .5 - (.04009986052352575650366980228640728),
          .04009986052352575650366980228640728),
       .00204546234216855322941711800170502),    // 28 112
  PQP3(R3(.04009986052352575650366980228640728, .04009986052352575650366980228640728,
          .5 - (.04009986052352575650366980228640728)),
       .00204546234216855322941711800170502),    // 29 116
  PQP3(R3(.5 - (.04009986052352575650366980228640728), .04009986052352575650366980228640728,
          .04009986052352575650366980228640728),
       .00204546234216855322941711800170502),    // 30 120
  PQP3(R3(.01951844463761131301132122485607343, .59982639757597731668263005976738196,
          1. - (.01951844463761131301132122485607343) - (.01951844463761131301132122485607343) -
            (.59982639757597731668263005976738196)),
       .00334576331671817115245418532677178),    // 31 124
  PQP3(R3(.01951844463761131301132122485607343,
          1. - (.01951844463761131301132122485607343) - (.01951844463761131301132122485607343) -
            (.59982639757597731668263005976738196),
          .59982639757597731668263005976738196),
       .00334576331671817115245418532677178),    // 32 128
  PQP3(R3(.59982639757597731668263005976738196, .01951844463761131301132122485607343,
          1. - (.01951844463761131301132122485607343) - (.01951844463761131301132122485607343) -
            (.59982639757597731668263005976738196)),
       .00334576331671817115245418532677178),    // 33 132
  PQP3(R3(.59982639757597731668263005976738196,
          1. - (.01951844463761131301132122485607343) - (.01951844463761131301132122485607343) -
            (.59982639757597731668263005976738196),
          .01951844463761131301132122485607343),
       .00334576331671817115245418532677178),    // 34 136
  PQP3(R3(1. - (.01951844463761131301132122485607343) - (.01951844463761131301132122485607343) -
            (.59982639757597731668263005976738196),
          .01951844463761131301132122485607343, .59982639757597731668263005976738196),
       .00334576331671817115245418532677178),    // 35 140
  PQP3(R3(1. - (.01951844463761131301132122485607343) - (.01951844463761131301132122485607343) -
            (.59982639757597731668263005976738196),
          .59982639757597731668263005976738196, .01951844463761131301132122485607343),
       .00334576331671817115245418532677178),    // 36 144
  PQP3(R3(.01951844463761131301132122485607343, .01951844463761131301132122485607343,
          1. - (.01951844463761131301132122485607343) - (.01951844463761131301132122485607343) -
            (.59982639757597731668263005976738196)),
       .00334576331671817115245418532677178),    // 37 148
  PQP3(R3(.01951844463761131301132122485607343,
          1. - (.01951844463761131301132122485607343) - (.01951844463761131301132122485607343) -
            (.59982639757597731668263005976738196),
          .01951844463761131301132122485607343),
       .00334576331671817115245418532677178),    // 38 152
  PQP3(R3(1. - (.01951844463761131301132122485607343) - (.01951844463761131301132122485607343) -
            (.59982639757597731668263005976738196),
          .01951844463761131301132122485607343, .01951844463761131301132122485607343),
       .00334576331671817115245418532677178),    // 39 156
  PQP3(R3(.01951844463761131301132122485607343, .01951844463761131301132122485607343,
          .59982639757597731668263005976738196),
       .00334576331671817115245418532677178),    // 40 160
  PQP3(R3(.01951844463761131301132122485607343, .59982639757597731668263005976738196,
          .01951844463761131301132122485607343),
       .00334576331671817115245418532677178),    // 41 164
  PQP3(R3(.59982639757597731668263005976738196, .01951844463761131301132122485607343,
          .01951844463761131301132122485607343),
       .00334576331671817115245418532677178),    // 42 168
  PQP3(R3(.24970741896308715787490891769354198, .47400425629911050000000000000000000,
          1. - (.24970741896308715787490891769354198) - (.24970741896308715787490891769354198) -
            (.47400425629911050000000000000000000)),
       .01181044822479275264785338274950585),    // 43 172
  PQP3(R3(.24970741896308715787490891769354198,
          1. - (.24970741896308715787490891769354198) - (.24970741896308715787490891769354198) -
            (.47400425629911050000000000000000000),
          .47400425629911050000000000000000000),
       .01181044822479275264785338274950585),    // 44 176
  PQP3(R3(.47400425629911050000000000000000000, .24970741896308715787490891769354198,
          1. - (.24970741896308715787490891769354198) - (.24970741896308715787490891769354198) -
            (.47400425629911050000000000000000000)),
       .01181044822479275264785338274950585),    // 45 180
  PQP3(R3(.47400425629911050000000000000000000,
          1. - (.24970741896308715787490891769354198) - (.24970741896308715787490891769354198) -
            (.47400425629911050000000000000000000),
          .24970741896308715787490891769354198),
       .01181044822479275264785338274950585),    // 46 184
  PQP3(R3(1. - (.24970741896308715787490891769354198) - (.24970741896308715787490891769354198) -
            (.47400425629911050000000000000000000),
          .24970741896308715787490891769354198, .47400425629911050000000000000000000),
       .01181044822479275264785338274950585),    // 47 188
  PQP3(R3(1. - (.24970741896308715787490891769354198) - (.24970741896308715787490891769354198) -
            (.47400425629911050000000000000000000),
          .47400425629911050000000000000000000, .24970741896308715787490891769354198),
       .01181044822479275264785338274950585),    // 48 192
  PQP3(R3(.24970741896308715787490891769354198, .24970741896308715787490891769354198,
          1. - (.24970741896308715787490891769354198) - (.24970741896308715787490891769354198) -
            (.47400425629911050000000000000000000)),
       .01181044822479275264785338274950585),    // 49 196
  PQP3(R3(.24970741896308715787490891769354198,
          1. - (.24970741896308715787490891769354198) - (.24970741896308715787490891769354198) -
            (.47400425629911050000000000000000000),
          .24970741896308715787490891769354198),
       .01181044822479275264785338274950585),    // 50 200
  PQP3(R3(1. - (.24970741896308715787490891769354198) - (.24970741896308715787490891769354198) -
            (.47400425629911050000000000000000000),
          .24970741896308715787490891769354198, .24970741896308715787490891769354198),
       .01181044822479275264785338274950585),    // 51 204
  PQP3(R3(.24970741896308715787490891769354198, .24970741896308715787490891769354198,
          .47400425629911050000000000000000000),
       .01181044822479275264785338274950585),    // 52 208
  PQP3(R3(.24970741896308715787490891769354198, .47400425629911050000000000000000000,
          .24970741896308715787490891769354198),
       .01181044822479275264785338274950585),    // 53 212
  PQP3(R3(.47400425629911050000000000000000000, .24970741896308715787490891769354198,
          .24970741896308715787490891769354198),
       .01181044822479275264785338274950585),    // 54 216
  PQP3(R3(.07674205857869954726322831328843659, .83056291375422969598432041821082569,
          1. - (.07674205857869954726322831328843659) - (.07674205857869954726322831328843659) -
            (.83056291375422969598432041821082569)),
       .00290156990282342152841364375092118),    // 55 220
  PQP3(R3(.07674205857869954726322831328843659,
          1. - (.07674205857869954726322831328843659) - (.07674205857869954726322831328843659) -
            (.83056291375422969598432041821082569),
          .83056291375422969598432041821082569),
       .00290156990282342152841364375092118),    // 56 224
  PQP3(R3(.83056291375422969598432041821082569, .07674205857869954726322831328843659,
          1. - (.07674205857869954726322831328843659) - (.07674205857869954726322831328843659) -
            (.83056291375422969598432041821082569)),
       .00290156990282342152841364375092118),    // 57 228
  PQP3(R3(.83056291375422969598432041821082569,
          1. - (.07674205857869954726322831328843659) - (.07674205857869954726322831328843659) -
            (.83056291375422969598432041821082569),
          .07674205857869954726322831328843659),
       .00290156990282342152841364375092118),    // 58 232
  PQP3(R3(1. - (.07674205857869954726322831328843659) - (.07674205857869954726322831328843659) -
            (.83056291375422969598432041821082569),
          .07674205857869954726322831328843659, .83056291375422969598432041821082569),
       .00290156990282342152841364375092118),    // 59 236
  PQP3(R3(1. - (.07674205857869954726322831328843659) - (.07674205857869954726322831328843659) -
            (.83056291375422969598432041821082569),
          .83056291375422969598432041821082569, .07674205857869954726322831328843659),
       .00290156990282342152841364375092118),    // 60 240
  PQP3(R3(.07674205857869954726322831328843659, .07674205857869954726322831328843659,
          1. - (.07674205857869954726322831328843659) - (.07674205857869954726322831328843659) -
            (.83056291375422969598432041821082569)),
       .00290156990282342152841364375092118),    // 61 244
  PQP3(R3(.07674205857869954726322831328843659,
          1. - (.07674205857869954726322831328843659) - (.07674205857869954726322831328843659) -
            (.83056291375422969598432041821082569),
          .07674205857869954726322831328843659),
       .00290156990282342152841364375092118),    // 62 248
  PQP3(R3(1. - (.07674205857869954726322831328843659) - (.07674205857869954726322831328843659) -
            (.83056291375422969598432041821082569),
          .07674205857869954726322831328843659, .07674205857869954726322831328843659),
       .00290156990282342152841364375092118),    // 63 252
  PQP3(R3(.07674205857869954726322831328843659, .07674205857869954726322831328843659,
          .83056291375422969598432041821082569),
       .00290156990282342152841364375092118),    // 64 256
  PQP3(R3(.07674205857869954726322831328843659, .83056291375422969598432041821082569,
          .07674205857869954726322831328843659),
       .00290156990282342152841364375092118),    // 65 260
  PQP3(R3(.83056291375422969598432041821082569, .07674205857869954726322831328843659,
          .07674205857869954726322831328843659),
       .00290156990282342152841364375092118),    // 66 264
  PQP3(R3(.43011409627915217536723647418133112, .02265922072588833582931396831630072,
          1. - (.43011409627915217536723647418133112) - (.43011409627915217536723647418133112) -
            (.02265922072588833582931396831630072)),
       .00949250645501753676094846901252898),    // 67 268
  PQP3(R3(.43011409627915217536723647418133112,
          1. - (.43011409627915217536723647418133112) - (.43011409627915217536723647418133112) -
            (.02265922072588833582931396831630072),
          .02265922072588833582931396831630072),
       .00949250645501753676094846901252898),    // 68 272
  PQP3(R3(.02265922072588833582931396831630072, .43011409627915217536723647418133112,
          1. - (.43011409627915217536723647418133112) - (.43011409627915217536723647418133112) -
            (.02265922072588833582931396831630072)),
       .00949250645501753676094846901252898),    // 69 276
  PQP3(R3(.02265922072588833582931396831630072,
          1. - (.43011409627915217536723647418133112) - (.43011409627915217536723647418133112) -
            (.02265922072588833582931396831630072),
          .43011409627915217536723647418133112),
       .00949250645501753676094846901252898),    // 70 280
  PQP3(R3(1. - (.43011409627915217536723647418133112) - (.43011409627915217536723647418133112) -
            (.02265922072588833582931396831630072),
          .43011409627915217536723647418133112, .02265922072588833582931396831630072),
       .00949250645501753676094846901252898),    // 71 284
  PQP3(R3(1. - (.43011409627915217536723647418133112) - (.43011409627915217536723647418133112) -
            (.02265922072588833582931396831630072),
          .02265922072588833582931396831630072, .43011409627915217536723647418133112),
       .00949250645501753676094846901252898),    // 72 288
  PQP3(R3(.43011409627915217536723647418133112, .43011409627915217536723647418133112,
          1. - (.43011409627915217536723647418133112) - (.43011409627915217536723647418133112) -
            (.02265922072588833582931396831630072)),
       .00949250645501753676094846901252898),    // 73 292
  PQP3(R3(.43011409627915217536723647418133112,
          1. - (.43011409627915217536723647418133112) - (.43011409627915217536723647418133112) -
            (.02265922072588833582931396831630072),
          .43011409627915217536723647418133112),
       .00949250645501753676094846901252898),    // 74 296
  PQP3(R3(1. - (.43011409627915217536723647418133112) - (.43011409627915217536723647418133112) -
            (.02265922072588833582931396831630072),
          .43011409627915217536723647418133112, .43011409627915217536723647418133112),
       .00949250645501753676094846901252898),    // 75 300
  PQP3(R3(.43011409627915217536723647418133112, .43011409627915217536723647418133112,
          .02265922072588833582931396831630072),
       .00949250645501753676094846901252898),    // 76 304
  PQP3(R3(.43011409627915217536723647418133112, .02265922072588833582931396831630072,
          .43011409627915217536723647418133112),
       .00949250645501753676094846901252898),    // 77 308
  PQP3(R3(.02265922072588833582931396831630072, .43011409627915217536723647418133112,
          .43011409627915217536723647418133112),
       .00949250645501753676094846901252898),    // 78 312
  PQP3(R3(.12197854304894211937147375564906792, .47765370899783134571567376444973682,
          1. - (.12197854304894211937147375564906792) - (.12197854304894211937147375564906792) -
            (.47765370899783134571567376444973682)),
       .02094018358085748583183796760479700),    // 79 316
  PQP3(R3(.12197854304894211937147375564906792,
          1. - (.12197854304894211937147375564906792) - (.12197854304894211937147375564906792) -
            (.47765370899783134571567376444973682),
          .47765370899783134571567376444973682),
       .02094018358085748583183796760479700),    // 80 320
  PQP3(R3(.47765370899783134571567376444973682, .12197854304894211937147375564906792,
          1. - (.12197854304894211937147375564906792) - (.12197854304894211937147375564906792) -
            (.47765370899783134571567376444973682)),
       .02094018358085748583183796760479700),    // 81 324
  PQP3(R3(.47765370899783134571567376444973682,
          1. - (.12197854304894211937147375564906792) - (.12197854304894211937147375564906792) -
            (.47765370899783134571567376444973682),
          .12197854304894211937147375564906792),
       .02094018358085748583183796760479700),    // 82 328
  PQP3(R3(1. - (.12197854304894211937147375564906792) - (.12197854304894211937147375564906792) -
            (.47765370899783134571567376444973682),
          .12197854304894211937147375564906792, .47765370899783134571567376444973682),
       .02094018358085748583183796760479700),    // 83 332
  PQP3(R3(1. - (.12197854304894211937147375564906792) - (.12197854304894211937147375564906792) -
            (.47765370899783134571567376444973682),
          .47765370899783134571567376444973682, .12197854304894211937147375564906792),
       .02094018358085748583183796760479700),    // 84 336
  PQP3(R3(.12197854304894211937147375564906792, .12197854304894211937147375564906792,
          1. - (.12197854304894211937147375564906792) - (.12197854304894211937147375564906792) -
            (.47765370899783134571567376444973682)),
       .02094018358085748583183796760479700),    // 85 340
  PQP3(R3(.12197854304894211937147375564906792,
          1. - (.12197854304894211937147375564906792) - (.12197854304894211937147375564906792) -
            (.47765370899783134571567376444973682),
          .12197854304894211937147375564906792),
       .02094018358085748583183796760479700),    // 86 344
  PQP3(R3(1. - (.12197854304894211937147375564906792) - (.12197854304894211937147375564906792) -
            (.47765370899783134571567376444973682),
          .12197854304894211937147375564906792, .12197854304894211937147375564906792),
       .02094018358085748583183796760479700),    // 87 348
  PQP3(R3(.12197854304894211937147375564906792, .12197854304894211937147375564906792,
          .47765370899783134571567376444973682),
       .02094018358085748583183796760479700),    // 88 352
  PQP3(R3(.12197854304894211937147375564906792, .47765370899783134571567376444973682,
          .12197854304894211937147375564906792),
       .02094018358085748583183796760479700),    // 89 356
  PQP3(R3(.47765370899783134571567376444973682, .12197854304894211937147375564906792,
          .12197854304894211937147375564906792),
       .02094018358085748583183796760479700),    // 90 360
  PQP3(R3(.01480482319031682427540691439704854, .81083799468092699988474915243749073,
          1. - (.01480482319031682427540691439704854) - (.01480482319031682427540691439704854) -
            (.81083799468092699988474915243749073)),
       .00171435866337409051521874943702732),    // 91 364
  PQP3(R3(.01480482319031682427540691439704854,
          1. - (.01480482319031682427540691439704854) - (.01480482319031682427540691439704854) -
            (.81083799468092699988474915243749073),
          .81083799468092699988474915243749073),
       .00171435866337409051521874943702732),    // 92 368
  PQP3(R3(.81083799468092699988474915243749073, .01480482319031682427540691439704854,
          1. - (.01480482319031682427540691439704854) - (.01480482319031682427540691439704854) -
            (.81083799468092699988474915243749073)),
       .00171435866337409051521874943702732),    // 93 372
  PQP3(R3(.81083799468092699988474915243749073,
          1. - (.01480482319031682427540691439704854) - (.01480482319031682427540691439704854) -
            (.81083799468092699988474915243749073),
          .01480482319031682427540691439704854),
       .00171435866337409051521874943702732),    // 94 376
  PQP3(R3(1. - (.01480482319031682427540691439704854) - (.01480482319031682427540691439704854) -
            (.81083799468092699988474915243749073),
          .01480482319031682427540691439704854, .81083799468092699988474915243749073),
       .00171435866337409051521874943702732),    // 95 380
  PQP3(R3(1. - (.01480482319031682427540691439704854) - (.01480482319031682427540691439704854) -
            (.81083799468092699988474915243749073),
          .81083799468092699988474915243749073, .01480482319031682427540691439704854),
       .00171435866337409051521874943702732),    // 96 384
  PQP3(R3(.01480482319031682427540691439704854, .01480482319031682427540691439704854,
          1. - (.01480482319031682427540691439704854) - (.01480482319031682427540691439704854) -
            (.81083799468092699988474915243749073)),
       .00171435866337409051521874943702732),    // 97 388
  PQP3(R3(.01480482319031682427540691439704854,
          1. - (.01480482319031682427540691439704854) - (.01480482319031682427540691439704854) -
            (.81083799468092699988474915243749073),
          .01480482319031682427540691439704854),
       .00171435866337409051521874943702732),    // 98 392
  PQP3(R3(1. - (.01480482319031682427540691439704854) - (.01480482319031682427540691439704854) -
            (.81083799468092699988474915243749073),
          .01480482319031682427540691439704854, .01480482319031682427540691439704854),
       .00171435866337409051521874943702732),    // 99 396
  PQP3(R3(.01480482319031682427540691439704854, .01480482319031682427540691439704854,
          .81083799468092699988474915243749073),
       .00171435866337409051521874943702732),    // 100 400
  PQP3(R3(.01480482319031682427540691439704854, .81083799468092699988474915243749073,
          .01480482319031682427540691439704854),
       .00171435866337409051521874943702732),    // 101 404
  PQP3(R3(.81083799468092699988474915243749073, .01480482319031682427540691439704854,
          .01480482319031682427540691439704854),
       .00171435866337409051521874943702732),    // 102 408
  PQP3(R3(.22646235632397177636617160407210034, .02251830769546778956654013747639605,
          1. - (.65250697573013212016385330106711095) - (.22646235632397177636617160407210034) -
            (.02251830769546778956654013747639605)),
       .00759915954173370886076474450830409),    // 103 412
  PQP3(R3(.22646235632397177636617160407210034,
          1. - (.65250697573013212016385330106711095) - (.22646235632397177636617160407210034) -
            (.02251830769546778956654013747639605),
          .02251830769546778956654013747639605),
       .00759915954173370886076474450830409),    // 104 416
  PQP3(R3(.02251830769546778956654013747639605, .22646235632397177636617160407210034,
          1. - (.65250697573013212016385330106711095) - (.22646235632397177636617160407210034) -
            (.02251830769546778956654013747639605)),
       .00759915954173370886076474450830409),    // 105 420
  PQP3(R3(.02251830769546778956654013747639605,
          1. - (.65250697573013212016385330106711095) - (.22646235632397177636617160407210034) -
            (.02251830769546778956654013747639605),
          .22646235632397177636617160407210034),
       .00759915954173370886076474450830409),    // 106 424
  PQP3(R3(1. - (.65250697573013212016385330106711095) - (.22646235632397177636617160407210034) -
            (.02251830769546778956654013747639605),
          .22646235632397177636617160407210034, .02251830769546778956654013747639605),
       .00759915954173370886076474450830409),    // 107 428
  PQP3(R3(1. - (.65250697573013212016385330106711095) - (.22646235632397177636617160407210034) -
            (.02251830769546778956654013747639605),
          .02251830769546778956654013747639605, .22646235632397177636617160407210034),
       .00759915954173370886076474450830409),    // 108 432
  PQP3(R3(.65250697573013212016385330106711095, .02251830769546778956654013747639605,
          1. - (.65250697573013212016385330106711095) - (.22646235632397177636617160407210034) -
            (.02251830769546778956654013747639605)),
       .00759915954173370886076474450830409),    // 109 436
  PQP3(R3(.65250697573013212016385330106711095,
          1. - (.65250697573013212016385330106711095) - (.22646235632397177636617160407210034) -
            (.02251830769546778956654013747639605),
          .02251830769546778956654013747639605),
       .00759915954173370886076474450830409),    // 110 440
  PQP3(R3(.02251830769546778956654013747639605, .65250697573013212016385330106711095,
          1. - (.65250697573013212016385330106711095) - (.22646235632397177636617160407210034) -
            (.02251830769546778956654013747639605)),
       .00759915954173370886076474450830409),    // 111 444
  PQP3(R3(.02251830769546778956654013747639605,
          1. - (.65250697573013212016385330106711095) - (.22646235632397177636617160407210034) -
            (.02251830769546778956654013747639605),
          .65250697573013212016385330106711095),
       .00759915954173370886076474450830409),    // 112 448
  PQP3(R3(1. - (.65250697573013212016385330106711095) - (.22646235632397177636617160407210034) -
            (.02251830769546778956654013747639605),
          .65250697573013212016385330106711095, .02251830769546778956654013747639605),
       .00759915954173370886076474450830409),    // 113 452
  PQP3(R3(1. - (.65250697573013212016385330106711095) - (.22646235632397177636617160407210034) -
            (.02251830769546778956654013747639605),
          .02251830769546778956654013747639605, .65250697573013212016385330106711095),
       .00759915954173370886076474450830409),    // 114 456
  PQP3(R3(.65250697573013212016385330106711095, .22646235632397177636617160407210034,
          1. - (.65250697573013212016385330106711095) - (.22646235632397177636617160407210034) -
            (.02251830769546778956654013747639605)),
       .00759915954173370886076474450830409),    // 115 460
  PQP3(R3(.65250697573013212016385330106711095,
          1. - (.65250697573013212016385330106711095) - (.22646235632397177636617160407210034) -
            (.02251830769546778956654013747639605),
          .22646235632397177636617160407210034),
       .00759915954173370886076474450830409),    // 116 464
  PQP3(R3(.22646235632397177636617160407210034, .65250697573013212016385330106711095,
          1. - (.65250697573013212016385330106711095) - (.22646235632397177636617160407210034) -
            (.02251830769546778956654013747639605)),
       .00759915954173370886076474450830409),    // 117 468
  PQP3(R3(.22646235632397177636617160407210034,
          1. - (.65250697573013212016385330106711095) - (.22646235632397177636617160407210034) -
            (.02251830769546778956654013747639605),
          .65250697573013212016385330106711095),
       .00759915954173370886076474450830409),    // 118 472
  PQP3(R3(1. - (.65250697573013212016385330106711095) - (.22646235632397177636617160407210034) -
            (.02251830769546778956654013747639605),
          .65250697573013212016385330106711095, .22646235632397177636617160407210034),
       .00759915954173370886076474450830409),    // 119 476
  PQP3(R3(1. - (.65250697573013212016385330106711095) - (.22646235632397177636617160407210034) -
            (.02251830769546778956654013747639605),
          .22646235632397177636617160407210034, .65250697573013212016385330106711095),
       .00759915954173370886076474450830409),    // 120 480
  PQP3(R3(.65250697573013212016385330106711095, .22646235632397177636617160407210034,
          .02251830769546778956654013747639605),
       .00759915954173370886076474450830409),    // 121 484
  PQP3(R3(.65250697573013212016385330106711095, .02251830769546778956654013747639605,
          .22646235632397177636617160407210034),
       .00759915954173370886076474450830409),    // 122 488
  PQP3(R3(.22646235632397177636617160407210034, .65250697573013212016385330106711095,
          .02251830769546778956654013747639605),
       .00759915954173370886076474450830409),    // 123 492
  PQP3(R3(.22646235632397177636617160407210034, .02251830769546778956654013747639605,
          .65250697573013212016385330106711095),
       .00759915954173370886076474450830409),    // 124 496
  PQP3(R3(.02251830769546778956654013747639605, .65250697573013212016385330106711095,
          .22646235632397177636617160407210034),
       .00759915954173370886076474450830409),    // 125 500
  PQP3(R3(.02251830769546778956654013747639605, .22646235632397177636617160407210034,
          .65250697573013212016385330106711095),
       .00759915954173370886076474450830409),    // 126 504
};
PQF3 const QuadratureFormular_Tet_P12(12, 127, QF_TET_P12);
// QUAD QUAD_3D_P13_ = { 149 596
PQP3 QF_TET_P13[] = {
  PQP3(R3(0.25, 0.25, 0.25), .02191579945212728678229670892998658),    // 0 0
  PQP3(R3(.09935339765028269917868020572165369, .09935339765028269917868020572165369,
          .09935339765028269917868020572165369),
       .00809592740005652573580359966615063),    // 1 4
  PQP3(R3(1. - 3. * (.09935339765028269917868020572165369), .09935339765028269917868020572165369,
          .09935339765028269917868020572165369),
       .00809592740005652573580359966615063),    // 2 8
  PQP3(R3(.09935339765028269917868020572165369, 1. - 3. * (.09935339765028269917868020572165369),
          .09935339765028269917868020572165369),
       .00809592740005652573580359966615063),    // 3 12
  PQP3(R3(.09935339765028269917868020572165369, .09935339765028269917868020572165369,
          1. - 3. * (.09935339765028269917868020572165369)),
       .00809592740005652573580359966615063),    // 4 16
  PQP3(R3(.02361873260499568532036302265004401, .02361873260499568532036302265004401,
          .02361873260499568532036302265004401),
       .00130319185047278813746994806952476),    // 5 20
  PQP3(R3(1. - 3. * (.02361873260499568532036302265004401), .02361873260499568532036302265004401,
          .02361873260499568532036302265004401),
       .00130319185047278813746994806952476),    // 6 24
  PQP3(R3(.02361873260499568532036302265004401, 1. - 3. * (.02361873260499568532036302265004401),
          .02361873260499568532036302265004401),
       .00130319185047278813746994806952476),    // 7 28
  PQP3(R3(.02361873260499568532036302265004401, .02361873260499568532036302265004401,
          1. - 3. * (.02361873260499568532036302265004401)),
       .00130319185047278813746994806952476),    // 8 32
  PQP3(R3(.30089166537572662790706731844610997, .30089166537572662790706731844610997,
          .30089166537572662790706731844610997),
       .01996610676014222116016391561580003),    // 9 36
  PQP3(R3(1. - 3. * (.30089166537572662790706731844610997), .30089166537572662790706731844610997,
          .30089166537572662790706731844610997),
       .01996610676014222116016391561580003),    // 10 40
  PQP3(R3(.30089166537572662790706731844610997, 1. - 3. * (.30089166537572662790706731844610997),
          .30089166537572662790706731844610997),
       .01996610676014222116016391561580003),    // 11 44
  PQP3(R3(.30089166537572662790706731844610997, .30089166537572662790706731844610997,
          1. - 3. * (.30089166537572662790706731844610997)),
       .01996610676014222116016391561580003),    // 12 48
  PQP3(R3(.18156624280757148139366685840064601, .18156624280757148139366685840064601,
          .18156624280757148139366685840064601),
       .02125705756007566772097136088386650),    // 13 52
  PQP3(R3(1. - 3. * (.18156624280757148139366685840064601), .18156624280757148139366685840064601,
          .18156624280757148139366685840064601),
       .02125705756007566772097136088386650),    // 14 56
  PQP3(R3(.18156624280757148139366685840064601, 1. - 3. * (.18156624280757148139366685840064601),
          .18156624280757148139366685840064601),
       .02125705756007566772097136088386650),    // 15 60
  PQP3(R3(.18156624280757148139366685840064601, .18156624280757148139366685840064601,
          1. - 3. * (.18156624280757148139366685840064601)),
       .02125705756007566772097136088386650),    // 16 64
  PQP3(R3(.00428160639152879988718710754508354, .5 - (.00428160639152879988718710754508354),
          .5 - (.00428160639152879988718710754508354)),
       .00077331890737182713690269661719116),    // 17 68
  PQP3(R3(.5 - (.00428160639152879988718710754508354), .00428160639152879988718710754508354,
          .5 - (.00428160639152879988718710754508354)),
       .00077331890737182713690269661719116),    // 18 72
  PQP3(R3(.5 - (.00428160639152879988718710754508354), .5 - (.00428160639152879988718710754508354),
          .00428160639152879988718710754508354),
       .00077331890737182713690269661719116),    // 19 76
  PQP3(R3(.00428160639152879988718710754508354, .5 - (.00428160639152879988718710754508354),
          .00428160639152879988718710754508354),
       .00077331890737182713690269661719116),    // 20 80
  PQP3(R3(.00428160639152879988718710754508354, .00428160639152879988718710754508354,
          .5 - (.00428160639152879988718710754508354)),
       .00077331890737182713690269661719116),    // 21 84
  PQP3(R3(.5 - (.00428160639152879988718710754508354), .00428160639152879988718710754508354,
          .00428160639152879988718710754508354),
       .00077331890737182713690269661719116),    // 22 88
  PQP3(R3(.12290357421888442998582785890620434, .5 - (.12290357421888442998582785890620434),
          .5 - (.12290357421888442998582785890620434)),
       .01755491389570430512641028370006205),    // 23 92
  PQP3(R3(.5 - (.12290357421888442998582785890620434), .12290357421888442998582785890620434,
          .5 - (.12290357421888442998582785890620434)),
       .01755491389570430512641028370006205),    // 24 96
  PQP3(R3(.5 - (.12290357421888442998582785890620434), .5 - (.12290357421888442998582785890620434),
          .12290357421888442998582785890620434),
       .01755491389570430512641028370006205),    // 25 100
  PQP3(R3(.12290357421888442998582785890620434, .5 - (.12290357421888442998582785890620434),
          .12290357421888442998582785890620434),
       .01755491389570430512641028370006205),    // 26 104
  PQP3(R3(.12290357421888442998582785890620434, .12290357421888442998582785890620434,
          .5 - (.12290357421888442998582785890620434)),
       .01755491389570430512641028370006205),    // 27 108
  PQP3(R3(.5 - (.12290357421888442998582785890620434), .12290357421888442998582785890620434,
          .12290357421888442998582785890620434),
       .01755491389570430512641028370006205),    // 28 112
  PQP3(R3(.28318219770202728236417353077594322, .43037955664247500440987356786807501,
          1. - (.28318219770202728236417353077594322) - (.28318219770202728236417353077594322) -
            (.43037955664247500440987356786807501)),
       .00213830361001659899343287397434178),    // 29 116
  PQP3(R3(.28318219770202728236417353077594322,
          1. - (.28318219770202728236417353077594322) - (.28318219770202728236417353077594322) -
            (.43037955664247500440987356786807501),
          .43037955664247500440987356786807501),
       .00213830361001659899343287397434178),    // 30 120
  PQP3(R3(.43037955664247500440987356786807501, .28318219770202728236417353077594322,
          1. - (.28318219770202728236417353077594322) - (.28318219770202728236417353077594322) -
            (.43037955664247500440987356786807501)),
       .00213830361001659899343287397434178),    // 31 124
  PQP3(R3(.43037955664247500440987356786807501,
          1. - (.28318219770202728236417353077594322) - (.28318219770202728236417353077594322) -
            (.43037955664247500440987356786807501),
          .28318219770202728236417353077594322),
       .00213830361001659899343287397434178),    // 32 128
  PQP3(R3(1. - (.28318219770202728236417353077594322) - (.28318219770202728236417353077594322) -
            (.43037955664247500440987356786807501),
          .28318219770202728236417353077594322, .43037955664247500440987356786807501),
       .00213830361001659899343287397434178),    // 33 132
  PQP3(R3(1. - (.28318219770202728236417353077594322) - (.28318219770202728236417353077594322) -
            (.43037955664247500440987356786807501),
          .43037955664247500440987356786807501, .28318219770202728236417353077594322),
       .00213830361001659899343287397434178),    // 34 136
  PQP3(R3(.28318219770202728236417353077594322, .28318219770202728236417353077594322,
          1. - (.28318219770202728236417353077594322) - (.28318219770202728236417353077594322) -
            (.43037955664247500440987356786807501)),
       .00213830361001659899343287397434178),    // 35 140
  PQP3(R3(.28318219770202728236417353077594322,
          1. - (.28318219770202728236417353077594322) - (.28318219770202728236417353077594322) -
            (.43037955664247500440987356786807501),
          .28318219770202728236417353077594322),
       .00213830361001659899343287397434178),    // 36 144
  PQP3(R3(1. - (.28318219770202728236417353077594322) - (.28318219770202728236417353077594322) -
            (.43037955664247500440987356786807501),
          .28318219770202728236417353077594322, .28318219770202728236417353077594322),
       .00213830361001659899343287397434178),    // 37 148
  PQP3(R3(.28318219770202728236417353077594322, .28318219770202728236417353077594322,
          .43037955664247500440987356786807501),
       .00213830361001659899343287397434178),    // 38 152
  PQP3(R3(.28318219770202728236417353077594322, .43037955664247500440987356786807501,
          .28318219770202728236417353077594322),
       .00213830361001659899343287397434178),    // 39 156
  PQP3(R3(.43037955664247500440987356786807501, .28318219770202728236417353077594322,
          .28318219770202728236417353077594322),
       .00213830361001659899343287397434178),    // 40 160
  PQP3(R3(.02239485904524970717572425710098278, .83488749018470024820940398932904512,
          1. - (.02239485904524970717572425710098278) - (.02239485904524970717572425710098278) -
            (.83488749018470024820940398932904512)),
       .00256560169283338620814651902766716),    // 41 164
  PQP3(R3(.02239485904524970717572425710098278,
          1. - (.02239485904524970717572425710098278) - (.02239485904524970717572425710098278) -
            (.83488749018470024820940398932904512),
          .83488749018470024820940398932904512),
       .00256560169283338620814651902766716),    // 42 168
  PQP3(R3(.83488749018470024820940398932904512, .02239485904524970717572425710098278,
          1. - (.02239485904524970717572425710098278) - (.02239485904524970717572425710098278) -
            (.83488749018470024820940398932904512)),
       .00256560169283338620814651902766716),    // 43 172
  PQP3(R3(.83488749018470024820940398932904512,
          1. - (.02239485904524970717572425710098278) - (.02239485904524970717572425710098278) -
            (.83488749018470024820940398932904512),
          .02239485904524970717572425710098278),
       .00256560169283338620814651902766716),    // 44 176
  PQP3(R3(1. - (.02239485904524970717572425710098278) - (.02239485904524970717572425710098278) -
            (.83488749018470024820940398932904512),
          .02239485904524970717572425710098278, .83488749018470024820940398932904512),
       .00256560169283338620814651902766716),    // 45 180
  PQP3(R3(1. - (.02239485904524970717572425710098278) - (.02239485904524970717572425710098278) -
            (.83488749018470024820940398932904512),
          .83488749018470024820940398932904512, .02239485904524970717572425710098278),
       .00256560169283338620814651902766716),    // 46 184
  PQP3(R3(.02239485904524970717572425710098278, .02239485904524970717572425710098278,
          1. - (.02239485904524970717572425710098278) - (.02239485904524970717572425710098278) -
            (.83488749018470024820940398932904512)),
       .00256560169283338620814651902766716),    // 47 188
  PQP3(R3(.02239485904524970717572425710098278,
          1. - (.02239485904524970717572425710098278) - (.02239485904524970717572425710098278) -
            (.83488749018470024820940398932904512),
          .02239485904524970717572425710098278),
       .00256560169283338620814651902766716),    // 48 192
  PQP3(R3(1. - (.02239485904524970717572425710098278) - (.02239485904524970717572425710098278) -
            (.83488749018470024820940398932904512),
          .02239485904524970717572425710098278, .02239485904524970717572425710098278),
       .00256560169283338620814651902766716),    // 49 196
  PQP3(R3(.02239485904524970717572425710098278, .02239485904524970717572425710098278,
          .83488749018470024820940398932904512),
       .00256560169283338620814651902766716),    // 50 200
  PQP3(R3(.02239485904524970717572425710098278, .83488749018470024820940398932904512,
          .02239485904524970717572425710098278),
       .00256560169283338620814651902766716),    // 51 204
  PQP3(R3(.83488749018470024820940398932904512, .02239485904524970717572425710098278,
          .02239485904524970717572425710098278),
       .00256560169283338620814651902766716),    // 52 208
  PQP3(R3(.02191788402113435132324662419880111, .67691762094326571059673391273529166,
          1. - (.02191788402113435132324662419880111) - (.02191788402113435132324662419880111) -
            (.67691762094326571059673391273529166)),
       .00338953948455728203040932651810398),    // 53 212
  PQP3(R3(.02191788402113435132324662419880111,
          1. - (.02191788402113435132324662419880111) - (.02191788402113435132324662419880111) -
            (.67691762094326571059673391273529166),
          .67691762094326571059673391273529166),
       .00338953948455728203040932651810398),    // 54 216
  PQP3(R3(.67691762094326571059673391273529166, .02191788402113435132324662419880111,
          1. - (.02191788402113435132324662419880111) - (.02191788402113435132324662419880111) -
            (.67691762094326571059673391273529166)),
       .00338953948455728203040932651810398),    // 55 220
  PQP3(R3(.67691762094326571059673391273529166,
          1. - (.02191788402113435132324662419880111) - (.02191788402113435132324662419880111) -
            (.67691762094326571059673391273529166),
          .02191788402113435132324662419880111),
       .00338953948455728203040932651810398),    // 56 224
  PQP3(R3(1. - (.02191788402113435132324662419880111) - (.02191788402113435132324662419880111) -
            (.67691762094326571059673391273529166),
          .02191788402113435132324662419880111, .67691762094326571059673391273529166),
       .00338953948455728203040932651810398),    // 57 228
  PQP3(R3(1. - (.02191788402113435132324662419880111) - (.02191788402113435132324662419880111) -
            (.67691762094326571059673391273529166),
          .67691762094326571059673391273529166, .02191788402113435132324662419880111),
       .00338953948455728203040932651810398),    // 58 232
  PQP3(R3(.02191788402113435132324662419880111, .02191788402113435132324662419880111,
          1. - (.02191788402113435132324662419880111) - (.02191788402113435132324662419880111) -
            (.67691762094326571059673391273529166)),
       .00338953948455728203040932651810398),    // 59 236
  PQP3(R3(.02191788402113435132324662419880111,
          1. - (.02191788402113435132324662419880111) - (.02191788402113435132324662419880111) -
            (.67691762094326571059673391273529166),
          .02191788402113435132324662419880111),
       .00338953948455728203040932651810398),    // 60 240
  PQP3(R3(1. - (.02191788402113435132324662419880111) - (.02191788402113435132324662419880111) -
            (.67691762094326571059673391273529166),
          .02191788402113435132324662419880111, .02191788402113435132324662419880111),
       .00338953948455728203040932651810398),    // 61 244
  PQP3(R3(.02191788402113435132324662419880111, .02191788402113435132324662419880111,
          .67691762094326571059673391273529166),
       .00338953948455728203040932651810398),    // 62 248
  PQP3(R3(.02191788402113435132324662419880111, .67691762094326571059673391273529166,
          .02191788402113435132324662419880111),
       .00338953948455728203040932651810398),    // 63 252
  PQP3(R3(.67691762094326571059673391273529166, .02191788402113435132324662419880111,
          .02191788402113435132324662419880111),
       .00338953948455728203040932651810398),    // 64 256
  PQP3(R3(.21481417044274656673534260788169227, .52280311286258745560867693994038579,
          1. - (.21481417044274656673534260788169227) - (.21481417044274656673534260788169227) -
            (.52280311286258745560867693994038579)),
       .01135828330503278417235563981454793),    // 65 260
  PQP3(R3(.21481417044274656673534260788169227,
          1. - (.21481417044274656673534260788169227) - (.21481417044274656673534260788169227) -
            (.52280311286258745560867693994038579),
          .52280311286258745560867693994038579),
       .01135828330503278417235563981454793),    // 66 264
  PQP3(R3(.52280311286258745560867693994038579, .21481417044274656673534260788169227,
          1. - (.21481417044274656673534260788169227) - (.21481417044274656673534260788169227) -
            (.52280311286258745560867693994038579)),
       .01135828330503278417235563981454793),    // 67 268
  PQP3(R3(.52280311286258745560867693994038579,
          1. - (.21481417044274656673534260788169227) - (.21481417044274656673534260788169227) -
            (.52280311286258745560867693994038579),
          .21481417044274656673534260788169227),
       .01135828330503278417235563981454793),    // 68 272
  PQP3(R3(1. - (.21481417044274656673534260788169227) - (.21481417044274656673534260788169227) -
            (.52280311286258745560867693994038579),
          .21481417044274656673534260788169227, .52280311286258745560867693994038579),
       .01135828330503278417235563981454793),    // 69 276
  PQP3(R3(1. - (.21481417044274656673534260788169227) - (.21481417044274656673534260788169227) -
            (.52280311286258745560867693994038579),
          .52280311286258745560867693994038579, .21481417044274656673534260788169227),
       .01135828330503278417235563981454793),    // 70 280
  PQP3(R3(.21481417044274656673534260788169227, .21481417044274656673534260788169227,
          1. - (.21481417044274656673534260788169227) - (.21481417044274656673534260788169227) -
            (.52280311286258745560867693994038579)),
       .01135828330503278417235563981454793),    // 71 284
  PQP3(R3(.21481417044274656673534260788169227,
          1. - (.21481417044274656673534260788169227) - (.21481417044274656673534260788169227) -
            (.52280311286258745560867693994038579),
          .21481417044274656673534260788169227),
       .01135828330503278417235563981454793),    // 72 288
  PQP3(R3(1. - (.21481417044274656673534260788169227) - (.21481417044274656673534260788169227) -
            (.52280311286258745560867693994038579),
          .21481417044274656673534260788169227, .21481417044274656673534260788169227),
       .01135828330503278417235563981454793),    // 73 292
  PQP3(R3(.21481417044274656673534260788169227, .21481417044274656673534260788169227,
          .52280311286258745560867693994038579),
       .01135828330503278417235563981454793),    // 74 296
  PQP3(R3(.21481417044274656673534260788169227, .52280311286258745560867693994038579,
          .21481417044274656673534260788169227),
       .01135828330503278417235563981454793),    // 75 300
  PQP3(R3(.52280311286258745560867693994038579, .21481417044274656673534260788169227,
          .21481417044274656673534260788169227),
       .01135828330503278417235563981454793),    // 76 304
  PQP3(R3(.08000490008644308882018405418010744, .24689045570275147370034631014113188,
          1. - (.08000490008644308882018405418010744) - (.08000490008644308882018405418010744) -
            (.24689045570275147370034631014113188)),
       .01103203882197761043040360052454856),    // 77 308
  PQP3(R3(.08000490008644308882018405418010744,
          1. - (.08000490008644308882018405418010744) - (.08000490008644308882018405418010744) -
            (.24689045570275147370034631014113188),
          .24689045570275147370034631014113188),
       .01103203882197761043040360052454856),    // 78 312
  PQP3(R3(.24689045570275147370034631014113188, .08000490008644308882018405418010744,
          1. - (.08000490008644308882018405418010744) - (.08000490008644308882018405418010744) -
            (.24689045570275147370034631014113188)),
       .01103203882197761043040360052454856),    // 79 316
  PQP3(R3(.24689045570275147370034631014113188,
          1. - (.08000490008644308882018405418010744) - (.08000490008644308882018405418010744) -
            (.24689045570275147370034631014113188),
          .08000490008644308882018405418010744),
       .01103203882197761043040360052454856),    // 80 320
  PQP3(R3(1. - (.08000490008644308882018405418010744) - (.08000490008644308882018405418010744) -
            (.24689045570275147370034631014113188),
          .08000490008644308882018405418010744, .24689045570275147370034631014113188),
       .01103203882197761043040360052454856),    // 81 324
  PQP3(R3(1. - (.08000490008644308882018405418010744) - (.08000490008644308882018405418010744) -
            (.24689045570275147370034631014113188),
          .24689045570275147370034631014113188, .08000490008644308882018405418010744),
       .01103203882197761043040360052454856),    // 82 328
  PQP3(R3(.08000490008644308882018405418010744, .08000490008644308882018405418010744,
          1. - (.08000490008644308882018405418010744) - (.08000490008644308882018405418010744) -
            (.24689045570275147370034631014113188)),
       .01103203882197761043040360052454856),    // 83 332
  PQP3(R3(.08000490008644308882018405418010744,
          1. - (.08000490008644308882018405418010744) - (.08000490008644308882018405418010744) -
            (.24689045570275147370034631014113188),
          .08000490008644308882018405418010744),
       .01103203882197761043040360052454856),    // 84 336
  PQP3(R3(1. - (.08000490008644308882018405418010744) - (.08000490008644308882018405418010744) -
            (.24689045570275147370034631014113188),
          .08000490008644308882018405418010744, .08000490008644308882018405418010744),
       .01103203882197761043040360052454856),    // 85 340
  PQP3(R3(.08000490008644308882018405418010744, .08000490008644308882018405418010744,
          .24689045570275147370034631014113188),
       .01103203882197761043040360052454856),    // 86 344
  PQP3(R3(.08000490008644308882018405418010744, .24689045570275147370034631014113188,
          .08000490008644308882018405418010744),
       .01103203882197761043040360052454856),    // 87 348
  PQP3(R3(.24689045570275147370034631014113188, .08000490008644308882018405418010744,
          .08000490008644308882018405418010744),
       .01103203882197761043040360052454856),    // 88 352
  PQP3(R3(.11579466150271899371721034492503850, .74997281767443310000000000000000000,
          1. - (.11579466150271899371721034492503850) - (.11579466150271899371721034492503850) -
            (.74997281767443310000000000000000000)),
       .00457602573785952356043458354199517),    // 89 356
  PQP3(R3(.11579466150271899371721034492503850,
          1. - (.11579466150271899371721034492503850) - (.11579466150271899371721034492503850) -
            (.74997281767443310000000000000000000),
          .74997281767443310000000000000000000),
       .00457602573785952356043458354199517),    // 90 360
  PQP3(R3(.74997281767443310000000000000000000, .11579466150271899371721034492503850,
          1. - (.11579466150271899371721034492503850) - (.11579466150271899371721034492503850) -
            (.74997281767443310000000000000000000)),
       .00457602573785952356043458354199517),    // 91 364
  PQP3(R3(.74997281767443310000000000000000000,
          1. - (.11579466150271899371721034492503850) - (.11579466150271899371721034492503850) -
            (.74997281767443310000000000000000000),
          .11579466150271899371721034492503850),
       .00457602573785952356043458354199517),    // 92 368
  PQP3(R3(1. - (.11579466150271899371721034492503850) - (.11579466150271899371721034492503850) -
            (.74997281767443310000000000000000000),
          .11579466150271899371721034492503850, .74997281767443310000000000000000000),
       .00457602573785952356043458354199517),    // 93 372
  PQP3(R3(1. - (.11579466150271899371721034492503850) - (.11579466150271899371721034492503850) -
            (.74997281767443310000000000000000000),
          .74997281767443310000000000000000000, .11579466150271899371721034492503850),
       .00457602573785952356043458354199517),    // 94 376
  PQP3(R3(.11579466150271899371721034492503850, .11579466150271899371721034492503850,
          1. - (.11579466150271899371721034492503850) - (.11579466150271899371721034492503850) -
            (.74997281767443310000000000000000000)),
       .00457602573785952356043458354199517),    // 95 380
  PQP3(R3(.11579466150271899371721034492503850,
          1. - (.11579466150271899371721034492503850) - (.11579466150271899371721034492503850) -
            (.74997281767443310000000000000000000),
          .11579466150271899371721034492503850),
       .00457602573785952356043458354199517),    // 96 384
  PQP3(R3(1. - (.11579466150271899371721034492503850) - (.11579466150271899371721034492503850) -
            (.74997281767443310000000000000000000),
          .11579466150271899371721034492503850, .11579466150271899371721034492503850),
       .00457602573785952356043458354199517),    // 97 388
  PQP3(R3(.11579466150271899371721034492503850, .11579466150271899371721034492503850,
          .74997281767443310000000000000000000),
       .00457602573785952356043458354199517),    // 98 392
  PQP3(R3(.11579466150271899371721034492503850, .74997281767443310000000000000000000,
          .11579466150271899371721034492503850),
       .00457602573785952356043458354199517),    // 99 396
  PQP3(R3(.74997281767443310000000000000000000, .11579466150271899371721034492503850,
          .11579466150271899371721034492503850),
       .00457602573785952356043458354199517),    // 100 400
  PQP3(R3(.39129315347000474438672195978809687, .18835457382799180000000000000000000,
          1. - (.39129315347000474438672195978809687) - (.39129315347000474438672195978809687) -
            (.18835457382799180000000000000000000)),
       .00827343104220868129752243222682095),    // 101 404
  PQP3(R3(.39129315347000474438672195978809687,
          1. - (.39129315347000474438672195978809687) - (.39129315347000474438672195978809687) -
            (.18835457382799180000000000000000000),
          .18835457382799180000000000000000000),
       .00827343104220868129752243222682095),    // 102 408
  PQP3(R3(.18835457382799180000000000000000000, .39129315347000474438672195978809687,
          1. - (.39129315347000474438672195978809687) - (.39129315347000474438672195978809687) -
            (.18835457382799180000000000000000000)),
       .00827343104220868129752243222682095),    // 103 412
  PQP3(R3(.18835457382799180000000000000000000,
          1. - (.39129315347000474438672195978809687) - (.39129315347000474438672195978809687) -
            (.18835457382799180000000000000000000),
          .39129315347000474438672195978809687),
       .00827343104220868129752243222682095),    // 104 416
  PQP3(R3(1. - (.39129315347000474438672195978809687) - (.39129315347000474438672195978809687) -
            (.18835457382799180000000000000000000),
          .39129315347000474438672195978809687, .18835457382799180000000000000000000),
       .00827343104220868129752243222682095),    // 105 420
  PQP3(R3(1. - (.39129315347000474438672195978809687) - (.39129315347000474438672195978809687) -
            (.18835457382799180000000000000000000),
          .18835457382799180000000000000000000, .39129315347000474438672195978809687),
       .00827343104220868129752243222682095),    // 106 424
  PQP3(R3(.39129315347000474438672195978809687, .39129315347000474438672195978809687,
          1. - (.39129315347000474438672195978809687) - (.39129315347000474438672195978809687) -
            (.18835457382799180000000000000000000)),
       .00827343104220868129752243222682095),    // 107 428
  PQP3(R3(.39129315347000474438672195978809687,
          1. - (.39129315347000474438672195978809687) - (.39129315347000474438672195978809687) -
            (.18835457382799180000000000000000000),
          .39129315347000474438672195978809687),
       .00827343104220868129752243222682095),    // 108 432
  PQP3(R3(1. - (.39129315347000474438672195978809687) - (.39129315347000474438672195978809687) -
            (.18835457382799180000000000000000000),
          .39129315347000474438672195978809687, .39129315347000474438672195978809687),
       .00827343104220868129752243222682095),    // 109 436
  PQP3(R3(.39129315347000474438672195978809687, .39129315347000474438672195978809687,
          .18835457382799180000000000000000000),
       .00827343104220868129752243222682095),    // 110 440
  PQP3(R3(.39129315347000474438672195978809687, .18835457382799180000000000000000000,
          .39129315347000474438672195978809687),
       .00827343104220868129752243222682095),    // 111 444
  PQP3(R3(.18835457382799180000000000000000000, .39129315347000474438672195978809687,
          .39129315347000474438672195978809687),
       .00827343104220868129752243222682095),    // 112 448
  PQP3(R3(.45315745821242834581317282468854978, .02202033169457796534173826092007299,
          1. - (.45315745821242834581317282468854978) - (.45315745821242834581317282468854978) -
            (.02202033169457796534173826092007299)),
       .00586641165391940007076312979369247),    // 113 452
  PQP3(R3(.45315745821242834581317282468854978,
          1. - (.45315745821242834581317282468854978) - (.45315745821242834581317282468854978) -
            (.02202033169457796534173826092007299),
          .02202033169457796534173826092007299),
       .00586641165391940007076312979369247),    // 114 456
  PQP3(R3(.02202033169457796534173826092007299, .45315745821242834581317282468854978,
          1. - (.45315745821242834581317282468854978) - (.45315745821242834581317282468854978) -
            (.02202033169457796534173826092007299)),
       .00586641165391940007076312979369247),    // 115 460
  PQP3(R3(.02202033169457796534173826092007299,
          1. - (.45315745821242834581317282468854978) - (.45315745821242834581317282468854978) -
            (.02202033169457796534173826092007299),
          .45315745821242834581317282468854978),
       .00586641165391940007076312979369247),    // 116 464
  PQP3(R3(1. - (.45315745821242834581317282468854978) - (.45315745821242834581317282468854978) -
            (.02202033169457796534173826092007299),
          .45315745821242834581317282468854978, .02202033169457796534173826092007299),
       .00586641165391940007076312979369247),    // 117 468
  PQP3(R3(1. - (.45315745821242834581317282468854978) - (.45315745821242834581317282468854978) -
            (.02202033169457796534173826092007299),
          .02202033169457796534173826092007299, .45315745821242834581317282468854978),
       .00586641165391940007076312979369247),    // 118 472
  PQP3(R3(.45315745821242834581317282468854978, .45315745821242834581317282468854978,
          1. - (.45315745821242834581317282468854978) - (.45315745821242834581317282468854978) -
            (.02202033169457796534173826092007299)),
       .00586641165391940007076312979369247),    // 119 476
  PQP3(R3(.45315745821242834581317282468854978,
          1. - (.45315745821242834581317282468854978) - (.45315745821242834581317282468854978) -
            (.02202033169457796534173826092007299),
          .45315745821242834581317282468854978),
       .00586641165391940007076312979369247),    // 120 480
  PQP3(R3(1. - (.45315745821242834581317282468854978) - (.45315745821242834581317282468854978) -
            (.02202033169457796534173826092007299),
          .45315745821242834581317282468854978, .45315745821242834581317282468854978),
       .00586641165391940007076312979369247),    // 121 484
  PQP3(R3(.45315745821242834581317282468854978, .45315745821242834581317282468854978,
          .02202033169457796534173826092007299),
       .00586641165391940007076312979369247),    // 122 488
  PQP3(R3(.45315745821242834581317282468854978, .02202033169457796534173826092007299,
          .45315745821242834581317282468854978),
       .00586641165391940007076312979369247),    // 123 492
  PQP3(R3(.02202033169457796534173826092007299, .45315745821242834581317282468854978,
          .45315745821242834581317282468854978),
       .00586641165391940007076312979369247),    // 124 496
  PQP3(R3(.60775441245653315696274741541102470, .00561877924700169073874366184065955,
          1. - (.27324999892429634023602493512400674) - (.60775441245653315696274741541102470) -
            (.00561877924700169073874366184065955)),
       .00313458521939849614410720196518793),    // 125 500
  PQP3(R3(.60775441245653315696274741541102470,
          1. - (.27324999892429634023602493512400674) - (.60775441245653315696274741541102470) -
            (.00561877924700169073874366184065955),
          .00561877924700169073874366184065955),
       .00313458521939849614410720196518793),    // 126 504
  PQP3(R3(.00561877924700169073874366184065955, .60775441245653315696274741541102470,
          1. - (.27324999892429634023602493512400674) - (.60775441245653315696274741541102470) -
            (.00561877924700169073874366184065955)),
       .00313458521939849614410720196518793),    // 127 508
  PQP3(R3(.00561877924700169073874366184065955,
          1. - (.27324999892429634023602493512400674) - (.60775441245653315696274741541102470) -
            (.00561877924700169073874366184065955),
          .60775441245653315696274741541102470),
       .00313458521939849614410720196518793),    // 128 512
  PQP3(R3(1. - (.27324999892429634023602493512400674) - (.60775441245653315696274741541102470) -
            (.00561877924700169073874366184065955),
          .60775441245653315696274741541102470, .00561877924700169073874366184065955),
       .00313458521939849614410720196518793),    // 129 516
  PQP3(R3(1. - (.27324999892429634023602493512400674) - (.60775441245653315696274741541102470) -
            (.00561877924700169073874366184065955),
          .00561877924700169073874366184065955, .60775441245653315696274741541102470),
       .00313458521939849614410720196518793),    // 130 520
  PQP3(R3(.27324999892429634023602493512400674, .00561877924700169073874366184065955,
          1. - (.27324999892429634023602493512400674) - (.60775441245653315696274741541102470) -
            (.00561877924700169073874366184065955)),
       .00313458521939849614410720196518793),    // 131 524
  PQP3(R3(.27324999892429634023602493512400674,
          1. - (.27324999892429634023602493512400674) - (.60775441245653315696274741541102470) -
            (.00561877924700169073874366184065955),
          .00561877924700169073874366184065955),
       .00313458521939849614410720196518793),    // 132 528
  PQP3(R3(.00561877924700169073874366184065955, .27324999892429634023602493512400674,
          1. - (.27324999892429634023602493512400674) - (.60775441245653315696274741541102470) -
            (.00561877924700169073874366184065955)),
       .00313458521939849614410720196518793),    // 133 532
  PQP3(R3(.00561877924700169073874366184065955,
          1. - (.27324999892429634023602493512400674) - (.60775441245653315696274741541102470) -
            (.00561877924700169073874366184065955),
          .27324999892429634023602493512400674),
       .00313458521939849614410720196518793),    // 134 536
  PQP3(R3(1. - (.27324999892429634023602493512400674) - (.60775441245653315696274741541102470) -
            (.00561877924700169073874366184065955),
          .27324999892429634023602493512400674, .00561877924700169073874366184065955),
       .00313458521939849614410720196518793),    // 135 540
  PQP3(R3(1. - (.27324999892429634023602493512400674) - (.60775441245653315696274741541102470) -
            (.00561877924700169073874366184065955),
          .00561877924700169073874366184065955, .27324999892429634023602493512400674),
       .00313458521939849614410720196518793),    // 136 544
  PQP3(R3(.27324999892429634023602493512400674, .60775441245653315696274741541102470,
          1. - (.27324999892429634023602493512400674) - (.60775441245653315696274741541102470) -
            (.00561877924700169073874366184065955)),
       .00313458521939849614410720196518793),    // 137 548
  PQP3(R3(.27324999892429634023602493512400674,
          1. - (.27324999892429634023602493512400674) - (.60775441245653315696274741541102470) -
            (.00561877924700169073874366184065955),
          .60775441245653315696274741541102470),
       .00313458521939849614410720196518793),    // 138 552
  PQP3(R3(.60775441245653315696274741541102470, .27324999892429634023602493512400674,
          1. - (.27324999892429634023602493512400674) - (.60775441245653315696274741541102470) -
            (.00561877924700169073874366184065955)),
       .00313458521939849614410720196518793),    // 139 556
  PQP3(R3(.60775441245653315696274741541102470,
          1. - (.27324999892429634023602493512400674) - (.60775441245653315696274741541102470) -
            (.00561877924700169073874366184065955),
          .27324999892429634023602493512400674),
       .00313458521939849614410720196518793),    // 140 560
  PQP3(R3(1. - (.27324999892429634023602493512400674) - (.60775441245653315696274741541102470) -
            (.00561877924700169073874366184065955),
          .27324999892429634023602493512400674, .60775441245653315696274741541102470),
       .00313458521939849614410720196518793),    // 141 564
  PQP3(R3(1. - (.27324999892429634023602493512400674) - (.60775441245653315696274741541102470) -
            (.00561877924700169073874366184065955),
          .60775441245653315696274741541102470, .27324999892429634023602493512400674),
       .00313458521939849614410720196518793),    // 142 568
  PQP3(R3(.27324999892429634023602493512400674, .60775441245653315696274741541102470,
          .00561877924700169073874366184065955),
       .00313458521939849614410720196518793),    // 143 572
  PQP3(R3(.27324999892429634023602493512400674, .00561877924700169073874366184065955,
          .60775441245653315696274741541102470),
       .00313458521939849614410720196518793),    // 144 576
  PQP3(R3(.60775441245653315696274741541102470, .27324999892429634023602493512400674,
          .00561877924700169073874366184065955),
       .00313458521939849614410720196518793),    // 145 580
  PQP3(R3(.60775441245653315696274741541102470, .00561877924700169073874366184065955,
          .27324999892429634023602493512400674),
       .00313458521939849614410720196518793),    // 146 584
  PQP3(R3(.00561877924700169073874366184065955, .27324999892429634023602493512400674,
          .60775441245653315696274741541102470),
       .00313458521939849614410720196518793),    // 147 588
  PQP3(R3(.00561877924700169073874366184065955, .60775441245653315696274741541102470,
          .27324999892429634023602493512400674),
       .00313458521939849614410720196518793),    // 148 592
};
PQF3 const QuadratureFormular_Tet_P13(13, 149, QF_TET_P13);
// QUAD QUAD_3D_P14_ = { 194 776
PQP3 QF_TET_P14[] = {
  PQP3(R3(.12703434587701869604797950660749487, .12703434587701869604797950660749487,
          .12703434587701869604797950660749487),
       .00898427322254918127543126682598773),    // 0 0
  PQP3(R3(1. - 3. * (.12703434587701869604797950660749487), .12703434587701869604797950660749487,
          .12703434587701869604797950660749487),
       .00898427322254918127543126682598773),    // 1 4
  PQP3(R3(.12703434587701869604797950660749487, 1. - 3. * (.12703434587701869604797950660749487),
          .12703434587701869604797950660749487),
       .00898427322254918127543126682598773),    // 2 8
  PQP3(R3(.12703434587701869604797950660749487, .12703434587701869604797950660749487,
          1. - 3. * (.12703434587701869604797950660749487)),
       .00898427322254918127543126682598773),    // 3 12
  PQP3(R3(.03716308713428675181759859706979325, .03716308713428675181759859706979325,
          .03716308713428675181759859706979325),
       .00235414897468188299910869230818368),    // 4 16
  PQP3(R3(1. - 3. * (.03716308713428675181759859706979325), .03716308713428675181759859706979325,
          .03716308713428675181759859706979325),
       .00235414897468188299910869230818368),    // 5 20
  PQP3(R3(.03716308713428675181759859706979325, 1. - 3. * (.03716308713428675181759859706979325),
          .03716308713428675181759859706979325),
       .00235414897468188299910869230818368),    // 6 24
  PQP3(R3(.03716308713428675181759859706979325, .03716308713428675181759859706979325,
          1. - 3. * (.03716308713428675181759859706979325)),
       .00235414897468188299910869230818368),    // 7 28
  PQP3(R3(.30931161817607732544635505822019770, .30931161817607732544635505822019770,
          .30931161817607732544635505822019770),
       .00733553866836377016223467789336265),    // 8 32
  PQP3(R3(1. - 3. * (.30931161817607732544635505822019770), .30931161817607732544635505822019770,
          .30931161817607732544635505822019770),
       .00733553866836377016223467789336265),    // 9 36
  PQP3(R3(.30931161817607732544635505822019770, 1. - 3. * (.30931161817607732544635505822019770),
          .30931161817607732544635505822019770),
       .00733553866836377016223467789336265),    // 10 40
  PQP3(R3(.30931161817607732544635505822019770, .30931161817607732544635505822019770,
          1. - 3. * (.30931161817607732544635505822019770)),
       .00733553866836377016223467789336265),    // 11 44
  PQP3(R3(.07778813507287403019691221965639750, .07778813507287403019691221965639750,
          .07778813507287403019691221965639750),
       .00360629336228634011530354432318077),    // 12 48
  PQP3(R3(1. - 3. * (.07778813507287403019691221965639750), .07778813507287403019691221965639750,
          .07778813507287403019691221965639750),
       .00360629336228634011530354432318077),    // 13 52
  PQP3(R3(.07778813507287403019691221965639750, 1. - 3. * (.07778813507287403019691221965639750),
          .07778813507287403019691221965639750),
       .00360629336228634011530354432318077),    // 14 56
  PQP3(R3(.07778813507287403019691221965639750, .07778813507287403019691221965639750,
          1. - 3. * (.07778813507287403019691221965639750)),
       .00360629336228634011530354432318077),    // 15 60
  PQP3(R3(.01187611663683786502091234677477106, .01187611663683786502091234677477106,
          .01187611663683786502091234677477106),
       .00022796656022189240650071390651338),    // 16 64
  PQP3(R3(1. - 3. * (.01187611663683786502091234677477106), .01187611663683786502091234677477106,
          .01187611663683786502091234677477106),
       .00022796656022189240650071390651338),    // 17 68
  PQP3(R3(.01187611663683786502091234677477106, 1. - 3. * (.01187611663683786502091234677477106),
          .01187611663683786502091234677477106),
       .00022796656022189240650071390651338),    // 18 72
  PQP3(R3(.01187611663683786502091234677477106, .01187611663683786502091234677477106,
          1. - 3. * (.01187611663683786502091234677477106)),
       .00022796656022189240650071390651338),    // 19 76
  PQP3(R3(.02371189715571358237825633505545476, .5 - (.02371189715571358237825633505545476),
          .5 - (.02371189715571358237825633505545476)),
       .00425068731230945391542573203967906),    // 20 80
  PQP3(R3(.5 - (.02371189715571358237825633505545476), .02371189715571358237825633505545476,
          .5 - (.02371189715571358237825633505545476)),
       .00425068731230945391542573203967906),    // 21 84
  PQP3(R3(.5 - (.02371189715571358237825633505545476), .5 - (.02371189715571358237825633505545476),
          .02371189715571358237825633505545476),
       .00425068731230945391542573203967906),    // 22 88
  PQP3(R3(.02371189715571358237825633505545476, .5 - (.02371189715571358237825633505545476),
          .02371189715571358237825633505545476),
       .00425068731230945391542573203967906),    // 23 92
  PQP3(R3(.02371189715571358237825633505545476, .02371189715571358237825633505545476,
          .5 - (.02371189715571358237825633505545476)),
       .00425068731230945391542573203967906),    // 24 96
  PQP3(R3(.5 - (.02371189715571358237825633505545476), .02371189715571358237825633505545476,
          .02371189715571358237825633505545476),
       .00425068731230945391542573203967906),    // 25 100
  PQP3(R3(.04551422172971295738029708158398140, .73884882267833978290969755547076243,
          1. - (.04551422172971295738029708158398140) - (.04551422172971295738029708158398140) -
            (.73884882267833978290969755547076243)),
       .00502229674184657212637707578731437),    // 26 104
  PQP3(R3(.04551422172971295738029708158398140,
          1. - (.04551422172971295738029708158398140) - (.04551422172971295738029708158398140) -
            (.73884882267833978290969755547076243),
          .73884882267833978290969755547076243),
       .00502229674184657212637707578731437),    // 27 108
  PQP3(R3(.73884882267833978290969755547076243, .04551422172971295738029708158398140,
          1. - (.04551422172971295738029708158398140) - (.04551422172971295738029708158398140) -
            (.73884882267833978290969755547076243)),
       .00502229674184657212637707578731437),    // 28 112
  PQP3(R3(.73884882267833978290969755547076243,
          1. - (.04551422172971295738029708158398140) - (.04551422172971295738029708158398140) -
            (.73884882267833978290969755547076243),
          .04551422172971295738029708158398140),
       .00502229674184657212637707578731437),    // 29 116
  PQP3(R3(1. - (.04551422172971295738029708158398140) - (.04551422172971295738029708158398140) -
            (.73884882267833978290969755547076243),
          .04551422172971295738029708158398140, .73884882267833978290969755547076243),
       .00502229674184657212637707578731437),    // 30 120
  PQP3(R3(1. - (.04551422172971295738029708158398140) - (.04551422172971295738029708158398140) -
            (.73884882267833978290969755547076243),
          .73884882267833978290969755547076243, .04551422172971295738029708158398140),
       .00502229674184657212637707578731437),    // 31 124
  PQP3(R3(.04551422172971295738029708158398140, .04551422172971295738029708158398140,
          1. - (.04551422172971295738029708158398140) - (.04551422172971295738029708158398140) -
            (.73884882267833978290969755547076243)),
       .00502229674184657212637707578731437),    // 32 128
  PQP3(R3(.04551422172971295738029708158398140,
          1. - (.04551422172971295738029708158398140) - (.04551422172971295738029708158398140) -
            (.73884882267833978290969755547076243),
          .04551422172971295738029708158398140),
       .00502229674184657212637707578731437),    // 33 132
  PQP3(R3(1. - (.04551422172971295738029708158398140) - (.04551422172971295738029708158398140) -
            (.73884882267833978290969755547076243),
          .04551422172971295738029708158398140, .04551422172971295738029708158398140),
       .00502229674184657212637707578731437),    // 34 136
  PQP3(R3(.04551422172971295738029708158398140, .04551422172971295738029708158398140,
          .73884882267833978290969755547076243),
       .00502229674184657212637707578731437),    // 35 140
  PQP3(R3(.04551422172971295738029708158398140, .73884882267833978290969755547076243,
          .04551422172971295738029708158398140),
       .00502229674184657212637707578731437),    // 36 144
  PQP3(R3(.73884882267833978290969755547076243, .04551422172971295738029708158398140,
          .04551422172971295738029708158398140),
       .00502229674184657212637707578731437),    // 37 148
  PQP3(R3(.19457055431059420000000000000000000, .36138202354403612356128050094846106,
          1. - (.19457055431059420000000000000000000) - (.19457055431059420000000000000000000) -
            (.36138202354403612356128050094846106)),
       .00664105199619194276141547967835717),    // 38 152
  PQP3(R3(.19457055431059420000000000000000000,
          1. - (.19457055431059420000000000000000000) - (.19457055431059420000000000000000000) -
            (.36138202354403612356128050094846106),
          .36138202354403612356128050094846106),
       .00664105199619194276141547967835717),    // 39 156
  PQP3(R3(.36138202354403612356128050094846106, .19457055431059420000000000000000000,
          1. - (.19457055431059420000000000000000000) - (.19457055431059420000000000000000000) -
            (.36138202354403612356128050094846106)),
       .00664105199619194276141547967835717),    // 40 160
  PQP3(R3(.36138202354403612356128050094846106,
          1. - (.19457055431059420000000000000000000) - (.19457055431059420000000000000000000) -
            (.36138202354403612356128050094846106),
          .19457055431059420000000000000000000),
       .00664105199619194276141547967835717),    // 41 164
  PQP3(R3(1. - (.19457055431059420000000000000000000) - (.19457055431059420000000000000000000) -
            (.36138202354403612356128050094846106),
          .19457055431059420000000000000000000, .36138202354403612356128050094846106),
       .00664105199619194276141547967835717),    // 42 168
  PQP3(R3(1. - (.19457055431059420000000000000000000) - (.19457055431059420000000000000000000) -
            (.36138202354403612356128050094846106),
          .36138202354403612356128050094846106, .19457055431059420000000000000000000),
       .00664105199619194276141547967835717),    // 43 172
  PQP3(R3(.19457055431059420000000000000000000, .19457055431059420000000000000000000,
          1. - (.19457055431059420000000000000000000) - (.19457055431059420000000000000000000) -
            (.36138202354403612356128050094846106)),
       .00664105199619194276141547967835717),    // 44 176
  PQP3(R3(.19457055431059420000000000000000000,
          1. - (.19457055431059420000000000000000000) - (.19457055431059420000000000000000000) -
            (.36138202354403612356128050094846106),
          .19457055431059420000000000000000000),
       .00664105199619194276141547967835717),    // 45 180
  PQP3(R3(1. - (.19457055431059420000000000000000000) - (.19457055431059420000000000000000000) -
            (.36138202354403612356128050094846106),
          .19457055431059420000000000000000000, .19457055431059420000000000000000000),
       .00664105199619194276141547967835717),    // 46 184
  PQP3(R3(.19457055431059420000000000000000000, .19457055431059420000000000000000000,
          .36138202354403612356128050094846106),
       .00664105199619194276141547967835717),    // 47 188
  PQP3(R3(.19457055431059420000000000000000000, .36138202354403612356128050094846106,
          .19457055431059420000000000000000000),
       .00664105199619194276141547967835717),    // 48 192
  PQP3(R3(.36138202354403612356128050094846106, .19457055431059420000000000000000000,
          .19457055431059420000000000000000000),
       .00664105199619194276141547967835717),    // 49 196
  PQP3(R3(.42158193164647035846631052119479790, .13481021809330111977392354242291205,
          1. - (.42158193164647035846631052119479790) - (.42158193164647035846631052119479790) -
            (.13481021809330111977392354242291205)),
       .00648663075652078221084713724389357),    // 50 200
  PQP3(R3(.42158193164647035846631052119479790,
          1. - (.42158193164647035846631052119479790) - (.42158193164647035846631052119479790) -
            (.13481021809330111977392354242291205),
          .13481021809330111977392354242291205),
       .00648663075652078221084713724389357),    // 51 204
  PQP3(R3(.13481021809330111977392354242291205, .42158193164647035846631052119479790,
          1. - (.42158193164647035846631052119479790) - (.42158193164647035846631052119479790) -
            (.13481021809330111977392354242291205)),
       .00648663075652078221084713724389357),    // 52 208
  PQP3(R3(.13481021809330111977392354242291205,
          1. - (.42158193164647035846631052119479790) - (.42158193164647035846631052119479790) -
            (.13481021809330111977392354242291205),
          .42158193164647035846631052119479790),
       .00648663075652078221084713724389357),    // 53 212
  PQP3(R3(1. - (.42158193164647035846631052119479790) - (.42158193164647035846631052119479790) -
            (.13481021809330111977392354242291205),
          .42158193164647035846631052119479790, .13481021809330111977392354242291205),
       .00648663075652078221084713724389357),    // 54 216
  PQP3(R3(1. - (.42158193164647035846631052119479790) - (.42158193164647035846631052119479790) -
            (.13481021809330111977392354242291205),
          .13481021809330111977392354242291205, .42158193164647035846631052119479790),
       .00648663075652078221084713724389357),    // 55 220
  PQP3(R3(.42158193164647035846631052119479790, .42158193164647035846631052119479790,
          1. - (.42158193164647035846631052119479790) - (.42158193164647035846631052119479790) -
            (.13481021809330111977392354242291205)),
       .00648663075652078221084713724389357),    // 56 224
  PQP3(R3(.42158193164647035846631052119479790,
          1. - (.42158193164647035846631052119479790) - (.42158193164647035846631052119479790) -
            (.13481021809330111977392354242291205),
          .42158193164647035846631052119479790),
       .00648663075652078221084713724389357),    // 57 228
  PQP3(R3(1. - (.42158193164647035846631052119479790) - (.42158193164647035846631052119479790) -
            (.13481021809330111977392354242291205),
          .42158193164647035846631052119479790, .42158193164647035846631052119479790),
       .00648663075652078221084713724389357),    // 58 232
  PQP3(R3(.42158193164647035846631052119479790, .42158193164647035846631052119479790,
          .13481021809330111977392354242291205),
       .00648663075652078221084713724389357),    // 59 236
  PQP3(R3(.42158193164647035846631052119479790, .13481021809330111977392354242291205,
          .42158193164647035846631052119479790),
       .00648663075652078221084713724389357),    // 60 240
  PQP3(R3(.13481021809330111977392354242291205, .42158193164647035846631052119479790,
          .42158193164647035846631052119479790),
       .00648663075652078221084713724389357),    // 61 244
  PQP3(R3(.36227661803202431683389679069549247, .09100846759454444774082592541447308,
          1. - (.36227661803202431683389679069549247) - (.36227661803202431683389679069549247) -
            (.09100846759454444774082592541447308)),
       .01084924609520658118048627917429636),    // 62 248
  PQP3(R3(.36227661803202431683389679069549247,
          1. - (.36227661803202431683389679069549247) - (.36227661803202431683389679069549247) -
            (.09100846759454444774082592541447308),
          .09100846759454444774082592541447308),
       .01084924609520658118048627917429636),    // 63 252
  PQP3(R3(.09100846759454444774082592541447308, .36227661803202431683389679069549247,
          1. - (.36227661803202431683389679069549247) - (.36227661803202431683389679069549247) -
            (.09100846759454444774082592541447308)),
       .01084924609520658118048627917429636),    // 64 256
  PQP3(R3(.09100846759454444774082592541447308,
          1. - (.36227661803202431683389679069549247) - (.36227661803202431683389679069549247) -
            (.09100846759454444774082592541447308),
          .36227661803202431683389679069549247),
       .01084924609520658118048627917429636),    // 65 260
  PQP3(R3(1. - (.36227661803202431683389679069549247) - (.36227661803202431683389679069549247) -
            (.09100846759454444774082592541447308),
          .36227661803202431683389679069549247, .09100846759454444774082592541447308),
       .01084924609520658118048627917429636),    // 66 264
  PQP3(R3(1. - (.36227661803202431683389679069549247) - (.36227661803202431683389679069549247) -
            (.09100846759454444774082592541447308),
          .09100846759454444774082592541447308, .36227661803202431683389679069549247),
       .01084924609520658118048627917429636),    // 67 268
  PQP3(R3(.36227661803202431683389679069549247, .36227661803202431683389679069549247,
          1. - (.36227661803202431683389679069549247) - (.36227661803202431683389679069549247) -
            (.09100846759454444774082592541447308)),
       .01084924609520658118048627917429636),    // 68 272
  PQP3(R3(.36227661803202431683389679069549247,
          1. - (.36227661803202431683389679069549247) - (.36227661803202431683389679069549247) -
            (.09100846759454444774082592541447308),
          .36227661803202431683389679069549247),
       .01084924609520658118048627917429636),    // 69 276
  PQP3(R3(1. - (.36227661803202431683389679069549247) - (.36227661803202431683389679069549247) -
            (.09100846759454444774082592541447308),
          .36227661803202431683389679069549247, .36227661803202431683389679069549247),
       .01084924609520658118048627917429636),    // 70 280
  PQP3(R3(.36227661803202431683389679069549247, .36227661803202431683389679069549247,
          .09100846759454444774082592541447308),
       .01084924609520658118048627917429636),    // 71 284
  PQP3(R3(.36227661803202431683389679069549247, .09100846759454444774082592541447308,
          .36227661803202431683389679069549247),
       .01084924609520658118048627917429636),    // 72 288
  PQP3(R3(.09100846759454444774082592541447308, .36227661803202431683389679069549247,
          .36227661803202431683389679069549247),
       .01084924609520658118048627917429636),    // 73 292
  PQP3(R3(.26662003783461096351186917353420086, .45135951603290056428206454329600320,
          1. - (.26662003783461096351186917353420086) - (.26662003783461096351186917353420086) -
            (.45135951603290056428206454329600320)),
       .00698225572400728567899793615355807),    // 74 296
  PQP3(R3(.26662003783461096351186917353420086,
          1. - (.26662003783461096351186917353420086) - (.26662003783461096351186917353420086) -
            (.45135951603290056428206454329600320),
          .45135951603290056428206454329600320),
       .00698225572400728567899793615355807),    // 75 300
  PQP3(R3(.45135951603290056428206454329600320, .26662003783461096351186917353420086,
          1. - (.26662003783461096351186917353420086) - (.26662003783461096351186917353420086) -
            (.45135951603290056428206454329600320)),
       .00698225572400728567899793615355807),    // 76 304
  PQP3(R3(.45135951603290056428206454329600320,
          1. - (.26662003783461096351186917353420086) - (.26662003783461096351186917353420086) -
            (.45135951603290056428206454329600320),
          .26662003783461096351186917353420086),
       .00698225572400728567899793615355807),    // 77 308
  PQP3(R3(1. - (.26662003783461096351186917353420086) - (.26662003783461096351186917353420086) -
            (.45135951603290056428206454329600320),
          .26662003783461096351186917353420086, .45135951603290056428206454329600320),
       .00698225572400728567899793615355807),    // 78 312
  PQP3(R3(1. - (.26662003783461096351186917353420086) - (.26662003783461096351186917353420086) -
            (.45135951603290056428206454329600320),
          .45135951603290056428206454329600320, .26662003783461096351186917353420086),
       .00698225572400728567899793615355807),    // 79 316
  PQP3(R3(.26662003783461096351186917353420086, .26662003783461096351186917353420086,
          1. - (.26662003783461096351186917353420086) - (.26662003783461096351186917353420086) -
            (.45135951603290056428206454329600320)),
       .00698225572400728567899793615355807),    // 80 320
  PQP3(R3(.26662003783461096351186917353420086,
          1. - (.26662003783461096351186917353420086) - (.26662003783461096351186917353420086) -
            (.45135951603290056428206454329600320),
          .26662003783461096351186917353420086),
       .00698225572400728567899793615355807),    // 81 324
  PQP3(R3(1. - (.26662003783461096351186917353420086) - (.26662003783461096351186917353420086) -
            (.45135951603290056428206454329600320),
          .26662003783461096351186917353420086, .26662003783461096351186917353420086),
       .00698225572400728567899793615355807),    // 82 328
  PQP3(R3(.26662003783461096351186917353420086, .26662003783461096351186917353420086,
          .45135951603290056428206454329600320),
       .00698225572400728567899793615355807),    // 83 332
  PQP3(R3(.26662003783461096351186917353420086, .45135951603290056428206454329600320,
          .26662003783461096351186917353420086),
       .00698225572400728567899793615355807),    // 84 336
  PQP3(R3(.45135951603290056428206454329600320, .26662003783461096351186917353420086,
          .26662003783461096351186917353420086),
       .00698225572400728567899793615355807),    // 85 340
  PQP3(R3(.07870367664603755989163074150395650, .53854007868617855365162509332690316,
          1. - (.07870367664603755989163074150395650) - (.07870367664603755989163074150395650) -
            (.53854007868617855365162509332690316)),
       .01057643198113441258335538488635301),    // 86 344
  PQP3(R3(.07870367664603755989163074150395650,
          1. - (.07870367664603755989163074150395650) - (.07870367664603755989163074150395650) -
            (.53854007868617855365162509332690316),
          .53854007868617855365162509332690316),
       .01057643198113441258335538488635301),    // 87 348
  PQP3(R3(.53854007868617855365162509332690316, .07870367664603755989163074150395650,
          1. - (.07870367664603755989163074150395650) - (.07870367664603755989163074150395650) -
            (.53854007868617855365162509332690316)),
       .01057643198113441258335538488635301),    // 88 352
  PQP3(R3(.53854007868617855365162509332690316,
          1. - (.07870367664603755989163074150395650) - (.07870367664603755989163074150395650) -
            (.53854007868617855365162509332690316),
          .07870367664603755989163074150395650),
       .01057643198113441258335538488635301),    // 89 356
  PQP3(R3(1. - (.07870367664603755989163074150395650) - (.07870367664603755989163074150395650) -
            (.53854007868617855365162509332690316),
          .07870367664603755989163074150395650, .53854007868617855365162509332690316),
       .01057643198113441258335538488635301),    // 90 360
  PQP3(R3(1. - (.07870367664603755989163074150395650) - (.07870367664603755989163074150395650) -
            (.53854007868617855365162509332690316),
          .53854007868617855365162509332690316, .07870367664603755989163074150395650),
       .01057643198113441258335538488635301),    // 91 364
  PQP3(R3(.07870367664603755989163074150395650, .07870367664603755989163074150395650,
          1. - (.07870367664603755989163074150395650) - (.07870367664603755989163074150395650) -
            (.53854007868617855365162509332690316)),
       .01057643198113441258335538488635301),    // 92 368
  PQP3(R3(.07870367664603755989163074150395650,
          1. - (.07870367664603755989163074150395650) - (.07870367664603755989163074150395650) -
            (.53854007868617855365162509332690316),
          .07870367664603755989163074150395650),
       .01057643198113441258335538488635301),    // 93 372
  PQP3(R3(1. - (.07870367664603755989163074150395650) - (.07870367664603755989163074150395650) -
            (.53854007868617855365162509332690316),
          .07870367664603755989163074150395650, .07870367664603755989163074150395650),
       .01057643198113441258335538488635301),    // 94 376
  PQP3(R3(.07870367664603755989163074150395650, .07870367664603755989163074150395650,
          .53854007868617855365162509332690316),
       .01057643198113441258335538488635301),    // 95 380
  PQP3(R3(.07870367664603755989163074150395650, .53854007868617855365162509332690316,
          .07870367664603755989163074150395650),
       .01057643198113441258335538488635301),    // 96 384
  PQP3(R3(.53854007868617855365162509332690316, .07870367664603755989163074150395650,
          .07870367664603755989163074150395650),
       .01057643198113441258335538488635301),    // 97 388
  PQP3(R3(.01462604843949452202375023818416595, .68140642280720592407050422036244765,
          1. - (.01462604843949452202375023818416595) - (.01462604843949452202375023818416595) -
            (.68140642280720592407050422036244765)),
       .00172517387494940531214061228255136),    // 98 392
  PQP3(R3(.01462604843949452202375023818416595,
          1. - (.01462604843949452202375023818416595) - (.01462604843949452202375023818416595) -
            (.68140642280720592407050422036244765),
          .68140642280720592407050422036244765),
       .00172517387494940531214061228255136),    // 99 396
  PQP3(R3(.68140642280720592407050422036244765, .01462604843949452202375023818416595,
          1. - (.01462604843949452202375023818416595) - (.01462604843949452202375023818416595) -
            (.68140642280720592407050422036244765)),
       .00172517387494940531214061228255136),    // 100 400
  PQP3(R3(.68140642280720592407050422036244765,
          1. - (.01462604843949452202375023818416595) - (.01462604843949452202375023818416595) -
            (.68140642280720592407050422036244765),
          .01462604843949452202375023818416595),
       .00172517387494940531214061228255136),    // 101 404
  PQP3(R3(1. - (.01462604843949452202375023818416595) - (.01462604843949452202375023818416595) -
            (.68140642280720592407050422036244765),
          .01462604843949452202375023818416595, .68140642280720592407050422036244765),
       .00172517387494940531214061228255136),    // 102 408
  PQP3(R3(1. - (.01462604843949452202375023818416595) - (.01462604843949452202375023818416595) -
            (.68140642280720592407050422036244765),
          .68140642280720592407050422036244765, .01462604843949452202375023818416595),
       .00172517387494940531214061228255136),    // 103 412
  PQP3(R3(.01462604843949452202375023818416595, .01462604843949452202375023818416595,
          1. - (.01462604843949452202375023818416595) - (.01462604843949452202375023818416595) -
            (.68140642280720592407050422036244765)),
       .00172517387494940531214061228255136),    // 104 416
  PQP3(R3(.01462604843949452202375023818416595,
          1. - (.01462604843949452202375023818416595) - (.01462604843949452202375023818416595) -
            (.68140642280720592407050422036244765),
          .01462604843949452202375023818416595),
       .00172517387494940531214061228255136),    // 105 420
  PQP3(R3(1. - (.01462604843949452202375023818416595) - (.01462604843949452202375023818416595) -
            (.68140642280720592407050422036244765),
          .01462604843949452202375023818416595, .01462604843949452202375023818416595),
       .00172517387494940531214061228255136),    // 106 424
  PQP3(R3(.01462604843949452202375023818416595, .01462604843949452202375023818416595,
          .68140642280720592407050422036244765),
       .00172517387494940531214061228255136),    // 107 428
  PQP3(R3(.01462604843949452202375023818416595, .68140642280720592407050422036244765,
          .01462604843949452202375023818416595),
       .00172517387494940531214061228255136),    // 108 432
  PQP3(R3(.68140642280720592407050422036244765, .01462604843949452202375023818416595,
          .01462604843949452202375023818416595),
       .00172517387494940531214061228255136),    // 109 436
  PQP3(R3(.20755902173331721318141636044536441, .49641284136813420000000000000000000,
          1. - (.20755902173331721318141636044536441) - (.20755902173331721318141636044536441) -
            (.49641284136813420000000000000000000)),
       .01064026039260234415487304925754523),    // 110 440
  PQP3(R3(.20755902173331721318141636044536441,
          1. - (.20755902173331721318141636044536441) - (.20755902173331721318141636044536441) -
            (.49641284136813420000000000000000000),
          .49641284136813420000000000000000000),
       .01064026039260234415487304925754523),    // 111 444
  PQP3(R3(.49641284136813420000000000000000000, .20755902173331721318141636044536441,
          1. - (.20755902173331721318141636044536441) - (.20755902173331721318141636044536441) -
            (.49641284136813420000000000000000000)),
       .01064026039260234415487304925754523),    // 112 448
  PQP3(R3(.49641284136813420000000000000000000,
          1. - (.20755902173331721318141636044536441) - (.20755902173331721318141636044536441) -
            (.49641284136813420000000000000000000),
          .20755902173331721318141636044536441),
       .01064026039260234415487304925754523),    // 113 452
  PQP3(R3(1. - (.20755902173331721318141636044536441) - (.20755902173331721318141636044536441) -
            (.49641284136813420000000000000000000),
          .20755902173331721318141636044536441, .49641284136813420000000000000000000),
       .01064026039260234415487304925754523),    // 114 456
  PQP3(R3(1. - (.20755902173331721318141636044536441) - (.20755902173331721318141636044536441) -
            (.49641284136813420000000000000000000),
          .49641284136813420000000000000000000, .20755902173331721318141636044536441),
       .01064026039260234415487304925754523),    // 115 460
  PQP3(R3(.20755902173331721318141636044536441, .20755902173331721318141636044536441,
          1. - (.20755902173331721318141636044536441) - (.20755902173331721318141636044536441) -
            (.49641284136813420000000000000000000)),
       .01064026039260234415487304925754523),    // 116 464
  PQP3(R3(.20755902173331721318141636044536441,
          1. - (.20755902173331721318141636044536441) - (.20755902173331721318141636044536441) -
            (.49641284136813420000000000000000000),
          .20755902173331721318141636044536441),
       .01064026039260234415487304925754523),    // 117 468
  PQP3(R3(1. - (.20755902173331721318141636044536441) - (.20755902173331721318141636044536441) -
            (.49641284136813420000000000000000000),
          .20755902173331721318141636044536441, .20755902173331721318141636044536441),
       .01064026039260234415487304925754523),    // 118 472
  PQP3(R3(.20755902173331721318141636044536441, .20755902173331721318141636044536441,
          .49641284136813420000000000000000000),
       .01064026039260234415487304925754523),    // 119 476
  PQP3(R3(.20755902173331721318141636044536441, .49641284136813420000000000000000000,
          .20755902173331721318141636044536441),
       .01064026039260234415487304925754523),    // 120 480
  PQP3(R3(.49641284136813420000000000000000000, .20755902173331721318141636044536441,
          .20755902173331721318141636044536441),
       .01064026039260234415487304925754523),    // 121 484
  PQP3(R3(.00317672566580133046838579859910808, .88571644680187933415518991697343211,
          1. - (.00317672566580133046838579859910808) - (.00317672566580133046838579859910808) -
            (.88571644680187933415518991697343211)),
       .00031627239419231128593612508289817),    // 122 488
  PQP3(R3(.00317672566580133046838579859910808,
          1. - (.00317672566580133046838579859910808) - (.00317672566580133046838579859910808) -
            (.88571644680187933415518991697343211),
          .88571644680187933415518991697343211),
       .00031627239419231128593612508289817),    // 123 492
  PQP3(R3(.88571644680187933415518991697343211, .00317672566580133046838579859910808,
          1. - (.00317672566580133046838579859910808) - (.00317672566580133046838579859910808) -
            (.88571644680187933415518991697343211)),
       .00031627239419231128593612508289817),    // 124 496
  PQP3(R3(.88571644680187933415518991697343211,
          1. - (.00317672566580133046838579859910808) - (.00317672566580133046838579859910808) -
            (.88571644680187933415518991697343211),
          .00317672566580133046838579859910808),
       .00031627239419231128593612508289817),    // 125 500
  PQP3(R3(1. - (.00317672566580133046838579859910808) - (.00317672566580133046838579859910808) -
            (.88571644680187933415518991697343211),
          .00317672566580133046838579859910808, .88571644680187933415518991697343211),
       .00031627239419231128593612508289817),    // 126 504
  PQP3(R3(1. - (.00317672566580133046838579859910808) - (.00317672566580133046838579859910808) -
            (.88571644680187933415518991697343211),
          .88571644680187933415518991697343211, .00317672566580133046838579859910808),
       .00031627239419231128593612508289817),    // 127 508
  PQP3(R3(.00317672566580133046838579859910808, .00317672566580133046838579859910808,
          1. - (.00317672566580133046838579859910808) - (.00317672566580133046838579859910808) -
            (.88571644680187933415518991697343211)),
       .00031627239419231128593612508289817),    // 128 512
  PQP3(R3(.00317672566580133046838579859910808,
          1. - (.00317672566580133046838579859910808) - (.00317672566580133046838579859910808) -
            (.88571644680187933415518991697343211),
          .00317672566580133046838579859910808),
       .00031627239419231128593612508289817),    // 129 516
  PQP3(R3(1. - (.00317672566580133046838579859910808) - (.00317672566580133046838579859910808) -
            (.88571644680187933415518991697343211),
          .00317672566580133046838579859910808, .00317672566580133046838579859910808),
       .00031627239419231128593612508289817),    // 130 520
  PQP3(R3(.00317672566580133046838579859910808, .00317672566580133046838579859910808,
          .88571644680187933415518991697343211),
       .00031627239419231128593612508289817),    // 131 524
  PQP3(R3(.00317672566580133046838579859910808, .88571644680187933415518991697343211,
          .00317672566580133046838579859910808),
       .00031627239419231128593612508289817),    // 132 528
  PQP3(R3(.88571644680187933415518991697343211, .00317672566580133046838579859910808,
          .00317672566580133046838579859910808),
       .00031627239419231128593612508289817),    // 133 532
  PQP3(R3(.16634658949265576428233847556684871, .64221464654291632524678940601354742,
          1. - (.16634658949265576428233847556684871) - (.16634658949265576428233847556684871) -
            (.64221464654291632524678940601354742)),
       .00676212093730203740266276007684025),    // 134 536
  PQP3(R3(.16634658949265576428233847556684871,
          1. - (.16634658949265576428233847556684871) - (.16634658949265576428233847556684871) -
            (.64221464654291632524678940601354742),
          .64221464654291632524678940601354742),
       .00676212093730203740266276007684025),    // 135 540
  PQP3(R3(.64221464654291632524678940601354742, .16634658949265576428233847556684871,
          1. - (.16634658949265576428233847556684871) - (.16634658949265576428233847556684871) -
            (.64221464654291632524678940601354742)),
       .00676212093730203740266276007684025),    // 136 544
  PQP3(R3(.64221464654291632524678940601354742,
          1. - (.16634658949265576428233847556684871) - (.16634658949265576428233847556684871) -
            (.64221464654291632524678940601354742),
          .16634658949265576428233847556684871),
       .00676212093730203740266276007684025),    // 137 548
  PQP3(R3(1. - (.16634658949265576428233847556684871) - (.16634658949265576428233847556684871) -
            (.64221464654291632524678940601354742),
          .16634658949265576428233847556684871, .64221464654291632524678940601354742),
       .00676212093730203740266276007684025),    // 138 552
  PQP3(R3(1. - (.16634658949265576428233847556684871) - (.16634658949265576428233847556684871) -
            (.64221464654291632524678940601354742),
          .64221464654291632524678940601354742, .16634658949265576428233847556684871),
       .00676212093730203740266276007684025),    // 139 556
  PQP3(R3(.16634658949265576428233847556684871, .16634658949265576428233847556684871,
          1. - (.16634658949265576428233847556684871) - (.16634658949265576428233847556684871) -
            (.64221464654291632524678940601354742)),
       .00676212093730203740266276007684025),    // 140 560
  PQP3(R3(.16634658949265576428233847556684871,
          1. - (.16634658949265576428233847556684871) - (.16634658949265576428233847556684871) -
            (.64221464654291632524678940601354742),
          .16634658949265576428233847556684871),
       .00676212093730203740266276007684025),    // 141 564
  PQP3(R3(1. - (.16634658949265576428233847556684871) - (.16634658949265576428233847556684871) -
            (.64221464654291632524678940601354742),
          .16634658949265576428233847556684871, .16634658949265576428233847556684871),
       .00676212093730203740266276007684025),    // 142 568
  PQP3(R3(.16634658949265576428233847556684871, .16634658949265576428233847556684871,
          .64221464654291632524678940601354742),
       .00676212093730203740266276007684025),    // 143 572
  PQP3(R3(.16634658949265576428233847556684871, .64221464654291632524678940601354742,
          .16634658949265576428233847556684871),
       .00676212093730203740266276007684025),    // 144 576
  PQP3(R3(.64221464654291632524678940601354742, .16634658949265576428233847556684871,
          .16634658949265576428233847556684871),
       .00676212093730203740266276007684025),    // 145 580
  PQP3(R3(.30344194369885264264500117734906354, .00772105989990930297678960227638472,
          1. - (.59698804897542365623933181080626979) - (.30344194369885264264500117734906354) -
            (.00772105989990930297678960227638472)),
       .00293371746826111669254642316791922),    // 146 584
  PQP3(R3(.30344194369885264264500117734906354,
          1. - (.59698804897542365623933181080626979) - (.30344194369885264264500117734906354) -
            (.00772105989990930297678960227638472),
          .00772105989990930297678960227638472),
       .00293371746826111669254642316791922),    // 147 588
  PQP3(R3(.00772105989990930297678960227638472, .30344194369885264264500117734906354,
          1. - (.59698804897542365623933181080626979) - (.30344194369885264264500117734906354) -
            (.00772105989990930297678960227638472)),
       .00293371746826111669254642316791922),    // 148 592
  PQP3(R3(.00772105989990930297678960227638472,
          1. - (.59698804897542365623933181080626979) - (.30344194369885264264500117734906354) -
            (.00772105989990930297678960227638472),
          .30344194369885264264500117734906354),
       .00293371746826111669254642316791922),    // 149 596
  PQP3(R3(1. - (.59698804897542365623933181080626979) - (.30344194369885264264500117734906354) -
            (.00772105989990930297678960227638472),
          .30344194369885264264500117734906354, .00772105989990930297678960227638472),
       .00293371746826111669254642316791922),    // 150 600
  PQP3(R3(1. - (.59698804897542365623933181080626979) - (.30344194369885264264500117734906354) -
            (.00772105989990930297678960227638472),
          .00772105989990930297678960227638472, .30344194369885264264500117734906354),
       .00293371746826111669254642316791922),    // 151 604
  PQP3(R3(.59698804897542365623933181080626979, .00772105989990930297678960227638472,
          1. - (.59698804897542365623933181080626979) - (.30344194369885264264500117734906354) -
            (.00772105989990930297678960227638472)),
       .00293371746826111669254642316791922),    // 152 608
  PQP3(R3(.59698804897542365623933181080626979,
          1. - (.59698804897542365623933181080626979) - (.30344194369885264264500117734906354) -
            (.00772105989990930297678960227638472),
          .00772105989990930297678960227638472),
       .00293371746826111669254642316791922),    // 153 612
  PQP3(R3(.00772105989990930297678960227638472, .59698804897542365623933181080626979,
          1. - (.59698804897542365623933181080626979) - (.30344194369885264264500117734906354) -
            (.00772105989990930297678960227638472)),
       .00293371746826111669254642316791922),    // 154 616
  PQP3(R3(.00772105989990930297678960227638472,
          1. - (.59698804897542365623933181080626979) - (.30344194369885264264500117734906354) -
            (.00772105989990930297678960227638472),
          .59698804897542365623933181080626979),
       .00293371746826111669254642316791922),    // 155 620
  PQP3(R3(1. - (.59698804897542365623933181080626979) - (.30344194369885264264500117734906354) -
            (.00772105989990930297678960227638472),
          .59698804897542365623933181080626979, .00772105989990930297678960227638472),
       .00293371746826111669254642316791922),    // 156 624
  PQP3(R3(1. - (.59698804897542365623933181080626979) - (.30344194369885264264500117734906354) -
            (.00772105989990930297678960227638472),
          .00772105989990930297678960227638472, .59698804897542365623933181080626979),
       .00293371746826111669254642316791922),    // 157 628
  PQP3(R3(.59698804897542365623933181080626979, .30344194369885264264500117734906354,
          1. - (.59698804897542365623933181080626979) - (.30344194369885264264500117734906354) -
            (.00772105989990930297678960227638472)),
       .00293371746826111669254642316791922),    // 158 632
  PQP3(R3(.59698804897542365623933181080626979,
          1. - (.59698804897542365623933181080626979) - (.30344194369885264264500117734906354) -
            (.00772105989990930297678960227638472),
          .30344194369885264264500117734906354),
       .00293371746826111669254642316791922),    // 159 636
  PQP3(R3(.30344194369885264264500117734906354, .59698804897542365623933181080626979,
          1. - (.59698804897542365623933181080626979) - (.30344194369885264264500117734906354) -
            (.00772105989990930297678960227638472)),
       .00293371746826111669254642316791922),    // 160 640
  PQP3(R3(.30344194369885264264500117734906354,
          1. - (.59698804897542365623933181080626979) - (.30344194369885264264500117734906354) -
            (.00772105989990930297678960227638472),
          .59698804897542365623933181080626979),
       .00293371746826111669254642316791922),    // 161 644
  PQP3(R3(1. - (.59698804897542365623933181080626979) - (.30344194369885264264500117734906354) -
            (.00772105989990930297678960227638472),
          .59698804897542365623933181080626979, .30344194369885264264500117734906354),
       .00293371746826111669254642316791922),    // 162 648
  PQP3(R3(1. - (.59698804897542365623933181080626979) - (.30344194369885264264500117734906354) -
            (.00772105989990930297678960227638472),
          .30344194369885264264500117734906354, .59698804897542365623933181080626979),
       .00293371746826111669254642316791922),    // 163 652
  PQP3(R3(.59698804897542365623933181080626979, .30344194369885264264500117734906354,
          .00772105989990930297678960227638472),
       .00293371746826111669254642316791922),    // 164 656
  PQP3(R3(.59698804897542365623933181080626979, .00772105989990930297678960227638472,
          .30344194369885264264500117734906354),
       .00293371746826111669254642316791922),    // 165 660
  PQP3(R3(.30344194369885264264500117734906354, .59698804897542365623933181080626979,
          .00772105989990930297678960227638472),
       .00293371746826111669254642316791922),    // 166 664
  PQP3(R3(.30344194369885264264500117734906354, .00772105989990930297678960227638472,
          .59698804897542365623933181080626979),
       .00293371746826111669254642316791922),    // 167 668
  PQP3(R3(.00772105989990930297678960227638472, .59698804897542365623933181080626979,
          .30344194369885264264500117734906354),
       .00293371746826111669254642316791922),    // 168 672
  PQP3(R3(.00772105989990930297678960227638472, .30344194369885264264500117734906354,
          .59698804897542365623933181080626979),
       .00293371746826111669254642316791922),    // 169 676
  PQP3(R3(.06021328978843793059084645285790579, .12582571438467239382589793638340901,
          1. - (.81379652801439184798325669233364806) - (.06021328978843793059084645285790579) -
            (.12582571438467239382589793638340901)),
       .00091803679200083798695474146748587),    // 170 680
  PQP3(R3(.06021328978843793059084645285790579,
          1. - (.81379652801439184798325669233364806) - (.06021328978843793059084645285790579) -
            (.12582571438467239382589793638340901),
          .12582571438467239382589793638340901),
       .00091803679200083798695474146748587),    // 171 684
  PQP3(R3(.12582571438467239382589793638340901, .06021328978843793059084645285790579,
          1. - (.81379652801439184798325669233364806) - (.06021328978843793059084645285790579) -
            (.12582571438467239382589793638340901)),
       .00091803679200083798695474146748587),    // 172 688
  PQP3(R3(.12582571438467239382589793638340901,
          1. - (.81379652801439184798325669233364806) - (.06021328978843793059084645285790579) -
            (.12582571438467239382589793638340901),
          .06021328978843793059084645285790579),
       .00091803679200083798695474146748587),    // 173 692
  PQP3(R3(1. - (.81379652801439184798325669233364806) - (.06021328978843793059084645285790579) -
            (.12582571438467239382589793638340901),
          .06021328978843793059084645285790579, .12582571438467239382589793638340901),
       .00091803679200083798695474146748587),    // 174 696
  PQP3(R3(1. - (.81379652801439184798325669233364806) - (.06021328978843793059084645285790579) -
            (.12582571438467239382589793638340901),
          .12582571438467239382589793638340901, .06021328978843793059084645285790579),
       .00091803679200083798695474146748587),    // 175 700
  PQP3(R3(.81379652801439184798325669233364806, .12582571438467239382589793638340901,
          1. - (.81379652801439184798325669233364806) - (.06021328978843793059084645285790579) -
            (.12582571438467239382589793638340901)),
       .00091803679200083798695474146748587),    // 176 704
  PQP3(R3(.81379652801439184798325669233364806,
          1. - (.81379652801439184798325669233364806) - (.06021328978843793059084645285790579) -
            (.12582571438467239382589793638340901),
          .12582571438467239382589793638340901),
       .00091803679200083798695474146748587),    // 177 708
  PQP3(R3(.12582571438467239382589793638340901, .81379652801439184798325669233364806,
          1. - (.81379652801439184798325669233364806) - (.06021328978843793059084645285790579) -
            (.12582571438467239382589793638340901)),
       .00091803679200083798695474146748587),    // 178 712
  PQP3(R3(.12582571438467239382589793638340901,
          1. - (.81379652801439184798325669233364806) - (.06021328978843793059084645285790579) -
            (.12582571438467239382589793638340901),
          .81379652801439184798325669233364806),
       .00091803679200083798695474146748587),    // 179 716
  PQP3(R3(1. - (.81379652801439184798325669233364806) - (.06021328978843793059084645285790579) -
            (.12582571438467239382589793638340901),
          .81379652801439184798325669233364806, .12582571438467239382589793638340901),
       .00091803679200083798695474146748587),    // 180 720
  PQP3(R3(1. - (.81379652801439184798325669233364806) - (.06021328978843793059084645285790579) -
            (.12582571438467239382589793638340901),
          .12582571438467239382589793638340901, .81379652801439184798325669233364806),
       .00091803679200083798695474146748587),    // 181 724
  PQP3(R3(.81379652801439184798325669233364806, .06021328978843793059084645285790579,
          1. - (.81379652801439184798325669233364806) - (.06021328978843793059084645285790579) -
            (.12582571438467239382589793638340901)),
       .00091803679200083798695474146748587),    // 182 728
  PQP3(R3(.81379652801439184798325669233364806,
          1. - (.81379652801439184798325669233364806) - (.06021328978843793059084645285790579) -
            (.12582571438467239382589793638340901),
          .06021328978843793059084645285790579),
       .00091803679200083798695474146748587),    // 183 732
  PQP3(R3(.06021328978843793059084645285790579, .81379652801439184798325669233364806,
          1. - (.81379652801439184798325669233364806) - (.06021328978843793059084645285790579) -
            (.12582571438467239382589793638340901)),
       .00091803679200083798695474146748587),    // 184 736
  PQP3(R3(.06021328978843793059084645285790579,
          1. - (.81379652801439184798325669233364806) - (.06021328978843793059084645285790579) -
            (.12582571438467239382589793638340901),
          .81379652801439184798325669233364806),
       .00091803679200083798695474146748587),    // 185 740
  PQP3(R3(1. - (.81379652801439184798325669233364806) - (.06021328978843793059084645285790579) -
            (.12582571438467239382589793638340901),
          .81379652801439184798325669233364806, .06021328978843793059084645285790579),
       .00091803679200083798695474146748587),    // 186 744
  PQP3(R3(1. - (.81379652801439184798325669233364806) - (.06021328978843793059084645285790579) -
            (.12582571438467239382589793638340901),
          .06021328978843793059084645285790579, .81379652801439184798325669233364806),
       .00091803679200083798695474146748587),    // 187 748
  PQP3(R3(.81379652801439184798325669233364806, .06021328978843793059084645285790579,
          .12582571438467239382589793638340901),
       .00091803679200083798695474146748587),    // 188 752
  PQP3(R3(.81379652801439184798325669233364806, .12582571438467239382589793638340901,
          .06021328978843793059084645285790579),
       .00091803679200083798695474146748587),    // 189 756
  PQP3(R3(.06021328978843793059084645285790579, .81379652801439184798325669233364806,
          .12582571438467239382589793638340901),
       .00091803679200083798695474146748587),    // 190 760
  PQP3(R3(.06021328978843793059084645285790579, .12582571438467239382589793638340901,
          .81379652801439184798325669233364806),
       .00091803679200083798695474146748587),    // 191 764
  PQP3(R3(.12582571438467239382589793638340901, .81379652801439184798325669233364806,
          .06021328978843793059084645285790579),
       .00091803679200083798695474146748587),    // 192 768
  PQP3(R3(.12582571438467239382589793638340901, .06021328978843793059084645285790579,
          .81379652801439184798325669233364806),
       .00091803679200083798695474146748587),    // 193 772
};
PQF3 const QuadratureFormular_Tet_P14(14, 194, QF_TET_P14);
const GQuadratureFormular< R2 > *tripleQF(Stack stack,
                                          const GQuadratureFormular< R2 > *const &pqf) {
  const GQuadratureFormular< R2 > &qf = *pqf;
  int np = qf.n * 3;

  GQuadraturePoint< R2 > *pq = new GQuadraturePoint< R2 >[np];

  for (int i = 0; i < np; ++i) {
    int j = i % 3, k = i / 3;
    const GQuadraturePoint< R2 > &Pk = qf[k];
    double x = Pk.x, y = Pk.y, z = 1 - x - y;
    if (j == 0) {
      x /= 3;
      y += x;
    } else if (j == 1) {
      y /= 3;
      x += y;
    } else {
      z /= 3;
      x += z;
      y += z;
    }

    pq[i].a = Pk.a / 3;
    pq[i].x = x;
    pq[i].y = y;
  }

  GQuadratureFormular< R2 > *q = new GQuadratureFormular< R2 >(qf.exact, np, pq, true);
  Add2StackOfPtr2Free(stack, q);
  return q;
}

template< class Rd >
const GQuadratureFormular< Rd > **cloneQF(const GQuadratureFormular< Rd > **const &pr,
                                          GQuadratureFormular< Rd > const *const &qf) {
  ffassert(pr);
  int np = qf->n;
  GQuadraturePoint< Rd > *pq = new GQuadraturePoint< Rd >[np];

  for (int i = 0; i < np; ++i) {
    pq[i] = (*qf)[i];
  }

  *pr = new GQuadratureFormular< Rd >(qf->exact, np, pq, true);
  return pr;
}

#include "lex.hpp"
extern mylex *zzzfff;
static void Load_Init( ) {
  /*
   * grep QuadratureFormular QF.cpp|grep ^const|awk -F"[_(]" '{print "Global.New(@qf" $3
   * "pT@,CConstant<const QuadratureFormular *>(&QuadratureFormular_T_"$3"));"}'|sed -e 's/@/"/g'
   */
  Global.New("qf11pT", CConstant< const QuadratureFormular * >(&QuadratureFormular_T_11));
  Global.New("qf13pT", CConstant< const QuadratureFormular * >(&QuadratureFormular_T_13));
  Global.New("qf14pT", CConstant< const QuadratureFormular * >(&QuadratureFormular_T_14));
  Global.New("qf16pT", CConstant< const QuadratureFormular * >(&QuadratureFormular_T_16));
  Global.New("qf18pT", CConstant< const QuadratureFormular * >(&QuadratureFormular_T_18));
  Global.New("qf20pT", CConstant< const QuadratureFormular * >(&QuadratureFormular_T_20));
  Global.New("qf21pT", CConstant< const QuadratureFormular * >(&QuadratureFormular_T_21));
  Global.New("qf23pT", CConstant< const QuadratureFormular * >(&QuadratureFormular_T_23));
  Global.New("qf25pT", CConstant< const QuadratureFormular * >(&QuadratureFormular_T_25));
  Global.New("qf11pE", CConstant< const QuadratureFormular1d * >(
                         new QuadratureFormular1d(-1 + 2 * 11, 11, GaussLegendre(11), true)));
  Global.New("qf12pE", CConstant< const QuadratureFormular1d * >(
                         new QuadratureFormular1d(-1 + 2 * 12, 12, GaussLegendre(12), true)));
  Global.New("qf13pE", CConstant< const QuadratureFormular1d * >(
                         new QuadratureFormular1d(-1 + 2 * 13, 13, GaussLegendre(13), true)));

  Global.Add(
    "QF1d", "(",
    new OneOperator2_< const GQuadratureFormular< R1 > *, long, KNM_< double > >(BuilQFd< R1 >));
  Global.Add(
    "QF2d", "(",
    new OneOperator2_< const GQuadratureFormular< R2 > *, long, KNM_< double > >(BuilQFd< R2 >));
  Global.Add(
    "QF3d", "(",
    new OneOperator2_< const GQuadratureFormular< R3 > *, long, KNM_< double > >(BuilQFd< R3 >));

  Dcl_Type< const GQuadratureFormular< R1 > ** >(
    ::InitializePtr< const GQuadratureFormular< R1 > * >,
    ::DeletePtr< const GQuadratureFormular< R1 > * >);
  Dcl_Type< const GQuadratureFormular< R2 > ** >(
    ::InitializePtr< const GQuadratureFormular< R2 > * >,
    ::DeletePtr< const GQuadratureFormular< R2 > * >);
  Dcl_Type< const GQuadratureFormular< R3 > ** >(
    ::InitializePtr< const GQuadratureFormular< R3 > * >,
    ::DeletePtr< const GQuadratureFormular< R3 > * >);

  zzzfff->Add("QF1", atype< const GQuadratureFormular< R1 > ** >( ));
  zzzfff->Add("QF2", atype< const GQuadratureFormular< R2 > ** >( ));
  zzzfff->Add("QF3", atype< const GQuadratureFormular< R3 > ** >( ));

  TheOperators->Add(
    "<-",
    new OneOperator3_< const GQuadratureFormular< R1 > **, const GQuadratureFormular< R1 > **, long,
                       KNM_< double > >(pBuilQFd< R1 >),
    new OneOperator3_< const GQuadratureFormular< R2 > **, const GQuadratureFormular< R2 > **, long,
                       KNM_< double > >(pBuilQFd< R2 >),
    new OneOperator3_< const GQuadratureFormular< R3 > **, const GQuadratureFormular< R3 > **, long,
                       KNM_< double > >(pBuilQFd< R3 >),
    new OneOperator2_< const GQuadratureFormular< R2 > **, const GQuadratureFormular< R2 > **,
                       const GQuadratureFormular< R2 > * >(cloneQF< R2 >),
    new OneOperator2_< const GQuadratureFormular< R3 > **, const GQuadratureFormular< R3 > **,
                       const GQuadratureFormular< R3 > * >(cloneQF< R3 >),
    new OneOperator2_< const GQuadratureFormular< R1 > **, const GQuadratureFormular< R1 > **,
                       const GQuadratureFormular< R1 > * >(cloneQF< R1 >)

  );
  // cast ** -> *
  map_type[typeid(const GQuadratureFormular< R1 > *).name( )]->AddCast(
    new E_F1_funcT< const GQuadratureFormular< R1 > *, const GQuadratureFormular< R1 > ** >(
      UnRef< const GQuadratureFormular< R1 > * >));
  map_type[typeid(const GQuadratureFormular< R2 > *).name( )]->AddCast(
    new E_F1_funcT< const GQuadratureFormular< R2 > *, const GQuadratureFormular< R2 > ** >(
      UnRef< const GQuadratureFormular< R2 > * >));
  map_type[typeid(const GQuadratureFormular< R3 > *).name( )]->AddCast(
    new E_F1_funcT< const GQuadratureFormular< R3 > *, const GQuadratureFormular< R3 > ** >(
      UnRef< const GQuadratureFormular< R3 > * >));
  // new quadrature formular for tet from ...
  /*
   * % Reference:
   * % @article{liu2009set,
   * %   title={{A SET OF SYMMETRIC QUADRATURE RULES ON TRIANGLES AND TETRAHEDRA}},
   * %   author={Zhang.L. and Cui, T. and Liu,H.},
   * %   journal={Journal of computational Mathematics
   * %   number={001},
   * %   pages={89--96},
   * %   issn={0254-9409},
   * %   year={2009}
   * % }
   *
   */
  Global.New("qfVp1", CConstant< const GQuadratureFormular< R3 > * >(&QuadratureFormular_Tet_P1));
  Global.New("qfVp2", CConstant< const GQuadratureFormular< R3 > * >(&QuadratureFormular_Tet_P2));
  Global.New("qfVp3", CConstant< const GQuadratureFormular< R3 > * >(&QuadratureFormular_Tet_P3));
  Global.New("qfVp4", CConstant< const GQuadratureFormular< R3 > * >(&QuadratureFormular_Tet_P4));
  Global.New("qfVp5", CConstant< const GQuadratureFormular< R3 > * >(&QuadratureFormular_Tet_P5));
  Global.New("qfVp6", CConstant< const GQuadratureFormular< R3 > * >(&QuadratureFormular_Tet_P6));
  Global.New("qfVp7", CConstant< const GQuadratureFormular< R3 > * >(&QuadratureFormular_Tet_P7));
  Global.New("qfVp8", CConstant< const GQuadratureFormular< R3 > * >(&QuadratureFormular_Tet_P8));
  Global.New("qfVp9", CConstant< const GQuadratureFormular< R3 > * >(&QuadratureFormular_Tet_P9));
  Global.New("qfVp10", CConstant< const GQuadratureFormular< R3 > * >(&QuadratureFormular_Tet_P10));
  Global.New("qfVp11", CConstant< const GQuadratureFormular< R3 > * >(&QuadratureFormular_Tet_P11));
  Global.New("qfVp12", CConstant< const GQuadratureFormular< R3 > * >(&QuadratureFormular_Tet_P12));
  Global.New("qfVp13", CConstant< const GQuadratureFormular< R3 > * >(&QuadratureFormular_Tet_P13));
  Global.New("qfVp14", CConstant< const GQuadratureFormular< R3 > * >(&QuadratureFormular_Tet_P14));
  //
  Global.Add(
    "tripleQF", "(",
    new OneOperator1s_< const GQuadratureFormular< R2 > *, const GQuadratureFormular< R2 > * >(
      tripleQF));
}

LOADFUNC(Load_Init)
